/*  Splunk: Variables */
/*  ================================================== */
/*  Variables to customize the look and feel of Bootstrap (splunk version) */

/*  STATIC PATHS */
/*  ------------------------- */


/*  COLOR PALETTE */
/*  ------------------------- */

/*  Enterprise */

/*  Light */

/*  Grayscale - DO NOT USE DIRECTLY WHENEVER POSSIBLE!!! Use text, border or table variables instead. */

/*  Accent colors */ /* sky */


/*  TYPOGRAPHY */
/*  ------------------------- */ /*  18px; */ /*  Lite listing pages */ /*  empty to use BS default, $baseFontFamily */    /*  instead of browser default, bold */ /*  empty to use BS default, $textColor */


/*  SCAFFOLDING */
/*  ------------------------- */ /*  aliases: $tableBorderColor $tableBorderColorVertical */
/*  also see: $interactiveBorderColor */      /* For containers without a wrapper */  /* For for containers with a wrapper, like popdown */ /*  44px */  /*  26px  */   /*  22px */


/*  Horizontal forms & lists */
/*  ------------------------- */


/*  Z-INDEX */
/*  ------------------------- */
/*  If a variable does not suit your purpose, set a value relatively such as, $zindexModal +1 */ /*  Splunk Lite */ /*  Splunk Lite */ /*  Sidebar Component */ /*  Sidebar Component */ /*  timerange popdown needs to be above modal + backdrop */ /*  top interactive element */ /*  top interactive element */ /*  top uninteractive */ /*  top uninteractive */


/*  TABLES */
/*  ------------------------- */ /*  overall background-color */ /*  for hover */ /*  for striping */ /*  for striping */ /*  table and cell border */ /*  table and cell border */ /*  table and cell border */


/*  FORMS */
/*  ------------------------- */ /*  base line-height + 8px vertical padding + 2px top/bottom border */ /*  This is generally overridden. */


/*  BASE INTERACTIVE */
/*  -------------------------- */
/*  text */
/*  background */
/*  borders */ /* these can't be different without breaking button groups. */
/*  shadow */


/*  BASE INTERACTIVE ERROR */
/*  -------------------------- */
/*  text */
/*  background */
/*  borders */

/*  PRIMARY BUTTONS */
/*  -------------------------- */
/*  text */
/*  background */
/*  borders */
/*  shadow */


/*  PILL BUTTONS */
/*  -------------------------- */
/*  text */
/*  background */


/*  BUTTONS */
/*  ------------------------- */
/*  Used in non-standard buttons - Legacy Bootstrap classes only */


/*  COMPONENT VARIABLES */
/*  -------------------------------------------------- */

/*  Navbar */
/*  ------------------------- */ /* Fixes issue for escaped Dashboards. */

/*  Inverted navbar */


/*  Tooltips and popovers */
/*  ------------------------- */


/*  GRID */
/*  -------------------------- */
/*  Default 940px grid */
/*  Fluid grid */

/*  1200px min */

/*  768px-979px */


/*  Fluid grid */
/*  ------------------------- */

/*  1200px min */

/*  768px-979px */


/*  Responsive Variables */


/*  SELECTORS FOR CUSTOMIZING SPECIFIC LOCALES */
/*  -------------------------- */


/*  BUILD COMMENT */
/*  -------------------------- */
/*  Hide the Build Comment. The make file sets this to true */

/*  LEGACY BUILD */
/*  -------------------------- */
/*  This is set to true when building the less for splunk components. */
/*  Splunk: Mixins */
/*  ================== */
/*  Snippets of reusable CSS to develop faster and keep code readable */

/*  Splunk: Mixins */
/*  ================== */
/*  Snippets of reusable CSS to develop faster and keep code readable */


/*  Mixins */
/*  -------------------------------------------------- */


/*  UTILITY MIXINS */
/*  -------------------------------------------------- */

/*  Link */
/*  ------------------ */


/*  Clearfix */
/*  -------- */
/*  For clearing floats like a boss h5bp.com/q */

/*  Webkit-style focus */
/*  ------------------ */

/*  Center-align a block level element */
/*  ---------------------------------- */

/*  Sizing shortcuts */
/*  ------------------------- */

/*  Placeholder text */
/*  ------------------------- */

/*  Text overflow */
/*  ------------------------- */
/*  Requires inline-block or block for proper styling */

/*  CSS image replacement */
/*  ------------------------- */
/*  Source: https://github.com/h5bp/html5-boilerplate/commit/aa0396eae757 */


/*  FONTS */
/*  -------------------------------------------------- */


/*  FORMS */
/*  -------------------------------------------------- */

/*  Block level inputs */

/*  Mixin for form field states */


/*  CSS3 PROPERTIES */
/*  -------------------------------------------------- */


/*  Single Side Border Radius */


/*  Transformations */



/*  Resize anything */

/*  CSS3 Content Columns */

/*  Optional hyphenation */




/*  BACKGROUNDS */
/*  -------------------------------------------------- */

/*  Gradient Bar Colors for buttons and alerts */

/*  Gradients */

/*  Reset filters for IE */



/*  COMPONENT MIXINS */
/*  -------------------------------------------------- */

/*  Horizontal dividers */
/*  ------------------------- */
/*  Dividers (basically an hr) within dropdowns and nav lists */

/*  Button backgrounds */
/*  ------------------ */

/*  Navbar vertical align */
/*  ------------------------- */
/*  Vertically center elements in the navbar. */
/*  Example: an element has a height of 30px, so write out `.navbarVerticalAlign(30px);` to calculate the appropriate top margin. */



/*  Disable highlighting text */
/*  ------------------------- */

/*  Printing */
/*  ------------------ */


/*  Popdown */
/*  ------------------ *//*  .popdown-dialog */

/*  popdown body */



/* Flex
/*  ------------- */

/*  Full Page Layout */
/*  ------------- */




/*  Grid System */
/*  ----------- */

/*  Centered container element */

/*  Table columns */

/*  Make a Grid */
/*  Use .makeRow and .makeColumn to assign semantic layouts grid system behavior */

/*  The Grid */

/*  Interactive */
/*  -------------------------------------------------- */
/*  These are by any element that can be clicked, such as buttons, menus and table headings. */

/*  Hover state */

/*  Interactive Error */
/*  These are by any interactive element that is is in an error state */

/*  primary */

/*  primary hover state */

/* Overlays (Modal, Popdown, Search Assistant) */

/*  Focus States */
/*  ----------------------------- */

/*  Text entry boxes change their border color and glow */

/*  Clickable buttons change their border color and glow */

/*  Block elements change the background color */
/*  Block elements change the background color and spread via box-shadow */

/*  Docking Elements */
/*  ------------------ */

/*  Webkit-style focus */
/*  ------------------ */

/*  Draggable Handle */
/*  Splunk bootstrap */
/*  import and override bootstrap defaults */

/*  CSS Reset */
/*  Reset CSS */
/*  Adapted from http://github.com/necolas/normalize.css */
/*  -------------------------------------------------- */


/*  Display in IE6-9 and FF3 */
/*  ------------------------- */

article,
aside,
details,
figcaption,
figure,
footer,
header,
hgroup,
nav,
section {
  display: block;
}

/*  Display block in IE6-9 and FF3 */
/*  ------------------------- */

audio,
canvas,
video {
  display: inline-block;
}

/*  Prevents modern browsers from displaying 'audio' without controls */
/*  ------------------------- */

audio:not([controls]) {
    display: none;
}

/*  Base settings */
/*  ------------------------- */

html {
  font-size: 100%;
  -webkit-text-size-adjust: 100%;
      -ms-text-size-adjust: 100%;
          text-size-adjust: 100%;
}
/*  Focus states */
a:focus {
  /*  Default */
  outline: thin dotted #333;
  /*  Webkit */
  outline: 3px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
/*  Hover & Active */
a:hover,
a:active {
  outline: 0;
}

/*  Prevents sub and sup affecting line-height in all browsers */
/*  ------------------------- */

sub,
sup {
  position: relative;
  font-size: 75%;
  line-height: 0;
  vertical-align: baseline;
}
sup {
  top: -0.5em;
}
sub {
  bottom: -0.25em;
}

/*  Img border in a's and image quality */
/*  ------------------------- */

img {
  /* Responsive images (ensure images don't scale beyond their parents) */
  max-width: 100%; /* Part 1: Set a maxium relative to the parent */
  height: auto; /* Part 2: Scale the height according to the width, otherwise you get stretching */

  vertical-align: middle;
  border: 0;
  -ms-interpolation-mode: bicubic;
}

/*  Prevent max-width from affecting Google Maps */
#map_canvas img,
.google-maps img {
  max-width: none;
}

/*  Forms */
/*  ------------------------- */

/*  Font size in all browsers, margin changes, misc consistency */
button,
input,
select,
textarea {
  margin: 0;
  font-size: 100%;
  vertical-align: middle;
}
button,
input {
  line-height: normal; /*  FF3/4 have !important on line-height in UA stylesheet */
}
button::-moz-focus-inner,
input::-moz-focus-inner { /*  Inner padding and border oddities in FF3/4 */
  padding: 0;
  border: 0;
}
button,
html input[type="button"], /*  Avoid the WebKit bug in Android 4.0.* where (2) destroys native `audio` and `video` controls. */
input[type="reset"],
input[type="submit"] {
    -webkit-appearance: button; /*  Corrects inability to style clickable `input` types in iOS. */
    cursor: pointer; /*  Improves usability and consistency of cursor style between image-type `input` and others. */
}
label,
select,
button,
input[type="button"],
input[type="reset"],
input[type="submit"],
input[type="radio"],
input[type="checkbox"] {
    cursor: pointer; /*  Improves usability and consistency of cursor style between image-type `input` and others. */
}
input[type="search"] { /*  Appearance in Safari/Chrome */
  box-sizing: content-box;
  -webkit-appearance: textfield;
}
input[type="search"]::-webkit-search-decoration,
input[type="search"]::-webkit-search-cancel-button {
  -webkit-appearance: none; /*  Inner-padding issues in Chrome OSX, Safari 5 */
}
textarea {
  overflow: auto; /*  Remove vertical scrollbar in IE6-9 */
  vertical-align: top; /*  Readability and alignment cross-browser */
}


/*  Printing */
/*  ------------------------- */
/*  Source: https://github.com/h5bp/html5-boilerplate/blob/master/css/main.css */

@media print {

  * {
    text-shadow: none !important;
    color: #000 !important; /*  Black prints faster: h5bp.com/s */
    background: transparent !important;
    box-shadow: none !important;
  }

  a,
  a:visited {
    text-decoration: underline;
  }

  a[href]:after {
    content: " (" attr(href) ")";
  }

  abbr[title]:after {
    content: " (" attr(title) ")";
  }

  /*  Don't show links for images, or javascript/internal links */
  .ir a:after,
  a[href^="javascript:"]:after,
  a[href^="#"]:after {
    content: "";
  }

  pre,
  blockquote {
    border: 1px solid #999;
    page-break-inside: avoid;
  }

  thead {
    display: table-header-group; /*  h5bp.com/t */
  }

  tr,
  img {
    page-break-inside: avoid;
  }

  img {
    max-width: 100% !important;
  }

  @page {
    margin: 0.5cm;
  }

  p,
  h2,
  h3 {
    orphans: 3;
    widows: 3;
  }

  h2,
  h3 {
    page-break-after: avoid;
  }
}

/*  Grid system and page structure */
/*  Splunk: scaffolding */
/*  =================== */


/*  Default & Structure */
/*  ----------------------------- */

/*  basic color & size */

body {
    margin: 0;
    background: #f3f3f3;
    color: #333;
    min-width: 960px;
    font-family: "Ubuntu", "Roboto", "Droid", "Helvetica Neue", Helvetica, Arial, sans-serif;
    font-size: 12px;
    line-height: 16px;
}


/*  SPL-76040 - turn off roboto for bad windows GDI rendering */
.tr-gdi body {
    font-family: Arial, Helvetica, sans-serif;
}


/*  Links */
/*  ------------------------- */

a {
  color: #0095cf;
  text-decoration: none;
  cursor: pointer;
}

a:hover {
  color: rgb(0, 77, 107);
  text-decoration: underline;
}

a:focus {
  box-shadow: 0 0 0 2px rgba(61, 171, 255, 0.12);
  background-color: rgba(61, 171, 255, 0.12);
  outline: 0;
}


/*  Images */
/*  ------------------------- */

/*  Rounded corners */
.img-rounded {
  border-radius: 6px;
}

/*  Add polaroid-esque trim */
.img-polaroid {
  padding: 4px;
  background-color: #fff;
  border: 1px solid #ccc;
  border: 1px solid rgba(0,0,0,.2);
  box-shadow: 0 1px 3px rgba(0,0,0,.1);
}

/*  Perfect circle */
.img-circle {
  border-radius: 500px; /*  crank the border-radius so it works with most reasonably sized images */
}



/*  Sections */
/*  ================= */

/* add padding to a section

    <div class="section-padded">
        padded content
    </div>

*/
.section-padded {
    padding:20px;
}
/*  section-header extends section-padded */
.section-header {
    padding-top:10px;
    position: relative;
}
.section-header .section-title {
  margin: 0;
  font-size: 24px;
  font-weight: 200;
}


/*  default container */
.main-section-body {
    color:#333;
    min-height: 500px;
}
/*  using three color so we can set color stop even though its only 2 colors */
.main-section-body h2 i[class^="icon-"],
    .main-section-body h2 i[class*=" icon-"]  {
  color: #999;
}
/*  huh? */
.main-section-body .nav-tabs {
  margin-bottom:0;
}
.main-section-body .divider {
  border-top: 1px solid #ccc;
  margin: 0;
}
/*  huh? */
.main-section-body > .pull-right {
  margin-right: 20px;
}
.main-section-body .loading-message {
  padding-top: 100px;
  min-height: 400px;
  text-align: center;
}


/*  Utility Classes */
/*  --------------- */

/* for full width unpadded content
    TODO: this should probably also remove width and margin: auto

    <div class="container container-full-width">
        content here ...
    </div>

*/
.container-full-width {
    padding:0;
}

/* force full width even in padded container

    <div class="container section-padded">
        padded content here ...
        <div class="push-margins">
            expanded content here ...
        </div>
    </div>

*/
.push-margins {
    margin-left:-20px;
    margin-right: -20px;
}

/* new image replacement

    <span class="hide-text">hidden</span>

*/
.hide-text {
    text-indent: 100%;
    white-space: nowrap;
    overflow: hidden;
}

/*  Panels */
/*  ======= */

/* panels for dashboards?

    <div class="panel">
        panel content ...
    </div>
    <div class="panel">
        panel content ...
    </div>
    <div class="panel">
        panel content ...
    </div>
*/

.panel {
    position: relative;
    border: 1px solid #ccc;
    background-color: #fff;
    padding: 20px;
    margin-right:20px;
    border-radius: 0;
    /* box-shadow: 0 1px 1px rgba(0,0,0,0.08); */
}

.panel:last-child {
    margin-right:0;
}

/* panel rows?

    <div class="panel-row">
        <div class="panel">
            panel content ...
        </div>
        <div class="panel">
            panel content ...
        </div>
    </div>
    <div class="panel-row">
        <div class="panel">
            panel content ...
        </div>
        <div class="panel">
            panel content ...
        </div>
    </div>

*/
.panel-row {
    padding: 0 20px;
    margin-bottom:20px
}

/*  Simple Layout Columns */
/*  --------------- */
.section-content {
    background-color: #fff;
    min-height: 400px;
    border-top: 1px solid #ccc;
}

.column {
    position: relative;
    padding: 20px;
    margin-right:20px;
}


/*  Links */
/*  ---------------- */

/* external link style

    <a href="http://example.com/" class="external">external</a>
*/
a.external:after {
  font-family: "Splunk Icons";
  content: "\EC13";
  display: inline-block;
  padding-left: 0.5em;
}


/*  508 accessability */
/*  ----------------- */
.navSkip {
    position: absolute;
    top:0;
    left:-1000px;
}

/*  Paywall */
/*  ------------------- */
.shared-paywall {
    padding-top: 30px;
}

/*  Definition Lists */
/*  ------------- */
.list-dotted {
    line-height: 20px;
    margin-top: 0;

}
.list-dotted dt {
  float: left;
  width: 120px;
  overflow: hidden;
  white-space: nowrap;
  margin-right: 5px;
  font-weight: normal;
  line-height: 20px;
  /*  SPL-69719 - fix IE10 when in dropdown */
  word-wrap: normal;
}
.list-dotted dd {
  line-height: 20px;
  margin-left: 125px;
}
.list-dotted dt:after {
  content: " ............................................";
}

/*  Page Load Placeholder */
/*  ---------------------- */

#placeholder-splunk-bar {
    padding: 0 ;
    background-color: #222;
}

#placeholder-splunk-bar .brand, #placeholder-splunk-bar .brand:hover {
  font-family: "Splunk Icons";
  font-weight: normal;
  color: #fff;
  padding: 0 20px;
  height: 40px;
  font-size: 17px;
  line-height: 40px;
  text-shadow: none;
  text-decoration: none;
  margin-left: 0;
}

#placeholder-splunk-bar .brand strong {
  color: #97999B;
  font-weight: normal;
}

/*  reg symbol */

#placeholder-splunk-bar .brand strong:after {
  content: '\AE';
  color: #97999B;
  font-weight: normal;
}

#placeholder-app-bar {
    color: #fff;
    background-color: rgb(133, 133, 133);
    background-color: rgb(142, 142, 142);
    background-image: linear-gradient(to bottom, rgb(148, 148, 148), rgb(133, 133, 133));
    /*  Standard, IE10 */
    background-repeat: repeat-x;
    height:40px;
}

#placeholder-main-section-body {
    color:#333;
    padding-top: 100px;
    min-height: 400px;
    text-align: center;
}





/*  Lite */
/*  -------------------------------------------------- */
#placeholder-app-bar {
  background: #333;
}
#placeholder-main-section-body {
  color: #333;
}


/*  Lite UI */
/*  -------------------------------------------------- */
body {
  font-family: "Ubuntu", "Roboto", "Droid", "Helvetica Neue", Helvetica, Arial, sans-serif;
}
.section-content {
  border-top-color: #ccc;
}


/*  Print */
/*  -------------------------------------------------- */
@media print {
    body,
    .main-section-body {
        background: none !important;
    }

    @page {
        margin: 1.27cm;
    }
}
/*
/*  Grid system */
/*  -------------------------------------------------- */


/*  Fixed (940px) */
.span1 {
  width: 60px;
  float: left;
  min-height: 1px;
  /*  prevent collapsing columns */
  margin-left: 20px;
}
.span2 {
  width: 140px;
  float: left;
  min-height: 1px;
  /*  prevent collapsing columns */
  margin-left: 20px;
}
.span3 {
  width: 220px;
  float: left;
  min-height: 1px;
  /*  prevent collapsing columns */
  margin-left: 20px;
}
.span4 {
  width: 300px;
  float: left;
  min-height: 1px;
  /*  prevent collapsing columns */
  margin-left: 20px;
}
.span5 {
  width: 380px;
  float: left;
  min-height: 1px;
  /*  prevent collapsing columns */
  margin-left: 20px;
}
.span6 {
  width: 460px;
  float: left;
  min-height: 1px;
  /*  prevent collapsing columns */
  margin-left: 20px;
}
.span7 {
  width: 540px;
  float: left;
  min-height: 1px;
  /*  prevent collapsing columns */
  margin-left: 20px;
}
.span8 {
  width: 620px;
  float: left;
  min-height: 1px;
  /*  prevent collapsing columns */
  margin-left: 20px;
}
.span9 {
  width: 700px;
  float: left;
  min-height: 1px;
  /*  prevent collapsing columns */
  margin-left: 20px;
}
.span10 {
  width: 780px;
  float: left;
  min-height: 1px;
  /*  prevent collapsing columns */
  margin-left: 20px;
}
.span11 {
  width: 860px;
  float: left;
  min-height: 1px;
  /*  prevent collapsing columns */
  margin-left: 20px;
}
.span12 {
  width: 940px;
  float: left;
  min-height: 1px;
  /*  prevent collapsing columns */
  margin-left: 20px;
}
.offset1 {
  margin-left: 980px;
}
.offset2 {
  margin-left: 980px;
}
.offset3 {
  margin-left: 980px;
}
.offset4 {
  margin-left: 980px;
}
.offset5 {
  margin-left: 980px;
}
.offset6 {
  margin-left: 980px;
}
.offset7 {
  margin-left: 980px;
}
.offset8 {
  margin-left: 980px;
}
.offset9 {
  margin-left: 980px;
}
.offset10 {
  margin-left: 980px;
}
.offset11 {
  margin-left: 980px;
}
.offset12 {
  margin-left: 980px;
}
.row {
  margin-left: -20px;
}
.row:before,
    .row:after {
  display: table;
  content: "";
  /*  Fixes Opera/contenteditable bug: */
  /*  http://nicolasgallagher.com/micro-clearfix-hack/#comment-36952 */
  line-height: 0;
}
.row:after {
  clear: both;
}
/*  Set the container width, and override it for fixed navbars in media queries */
.container,
    .navbar-static-top .container,
    .navbar-fixed-top .container,
    .navbar-fixed-bottom .container {
  width: 940px;
}

/*  Fluid (940px) */
.row-fluid {
  width: 100%;
}
.row-fluid:before,
    .row-fluid:after {
  display: table;
  content: "";
  /*  Fixes Opera/contenteditable bug: */
  /*  http://nicolasgallagher.com/micro-clearfix-hack/#comment-36952 */
  line-height: 0;
}
.row-fluid:after {
  clear: both;
}
.row-fluid .span1 {
  display: block;
  width: 100%;
  min-height: 26px;
  /*  Make inputs at least the height of their button counterpart (base line-height + padding + border) */
  box-sizing: border-box;
  /*  Makes inputs behave like true block-level elements */
  width: 6.38298%;
  float: left;
  margin-left: 2.127659574%;
}
.row-fluid .span1:first-child {
  margin-left: 0;
}
.row-fluid .span2 {
  display: block;
  width: 100%;
  min-height: 26px;
  /*  Make inputs at least the height of their button counterpart (base line-height + padding + border) */
  box-sizing: border-box;
  /*  Makes inputs behave like true block-level elements */
  width: 14.89362%;
  float: left;
  margin-left: 2.127659574%;
}
.row-fluid .span2:first-child {
  margin-left: 0;
}
.row-fluid .span3 {
  display: block;
  width: 100%;
  min-height: 26px;
  /*  Make inputs at least the height of their button counterpart (base line-height + padding + border) */
  box-sizing: border-box;
  /*  Makes inputs behave like true block-level elements */
  width: 23.40426%;
  float: left;
  margin-left: 2.127659574%;
}
.row-fluid .span3:first-child {
  margin-left: 0;
}
.row-fluid .span4 {
  display: block;
  width: 100%;
  min-height: 26px;
  /*  Make inputs at least the height of their button counterpart (base line-height + padding + border) */
  box-sizing: border-box;
  /*  Makes inputs behave like true block-level elements */
  width: 31.91489%;
  float: left;
  margin-left: 2.127659574%;
}
.row-fluid .span4:first-child {
  margin-left: 0;
}
.row-fluid .span5 {
  display: block;
  width: 100%;
  min-height: 26px;
  /*  Make inputs at least the height of their button counterpart (base line-height + padding + border) */
  box-sizing: border-box;
  /*  Makes inputs behave like true block-level elements */
  width: 40.42553%;
  float: left;
  margin-left: 2.127659574%;
}
.row-fluid .span5:first-child {
  margin-left: 0;
}
.row-fluid .span6 {
  display: block;
  width: 100%;
  min-height: 26px;
  /*  Make inputs at least the height of their button counterpart (base line-height + padding + border) */
  box-sizing: border-box;
  /*  Makes inputs behave like true block-level elements */
  width: 48.93617%;
  float: left;
  margin-left: 2.127659574%;
}
.row-fluid .span6:first-child {
  margin-left: 0;
}
.row-fluid .span7 {
  display: block;
  width: 100%;
  min-height: 26px;
  /*  Make inputs at least the height of their button counterpart (base line-height + padding + border) */
  box-sizing: border-box;
  /*  Makes inputs behave like true block-level elements */
  width: 57.44681%;
  float: left;
  margin-left: 2.127659574%;
}
.row-fluid .span7:first-child {
  margin-left: 0;
}
.row-fluid .span8 {
  display: block;
  width: 100%;
  min-height: 26px;
  /*  Make inputs at least the height of their button counterpart (base line-height + padding + border) */
  box-sizing: border-box;
  /*  Makes inputs behave like true block-level elements */
  width: 65.95745%;
  float: left;
  margin-left: 2.127659574%;
}
.row-fluid .span8:first-child {
  margin-left: 0;
}
.row-fluid .span9 {
  display: block;
  width: 100%;
  min-height: 26px;
  /*  Make inputs at least the height of their button counterpart (base line-height + padding + border) */
  box-sizing: border-box;
  /*  Makes inputs behave like true block-level elements */
  width: 74.46809%;
  float: left;
  margin-left: 2.127659574%;
}
.row-fluid .span9:first-child {
  margin-left: 0;
}
.row-fluid .span10 {
  display: block;
  width: 100%;
  min-height: 26px;
  /*  Make inputs at least the height of their button counterpart (base line-height + padding + border) */
  box-sizing: border-box;
  /*  Makes inputs behave like true block-level elements */
  width: 82.97873%;
  float: left;
  margin-left: 2.127659574%;
}
.row-fluid .span10:first-child {
  margin-left: 0;
}
.row-fluid .span11 {
  display: block;
  width: 100%;
  min-height: 26px;
  /*  Make inputs at least the height of their button counterpart (base line-height + padding + border) */
  box-sizing: border-box;
  /*  Makes inputs behave like true block-level elements */
  width: 91.48937%;
  float: left;
  margin-left: 2.127659574%;
}
.row-fluid .span11:first-child {
  margin-left: 0;
}
.row-fluid .span12 {
  display: block;
  width: 100%;
  min-height: 26px;
  /*  Make inputs at least the height of their button counterpart (base line-height + padding + border) */
  box-sizing: border-box;
  /*  Makes inputs behave like true block-level elements */
  width: 100%;
  float: left;
  margin-left: 2.127659574%;
}
.row-fluid .span12:first-child {
  margin-left: 0;
}
.row-fluid .offset1 {
  margin-left: 10.6383%;
}
.row-fluid .offset2 {
  margin-left: 19.14894%;
}
.row-fluid .offset3 {
  margin-left: 27.65958%;
}
.row-fluid .offset4 {
  margin-left: 36.17021%;
}
.row-fluid .offset5 {
  margin-left: 44.68085%;
}
.row-fluid .offset6 {
  margin-left: 53.19149%;
}
.row-fluid .offset7 {
  margin-left: 61.70213%;
}
.row-fluid .offset8 {
  margin-left: 70.21277%;
}
.row-fluid .offset9 {
  margin-left: 78.72341%;
}
.row-fluid .offset10 {
  margin-left: 87.23405%;
}
.row-fluid .offset11 {
  margin-left: 95.74469%;
}
.row-fluid .offset12 {
  margin-left: 104.25532%;
}
/*  Space grid-sized controls properly if multiple per line */
.row-fluid .controls-row [class*="span"] + [class*="span"] {
  margin-left: 2.127659574%;
}

/*  Reset utility classes due to specificity */
[class*="span"].hide,
.row-fluid [class*="span"].hide {
  display: none;
}

[class*="span"].pull-right,
.row-fluid [class*="span"].pull-right {
  float: right;
}
/*  Layouts */
/*  -------------------------------------------------- */


/*  Container (centered, fixed-width layouts) */
.container {
  margin-right: auto;
  margin-left: auto;
}
.container:before,
    .container:after {
  display: table;
  content: "";
  /*  Fixes Opera/contenteditable bug: */
  /*  http://nicolasgallagher.com/micro-clearfix-hack/#comment-36952 */
  line-height: 0;
}
.container:after {
  clear: both;
}

/*  Fluid layouts (left aligned, with sidebar, min- & max-width content) */
.container-fluid {
  padding-right: 20px;
  padding-left: 20px;
}
.container-fluid:before,
    .container-fluid:after {
  display: table;
  content: "";
  /*  Fixes Opera/contenteditable bug: */
  /*  http://nicolasgallagher.com/micro-clearfix-hack/#comment-36952 */
  line-height: 0;
}
.container-fluid:after {
  clear: both;
}

/*  Base CSS */
/*  Splunk: Typography */
/*  =================== */
/*  Headings, body text, lists, code, and more for a versatile and durable typography system */


/*  Fonts */
/*  ----------- */

/*  Monospace */
@font-face {
	font-family: 'Droid Sans Mono';
	src: url('/static/fonts/droid-sans-mono-webfont.woff') format('woff');
	font-weight: 400;
	font-style: normal;
}

/*  Ubuntu */

@font-face {
  font-family: 'Ubuntu';
  font-style: normal;
  font-weight: 400;
  src: url('/static/fonts/ubuntu-regular.ttf') format('truetype');
}

@font-face {
  font-family: 'Ubuntu';
  font-style: normal;
  font-weight: 300;
  src: url('/static/fonts/ubuntu-light.ttf') format('truetype');
}

@font-face {
  font-family: 'Ubuntu';
  font-style: normal;
  font-weight: 700;
  src: url('/static/fonts/ubuntu-medium.ttf') format('truetype');
}
@font-face {
  font-family: 'Architects Daughter';
  font-style: normal;
  font-weight: normal;
  src: url('/static/fonts/ArchitectsDaughter.ttf') format('truetype');
}



/*  Body text */
/*  ------------------------- */

p {
  margin: 0 0 8px;
}
.lead {
  margin-bottom: 16px;
  font-size: 18px;
  font-weight: 200;
  line-height: 24px;
}


/*  Emphasis & misc */
/*  ------------------------- */

/*  Ex: 14px base font * 85% = about 12px */
small   { font-size: 85%; }

strong  { font-weight: bold; }
em      { font-style: italic; }
cite    { font-style: normal; }

/*  Utility classes */
.muted               { color: #999; }
a.muted:hover,
a.muted:focus        { color: rgb(128, 128, 128); }

.text-warning        { color: rgb(217, 159, 13); }
a.text-warning:hover,
a.text-warning:focus { color: rgb(169, 124, 10); }

.text-error          { color: #d6563c; }
a.text-error:hover,
a.text-error:focus   { color: rgb(185, 64, 39); }

.text-info           { color: #3a87ad; }
a.text-info:hover,
a.text-info:focus    { color: rgb(45, 104, 134); }

.text-success        { color: #a2cc3e; }
a.text-success:hover,
a.text-success:focus { color: rgb(132, 169, 45); }

.text-left           { text-align: left; }
.text-right          { text-align: right; }
.text-center         { text-align: center; }



/*  Font Families */
/*  ------------- */

/* monospace for code and raw


	<p>normal</p>
	<p class="mono-space">mono space</p>

*/
.mono-space {
	font-family: 'Droid Sans Mono', 'Consolas', 'Monaco', 'Courier New', Courier, monospace;
}


/*  Headings */
/*  ------------------------- */

h1, h2, h3, h4, h5, h6 {
  margin: 8px 0;
  font-family: inherit;
  font-weight: bold;
  line-height: 16px;
  color: inherit;
  text-rendering: optimizelegibility;
}

/*  Fix the character spacing for headings */

h1 small, h2 small, h3 small, h4 small, h5 small, h6 small {
  font-weight: normal;
  line-height: 1;
  color: #999;
}

h1{ line-height: 32px; }
h2, h3 {line-height:normal;}

h1 { font-size: 33px; } /*  ~38px */
h2 { font-size: 27px; } /*  ~32px */
h3 {
    font-size: 16px;
    font-weight: normal;
}
h4 { font-size: 15px; } /*  ~18px */
h5 {
	font-size: 12px;
	color: #333;
	font-weight: bold;
	margin: 0;
}
h6 { font-size: 10.2px; } /*  ~12px */

h1 small { font-size: 21px; } /*  ~24px */
h2 small { font-size: 15px; } /*  ~18px */
h3 small { font-size: 12px; }
h4 small { font-size: 12px; }




/*  Page header */
/*  ------------------------- */

.page-header {
  padding-bottom: 7px;
  margin: 16px 0 24px;
  border-bottom: 1px solid #eee;
}



/*  Lists */
/*  -------------------------------------------------- */

/*  Unordered and Ordered lists */
ul, ol {
  padding: 0;
  margin: 0 0 8px 25px;
}
ul ul,
ul ol,
ol ol,
ol ul {
  margin-bottom: 0;
}
li {
  line-height: 16px;
}

/*  Remove default list styles */
ul.unstyled,
ol.unstyled {
  margin-left: 0;
  list-style: none;
}

/*  Single-line list items */
ul.inline,
ol.inline {
  margin-left: 0;
  list-style: none;
}
ul.inline > li, ol.inline > li {
  display: inline-block;
  padding-left: 5px;
  padding-right: 5px;
}

/*  Description Lists */
dl {
  margin-bottom: 16px;
}
dt,
dd {
  line-height: 16px;
}
dt {
  font-weight: bold;
}
dd {
  margin-left: 8px;
}
/*  Horizontal layout (like forms) */
.dl-horizontal:before,
    .dl-horizontal:after {
  display: table;
  content: "";
  /*  Fixes Opera/contenteditable bug: */
  /*  http://nicolasgallagher.com/micro-clearfix-hack/#comment-36952 */
  line-height: 0;
}
.dl-horizontal:after {
  clear: both;
}
/*  Ensure dl clears floats if empty dd elements present */
.dl-horizontal dt {
  float: left;
  width: 160px;
  clear: left;
  text-align: right;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.dl-horizontal dd {
  margin-left: 180px;
}

/*  MISC */
/*  ---- */

/*  Horizontal rules */
hr {
  margin: 16px 0;
  border: 0;
  border-top: 1px solid #eee;
  border-bottom: 1px solid #fff;
}

/*  Abbreviations and acronyms */
abbr[title],
/*  Added data-* attribute to help out our tooltip plugin, per https://github.com/twitter/bootstrap/issues/5257 */
abbr[data-original-title] {
  cursor: help;
  border-bottom: 1px dotted #999;
}
abbr.initialism {
  font-size: 90%;
  text-transform: uppercase;
}

/*  Blockquotes */
blockquote {
  padding: 0 0 0 15px;
  margin: 0 0 16px;
  border-left: 5px solid #eee;
}
blockquote p {
  margin-bottom: 0;
  font-size: 15px;
  font-weight: 300;
  line-height: 1.25;
}
blockquote small {
  display: block;
  line-height: 16px;
  color: #999;
}
blockquote small:before {
  content: '\2014   \A0';
}
/*  Float right with text-align: right */
blockquote.pull-right {
  float: right;
  padding-right: 15px;
  padding-left: 0;
  border-right: 5px solid #eee;
  border-left: 0;
}
blockquote.pull-right p,
    blockquote.pull-right small {
  text-align: right;
}
blockquote.pull-right small:before {
  content: '';
}
blockquote.pull-right small:after {
  content: '\A0   \2014';
}

/*  Quotes */
q:before,
q:after,
blockquote:before,
blockquote:after {
  content: "";
}

/*  Addresses */
address {
  display: block;
  margin-bottom: 16px;
  font-style: normal;
  line-height: 16px;
}
/*  Code (inline and blocK) */
/*  -------------------------------------------------- */


/*  Inline and block code styles */
code,
pre {
  padding: 0 3px 2px;
  font-family: 'Droid Sans Mono', 'Consolas', 'Monaco', 'Courier New', Courier, monospace;
  font-size: 10px;
  color: #333;
  border-radius: 3px;
}

/*  Inline code */
code {
  padding: 2px 4px;
  color: #d14;
  background-color: #f7f7f9;
  border: 1px solid #e1e1e8;
  white-space: nowrap;
}

/*  Blocks of code */
pre {
  display: block;
  padding: 7.5px;
  margin: 0 0 8px;
  font-size: 11px; /*  14px to 13px */
  line-height: 16px;
  word-break: break-all;
  word-wrap: break-word;
  white-space: pre;
  white-space: pre-wrap;
  background-color: #f5f5f5;
  border: 1px solid rgba(0,0,0,.15);
  border-radius: 2px;
}
/*  Make prettyprint styles more spaced out for readability */
pre.prettyprint {
  margin-bottom: 16px;
}
/*  Account for some code outputs that place code tags in pre tags */
pre code {
  padding: 0;
  color: inherit;
  white-space: pre;
  white-space: pre-wrap;
  background-color: transparent;
  border: 0;
}

/*  Enable scrollable blocks of code */
.pre-scrollable {
  max-height: 340px;
  overflow-y: scroll;
}
/*  Splunk: Forms */
/*  ============= */
/*  Base styles for various input types, form layouts, and states */



/*  GENERAL STYLES */
/*  -------------- */

/*  Make all forms have space below them */
form {
  margin: 0 0 16px;
}
form:last-child {
  margin: 0 0 16px;
}

fieldset {
  padding: 0;
  margin: 0;
  border: 0;
}

/*  Groups of fields with labels on top (legends) */
legend {
  display: block;
  width: 100%;
  padding: 0;
  margin-bottom: 16px;
  font-size: 18px;
  line-height: 32px;
  color: #333;
  border: 0;
  border-bottom: 1px solid #e5e5e5;
}
/*  Small */
legend small {
  font-size: 12px;
  color: #999;
}

/*  Set font for forms */
label,
input,
button,
select,
textarea {
  font-size: 12px;
  font-weight: normal;
  line-height: 16px; /*  Set size, weight, line-height here */
}
input,
button,
select,
textarea {
  font-family: "Ubuntu", "Roboto", "Droid", "Helvetica Neue", Helvetica, Arial, sans-serif; /*  And only set font-family here for those that need it (note the missing label element) */
}

/*  Identify controls by their labels */
label {
  display: block;
  margin-bottom: 5px;
  cursor: default; /* reset pointer */
}


/*  Form controls */
/*  ------------------------- */

/*  Shared size and type resets */
select,
textarea,
input[type="text"],
input[type="password"],
input[type="datetime"],
input[type="datetime-local"],
input[type="date"],
input[type="month"],
input[type="time"],
input[type="week"],
input[type="number"],
input[type="email"],
input[type="url"],
input[type="search"],
input[type="tel"],
input[type="color"],
.uneditable-input {
  display: inline-block;
  height: 16px;
  padding: 4px 6px;
  margin-bottom: 8px;
  font-size: 12px;
  line-height: 16px;
  color: #555;
  border-radius: 2px;
  vertical-align: middle;
}

/*  Reset appearance properties for textual inputs and textarea */
/*  Declare width for legacy (can't be on input[type=*] selectors or it's too specific) */
input,
textarea,
.uneditable-input {
  width: 206px; /*  plus 12px padding and 2px border */
}
/*  Reset height since textareas have rows */
textarea {
  height: auto;
}
/*  Everything else */
textarea,
input[type="text"],
input[type="password"],
input[type="datetime"],
input[type="datetime-local"],
input[type="date"],
input[type="month"],
input[type="time"],
input[type="week"],
input[type="number"],
input[type="email"],
input[type="url"],
input[type="search"],
input[type="tel"],
input[type="color"],
.uneditable-input {
  background-color: #fff;
  border: 1px solid #ccc;
  box-shadow: inset 0 1px 1px rgba(0,0,0,.075);
  transition: border linear .2s, box-shadow linear .2s;
}
/*  Focus state */
textarea:focus, input[type="text"]:focus, input[type="password"]:focus, input[type="datetime"]:focus, input[type="datetime-local"]:focus, input[type="date"]:focus, input[type="month"]:focus, input[type="time"]:focus, input[type="week"]:focus, input[type="number"]:focus, input[type="email"]:focus, input[type="url"]:focus, input[type="search"]:focus, input[type="tel"]:focus, input[type="color"]:focus, .uneditable-input:focus {
  border-color: rgba(82, 168, 236, 0.8);
  outline: 0;
}
/* Don't show IE clear button when an artificial one is shown. */
textarea.text-clear::-ms-clear, input[type="text"].text-clear::-ms-clear, input[type="password"].text-clear::-ms-clear, input[type="datetime"].text-clear::-ms-clear, input[type="datetime-local"].text-clear::-ms-clear, input[type="date"].text-clear::-ms-clear, input[type="month"].text-clear::-ms-clear, input[type="time"].text-clear::-ms-clear, input[type="week"].text-clear::-ms-clear, input[type="number"].text-clear::-ms-clear, input[type="email"].text-clear::-ms-clear, input[type="url"].text-clear::-ms-clear, input[type="search"].text-clear::-ms-clear, input[type="tel"].text-clear::-ms-clear, input[type="color"].text-clear::-ms-clear, .uneditable-input.text-clear::-ms-clear {
  display: none;
  width: 0;
  /* IE 11 on windows 8 */
  height: 0;
  /* IE 11 on windows 8 */
}



/*  Position radios and checkboxes better */
input[type="radio"],
input[type="checkbox"] {
  margin: 4px 0 0;
  margin-top: 1px \9; /* IE9 */
  line-height: normal;
}

/*  Reset width of input images, buttons, radios, checkboxes */
input[type="file"],
input[type="image"],
input[type="submit"],
input[type="reset"],
input[type="button"],
input[type="radio"],
input[type="checkbox"] {
  width: auto; /*  Override of generic input selector */
}

/*  Set the height of select and file controls to match text inputs */
select,
input[type="file"] {
  height: 26px;
  line-height: 26px;
}

/*  Make select elements obey height by applying a border */
select {
  width: 220px; /*  default input width + 10px of padding that doesn't get applied */
  border: 1px solid #ccc;
  background-color: #fff; /*  Chrome on Linux and Mobile Safari need background-color */
}

/*  Make multiple select elements height not fixed */
select[multiple],
select[size] {
  height: auto;
}

/*  Focus for select, file, radio, and checkbox */
select:focus,
input[type="file"]:focus,
input[type="radio"]:focus,
input[type="checkbox"]:focus {
  /*  Default */
  outline: thin dotted #333;
  /*  Webkit */
  outline: 3px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}


/*  Uneditable inputs */
/*  ------------------------- */

/*  Make uneditable inputs look inactive */
.uneditable-input,
.uneditable-textarea {
  color: #999;
  background-color: rgb(252, 252, 252);
  border-color: #ccc;
  box-shadow: inset 0 1px 2px rgba(0,0,0,.025);
  cursor: not-allowed;
}

/*  For text that needs to appear as an input but should not be an input */
.uneditable-input {
  overflow: hidden; /*  prevent text from wrapping, but still cut it off like an input does */
  white-space: nowrap;
}

/*  Make uneditable textareas behave like a textarea */
.uneditable-textarea {
  width: auto;
  height: auto;
}


/*  restrict text area resize */
textarea {
	min-height: 2em;
	resize: vertical;
}


/*  Placeholder */
/*  ------------------------- */

/*  Placeholder text gets special styles because when browsers invalidate entire lines if it doesn't understand a selector */
input::-webkit-input-placeholder, textarea::-webkit-input-placeholder {
  color: #999;
}
input::-moz-placeholder, textarea::-moz-placeholder {
  color: #999;
}
input:-ms-input-placeholder, textarea:-ms-input-placeholder {
  color: #999;
}
input::placeholder, textarea::placeholder {
  color: #999;
}



/*  CHECKBOXES & RADIOS */
/*  ------------------- */

/*  Indent the labels to position radios/checkboxes as hanging */
.radio,
.checkbox {
  min-height: 16px; /*  clear the floating input if there is no label text */
  padding-left: 20px;
}
.radio input[type="radio"],
.checkbox input[type="checkbox"] {
  float: left;
  margin-left: -20px;
}

/*  Move the options list down to align with labels */
.controls > .radio:first-child,
.controls > .checkbox:first-child {
  padding-top: 5px; /*  has to be padding because margin collaspes */
}

/*  Radios and checkboxes on same line */
/*  TODO v3: Convert .inline to .control-inline */
.radio.inline,
.checkbox.inline {
  display: inline-block;
  padding-top: 5px;
  margin-bottom: 0;
  vertical-align: middle;
}
.radio.inline + .radio.inline,
.checkbox.inline + .checkbox.inline {
  margin-left: 10px; /*  space out consecutive inline controls */
}


/*  INPUT SIZES */
/*  ----------- */

/*  General classes for quick sizes */
.input-very-small {	width: 25px; }
.input-mini       { width: 60px; }
.input-small      { width: 90px; }
.input-medium     { width: 150px; }
.input-large      { width: 210px; }
.input-xlarge     { width: 270px; }
.input-xxlarge    { width: 530px; }

/*  Grid style input sizes */
input[class*="span"],
select[class*="span"],
textarea[class*="span"],
.uneditable-input[class*="span"],
/*  Redeclare since the fluid row class is more specific */
.row-fluid input[class*="span"],
.row-fluid select[class*="span"],
.row-fluid textarea[class*="span"],
.row-fluid .uneditable-input[class*="span"] {
  float: none;
  margin-left: 0;
}
/*  Ensure input-prepend/append never wraps */
.input-append input[class*="span"],
.input-append .uneditable-input[class*="span"],
.input-prepend input[class*="span"],
.input-prepend .uneditable-input[class*="span"],
.row-fluid input[class*="span"],
.row-fluid select[class*="span"],
.row-fluid textarea[class*="span"],
.row-fluid .uneditable-input[class*="span"],
.row-fluid .input-prepend [class*="span"],
.row-fluid .input-append [class*="span"] {
  display: inline-block;
}





/*  GRID SIZING FOR INPUTS */
/*  ---------------------- */

/*  Grid sizes */
.span1 {
  width: 46px;
}
.span2 {
  width: 126px;
}
.span3 {
  width: 206px;
}
.span4 {
  width: 286px;
}
.span5 {
  width: 366px;
}
.span6 {
  width: 446px;
}
.span7 {
  width: 526px;
}
.span8 {
  width: 606px;
}
.span9 {
  width: 686px;
}
.span10 {
  width: 766px;
}
.span11 {
  width: 846px;
}
.span12 {
  width: 926px;
}
input,
    textarea,
    .uneditable-input {
  margin-left: 0;
  /*  override margin-left from core grid system */
}
/*  Space grid-sized controls properly if multiple per line */
.controls-row [class*="span"] + [class*="span"] {
  margin-left: 20px;
}

/*  Control row for multiple inputs per line */
.controls-row { /*  Clear the float from controls */
}
.controls-row:before,
    .controls-row:after {
  display: table;
  content: "";
  /*  Fixes Opera/contenteditable bug: */
  /*  http://nicolasgallagher.com/micro-clearfix-hack/#comment-36952 */
  line-height: 0;
}
.controls-row:after {
  clear: both;
}

/*  Float to collapse white-space for proper grid alignment */
.controls-row [class*="span"],
/*  Redeclare the fluid grid collapse since we undo the float for inputs */
.row-fluid .controls-row [class*="span"] {
  float: left;
}
/*  Explicity set top padding on all checkboxes/radios, not just first-child */
.controls-row .checkbox[class*="span"],
.controls-row .radio[class*="span"] {
  padding-top: 5px;
}




/*  DISABLED STATE */
/*  -------------- */

/*  Disabled and read-only inputs */
input[disabled],
select[disabled],
textarea[disabled],
input[readonly],
select[readonly],
textarea[readonly] {
  cursor: not-allowed;
  background-color: #eee;
}
/*  Explicitly reset the colors here */
input[type="radio"][disabled],
input[type="checkbox"][disabled],
input[type="radio"][readonly],
input[type="checkbox"][readonly] {
  background-color: transparent;
}






/*  FORM FIELD FEEDBACK STATES */
/*  -------------------------- */

/*  Warning */
/*  Set the text color */
.control-group.warning .control-label,
  .control-group.warning .help-block,
  .control-group.warning .help-inline {
  color: rgb(217, 159, 13);
}
/*  Style inputs accordingly */
.control-group.warning .checkbox,
  .control-group.warning .radio,
  .control-group.warning input,
  .control-group.warning select,
  .control-group.warning textarea {
  color: rgb(217, 159, 13);
}
.control-group.warning input,
  .control-group.warning select,
  .control-group.warning textarea {
  border-color: rgb(217, 159, 13);
  box-shadow: inset 0 1px 1px rgba(0,0,0,.075);
}
/*  Redeclare so transitions work */
.control-group.warning input:focus, .control-group.warning select:focus, .control-group.warning textarea:focus {
  border-color: rgb(169, 124, 10);
  box-shadow: inset 0 1px 1px rgba(0,0,0,.075), 0 0 6px rgb(245, 200, 86);
}
/*  Give a small background color for input-prepend/-append */
.control-group.warning .input-prepend .add-on,
  .control-group.warning .input-append .add-on {
  color: rgb(217, 159, 13);
  background-color: rgb(253, 244, 221);
  border-color: rgb(217, 159, 13);
}
/*  Error */
/*  Set the text color */
.control-group.error .control-label,
  .control-group.error .help-block,
  .control-group.error .help-inline {
  color: #d6563c;
}
/*  Style inputs accordingly */
.control-group.error .checkbox,
  .control-group.error .radio,
  .control-group.error input,
  .control-group.error select,
  .control-group.error textarea {
  color: #d6563c;
}
.control-group.error input,
  .control-group.error select,
  .control-group.error textarea {
  border-color: #d6563c;
  box-shadow: inset 0 1px 1px rgba(0,0,0,.075);
}
/*  Redeclare so transitions work */
.control-group.error input:focus, .control-group.error select:focus, .control-group.error textarea:focus {
  border-color: rgb(185, 64, 39);
  box-shadow: inset 0 1px 1px rgba(0,0,0,.075), 0 0 6px rgb(232, 160, 146);
}
/*  Give a small background color for input-prepend/-append */
.control-group.error .input-prepend .add-on,
  .control-group.error .input-append .add-on {
  color: #d6563c;
  background-color: rgb(250, 233, 230);
  border-color: #d6563c;
}
/*  Success */
/*  Set the text color */
.control-group.success .control-label,
  .control-group.success .help-block,
  .control-group.success .help-inline {
  color: #a2cc3e;
}
/*  Style inputs accordingly */
.control-group.success .checkbox,
  .control-group.success .radio,
  .control-group.success input,
  .control-group.success select,
  .control-group.success textarea {
  color: #a2cc3e;
}
.control-group.success input,
  .control-group.success select,
  .control-group.success textarea {
  border-color: #a2cc3e;
  box-shadow: inset 0 1px 1px rgba(0,0,0,.075);
}
/*  Redeclare so transitions work */
.control-group.success input:focus, .control-group.success select:focus, .control-group.success textarea:focus {
  border-color: rgb(132, 169, 45);
  box-shadow: inset 0 1px 1px rgba(0,0,0,.075), 0 0 6px rgb(200, 225, 142);
}
/*  Give a small background color for input-prepend/-append */
.control-group.success .input-prepend .add-on,
  .control-group.success .input-append .add-on {
  color: #a2cc3e;
  background-color: rgb(239, 246, 223);
  border-color: #a2cc3e;
}
/*  Success */
/*  Set the text color */
.control-group.info .control-label,
  .control-group.info .help-block,
  .control-group.info .help-inline {
  color: #3a87ad;
}
/*  Style inputs accordingly */
.control-group.info .checkbox,
  .control-group.info .radio,
  .control-group.info input,
  .control-group.info select,
  .control-group.info textarea {
  color: #3a87ad;
}
.control-group.info input,
  .control-group.info select,
  .control-group.info textarea {
  border-color: #3a87ad;
  box-shadow: inset 0 1px 1px rgba(0,0,0,.075);
}
/*  Redeclare so transitions work */
.control-group.info input:focus, .control-group.info select:focus, .control-group.info textarea:focus {
  border-color: rgb(45, 104, 134);
  box-shadow: inset 0 1px 1px rgba(0,0,0,.075), 0 0 6px rgb(121, 181, 210);
}
/*  Give a small background color for input-prepend/-append */
.control-group.info .input-prepend .add-on,
  .control-group.info .input-append .add-on {
  color: #3a87ad;
  background-color: #d9edf7;
  border-color: #3a87ad;
}

/*  HTML5 invalid states */
/*  Shares styles with the .control-group.error above */
input:focus:invalid,
textarea:focus:invalid,
select:focus:invalid {
  color: #b94a48;
  border-color: #ee5f5b;
}
input:focus:invalid:focus, textarea:focus:invalid:focus, select:focus:invalid:focus {
  border-color: rgb(233, 53, 47);
  box-shadow: 0 0 6px rgb(248, 188, 186);
}



/*  FORM ACTIONS */
/*  ------------ */

.form-actions {
  padding: 15px 20px 16px;
  margin-top: 16px;
  margin-bottom: 16px;
  background-color: #f3f3f3;
  border-top: 1px solid #e5e5e5; /*  Adding clearfix to allow for .pull-right button containers */
}

.form-actions:before,
    .form-actions:after {
  display: table;
  content: "";
  /*  Fixes Opera/contenteditable bug: */
  /*  http://nicolasgallagher.com/micro-clearfix-hack/#comment-36952 */
  line-height: 0;
}

.form-actions:after {
  clear: both;
}



/*  HELP TEXT */
/*  --------- */

.help-block,
.help-inline {
    color: #999;
}

.help-block {
  display: block; /*  account for any element using help-block */
  margin-bottom: 8px;
  font-size: 85%;
  word-wrap: break-word;
}

.help-inline {
  display: inline-block;
  vertical-align: middle;
  padding-left: 5px;
}



/*  INPUT GROUPS */
/*  ------------ */

/*  Allow us to put symbols and text within the input field for a cleaner look */
.input-append,
.input-prepend {
  display: inline-block;
  margin-bottom: 8px;
  vertical-align: middle;
  font-size: 0; /*  white space collapse hack */
  white-space: nowrap;
}
/*  Reset the white space collapse hack */
.input-append input,
  .input-append select,
  .input-append .uneditable-input,
  .input-append .dropdown-menu,
  .input-append .popover,
  .input-prepend input,
  .input-prepend select,
  .input-prepend .uneditable-input,
  .input-prepend .dropdown-menu,
  .input-prepend .popover {
  font-size: 12px;
}
/*  Prevent span and input from separating */
.input-append input,
  .input-append select,
  .input-append .uneditable-input,
  .input-prepend input,
  .input-prepend select,
  .input-prepend .uneditable-input {
  position: relative;
  /*  placed here by default so that on :focus we can place the input above the .add-on for full border and box-shadow goodness */
  margin-bottom: 0;
  /*  prevent bottom margin from screwing up alignment in stacked forms */
  vertical-align: top;
  border-radius: 0 2px 2px 0;
}
/*  Make input on top when focused so blue border and shadow always show */
.input-append input:focus, .input-append select:focus, .input-append .uneditable-input:focus, .input-prepend input:focus, .input-prepend select:focus, .input-prepend .uneditable-input:focus {
  z-index: 2;
}
.input-append .add-on, .input-prepend .add-on {
  display: inline-block;
  width: auto;
  height: 16px;
  min-width: 16px;
  padding: 4px 5px;
  font-size: 12px;
  font-weight: normal;
  line-height: 16px;
  text-align: center;
  text-shadow: 0 1px 0 #fff;
  background-color: #eee;
  border: 1px solid #ccc;
}
.input-append .add-on,
  .input-append .btn,
  .input-append .btn-group > .dropdown-toggle,
  .input-prepend .add-on,
  .input-prepend .btn,
  .input-prepend .btn-group > .dropdown-toggle {
  vertical-align: top;
  border-radius: 0;
}
.input-append .active, .input-prepend .active {
  background-color: rgb(220, 236, 182);
  border-color: #a2cc3e;
}

.input-prepend .add-on,
  .input-prepend .btn {
  margin-right: -1px;
}

.input-prepend .add-on:first-child,
  .input-prepend .btn:first-child {
  /*  FYI, `.btn:first-child` accounts for a button group that's prepended */
  border-radius: 2px 0 0 2px;
}

.input-append input,
  .input-append select,
  .input-append .uneditable-input {
  border-radius: 2px 0 0 2px;
}

.input-append input + .btn-group .btn:last-child, .input-append select + .btn-group .btn:last-child, .input-append .uneditable-input + .btn-group .btn:last-child {
  border-radius: 0 2px 2px 0;
}

.input-append .add-on,
  .input-append .btn,
  .input-append .btn-group {
  margin-left: -1px;
}

.input-append .add-on:last-child,
  .input-append .btn:last-child,
  .input-append .btn-group:last-child > .dropdown-toggle {
  border-radius: 0 2px 2px 0;
}

/*  Remove all border-radius for inputs with both prepend and append */
.input-prepend.input-append input,
  .input-prepend.input-append select,
  .input-prepend.input-append .uneditable-input {
  border-radius: 0;
}
.input-prepend.input-append input + .btn-group .btn, .input-prepend.input-append select + .btn-group .btn, .input-prepend.input-append .uneditable-input + .btn-group .btn {
  border-radius: 0 2px 2px 0;
}
.input-prepend.input-append .add-on:first-child,
  .input-prepend.input-append .btn:first-child {
  margin-right: -1px;
  border-radius: 2px 0 0 2px;
}
.input-prepend.input-append .add-on:last-child,
  .input-prepend.input-append .btn:last-child {
  margin-left: -1px;
  border-radius: 0 2px 2px 0;
}
.input-prepend.input-append .btn-group:first-child {
  margin-left: 0;
}




/*  SEARCH FORM */
/*  ----------- */

input.search-query {
  padding-right: 14px;
  padding-right: 4px \9;
  padding-left: 14px;
  margin-bottom: 0; /*  Remove the default margin on all inputs */
  border-radius: 15px;
}

/* Allow for input prepend/append in search forms */
.form-search .input-append .search-query,
.form-search .input-prepend .search-query {
  border-radius: 0; /*  Override due to specificity */
}
.form-search .input-append .search-query {
  border-radius: 14px 0 0 14px;
}
.form-search .input-append .btn {
  border-radius: 0 14px 14px 0;
}
.form-search .input-prepend .search-query {
  border-radius: 0 14px 14px 0;
}
.form-search .input-prepend .btn {
  border-radius: 14px 0 0 14px;
}




/*  HORIZONTAL & VERTICAL FORMS */
/*  --------------------------- */

/*  Common properties */
/*  ----------------- */

.form-search input,
  .form-search textarea,
  .form-search select,
  .form-search .help-inline,
  .form-search .uneditable-input,
  .form-search .input-prepend,
  .form-search .input-append,
  .form-inline input,
  .form-inline textarea,
  .form-inline select,
  .form-inline .help-inline,
  .form-inline .uneditable-input,
  .form-inline .input-prepend,
  .form-inline .input-append,
  .form-horizontal input,
  .form-horizontal textarea,
  .form-horizontal select,
  .form-horizontal .help-inline,
  .form-horizontal .uneditable-input,
  .form-horizontal .input-prepend,
  .form-horizontal .input-append {
  display: inline-block;
  margin-bottom: 0;
  vertical-align: middle;
}

/*  Re-hide hidden elements due to specifity */

.form-search .hide, .form-inline .hide, .form-horizontal .hide {
  display: none;
}
.form-search label,
.form-inline label,
.form-search .btn-group,
.form-inline .btn-group {
  display: inline-block;
}
/*  Remove margin for input-prepend/-append */
.form-search .input-append,
.form-inline .input-append,
.form-search .input-prepend,
.form-inline .input-prepend {
  margin-bottom: 0;
}
/*  Inline checkbox/radio labels (remove padding on left) */
.form-search .radio,
.form-search .checkbox,
.form-inline .radio,
.form-inline .checkbox {
  padding-left: 0;
  margin-bottom: 0;
  vertical-align: middle;
}
/*  Remove float and margin, set to inline-block */
.form-search .radio input[type="radio"],
.form-search .checkbox input[type="checkbox"],
.form-inline .radio input[type="radio"],
.form-inline .checkbox input[type="checkbox"] {
  float: left;
  margin-right: 3px;
  margin-left: 0;
}


/*  Margin to space out fieldsets */
.control-group {
  margin-bottom: 8px;
}

/*  Legend collapses margin, so next element is responsible for spacing */
legend + .control-group {
  margin-top: 16px;
  -webkit-margin-top-collapse: separate;
}

/*  If a control is disabled, also gray out the control label */
.control-group.disabled  .control-label {
	color: #999;
	cursor: default;
}

/*  Tooltop link */
.control-group .tooltip-link {
	top: -0.5em;
	position: relative;
	font-size: 75%;
	line-height: 0;
	vertical-align: baseline;
	padding: 2px;
	cursor: default;
	font-weight: normal;
}


/*  Horizontal-specific styles */
/*  -------------------------- */

/*  Increase spacing between groups */

.form-horizontal .control-group {
  margin-bottom: 16px;
}

.form-horizontal .control-group:before,
    .form-horizontal .control-group:after {
  display: table;
  content: "";
  /*  Fixes Opera/contenteditable bug: */
  /*  http://nicolasgallagher.com/micro-clearfix-hack/#comment-36952 */
  line-height: 0;
}

.form-horizontal .control-group:after {
  clear: both;
}

/*  Float the labels left */

.form-horizontal .control-label {
  float: left;
  width: 160px;
  padding-top: 5px;
  text-align: right;
}

/*  Move over all input controls and content */

.form-horizontal .controls {
  margin-left: 180px;
}

/*  Remove bottom margin on block level help text since that's accounted for on .control-group */

.form-horizontal .help-block {
  margin-bottom: 0;
}

/*  And apply it only to .help-block instances that follow a form control */

.form-horizontal input + .help-block, .form-horizontal select + .help-block, .form-horizontal textarea + .help-block, .form-horizontal .uneditable-input + .help-block, .form-horizontal .input-prepend + .help-block, .form-horizontal .input-append + .help-block {
  margin-top: 8px;
}

/*  Move over buttons in .form-actions to align with .controls */

.form-horizontal .form-actions {
  padding-left: 180px;
}



/*  Inline-specific styles */
/*  -------------------------- */
.form-inline label {
  line-height: 28px;
}
.form-inline .form-value {
  line-height: 28px;
  margin-right: 15px;
}
.form-inline input {
  width: auto;
  margin-right: 15px;
}

/*  Form elements */
/*  ---------------------- */

.control {
	position: relative;
    font-size: @baseFontSize;
}

/*  synthetic placeholder */

.control .placeholder {
  color: #999;
  position: absolute;
  max-width: 100%;
  top: 3px;
  left: 6px;
  font-size: inherit;
}

.control ::-webkit-input-placeholder {
  color:#999;
  opacity:1;
}

.control ::-moz-placeholder {
  color:#999;
  opacity:1;
}

.control :-ms-input-placeholder {
  color:#999;
  opacity:1;
}

.control ::placeholder {
  color:#999;
  opacity:1;
}

/* uneditable-input a read only text field or text area */

.control .uneditable-input {
  background-color: #f3f3f3;
  min-height: 16px;
  font-size: inherit;
}

.control .uneditable-input.uneditable-input-multiline {
  overflow-y: auto;
  white-space: normal;
  white-space: pre-wrap;
  word-break: break-all;
  word-break: break-word;
  height: auto;
  max-height: 100px;
}

.control.shared-controls-textcontrol .control-clear {
  position: absolute;
  top: 50%;
  transform: translate(0, -50%);
  right: 10px;
  font-size: 150%;
  color: #999;
  display: none;
}

.control.shared-controls-textcontrol input {
  padding-right: 25px;
}

.control.shared-controls-spinnercontrol {
  text-align: center;
}

.control.shared-controls-spinnercontrol input, .control.shared-controls-spinnercontrol .uneditable-input {
  display: block;
  width: calc(100% - 56px);
  /* 100% minus padding and border */
  padding: 4px 48px 4px 6px;
  transition: border-color 2s, box-shadow 2s;
}

.control.shared-controls-spinnercontrol input.corrected-value {
  border-color: #d6563c;
  box-shadow: rgba(214, 86, 60, 0.5) 0px 0px 8px 0px;
}

.control.shared-controls-spinnercontrol .increment-down, .control.shared-controls-spinnercontrol .increment-up {
  position: absolute;
  right: 1px;
  top: 1px;
  width: 20px;
  line-height: 20px;
}

.control.shared-controls-spinnercontrol .increment-down:focus, .control.shared-controls-spinnercontrol .increment-up:focus {
  outline: 0;
  text-decoration: none;
  background: rgba(61, 171, 255, 0.12);
  box-shadow: none;
  /* override default focus-link() */
}

.control.shared-controls-spinnercontrol .increment-down.disabled, .control.shared-controls-spinnercontrol .increment-up.disabled {
  color: #999;
}

.control.shared-controls-spinnercontrol .increment-down {
  right: 26px;
}

.control.shared-findinput {
  display: inline-block;
  margin: 5px 0;
}

.control.shared-findinput input {
  width: 250px;
}


/* simple text only control (LabelControl) */
.input-label {
    max-width: 100%;
    padding: 6px 0 4px 0;
    line-height: 15px;
    font-size: 12px;
    display: inline-block;
    word-wrap: break-word;
    word-break: break-word;
}

/* wrapper for checkbox */
label.checkbox {
	padding: 2px 0 2px 22px;
	margin-bottom: 0;
	min-height: 16px;
	position: relative;
	min-height: 16px;
    overflow: hidden;
    text-overflow: ellipsis;
}
label.checkbox.disabled {
  color: #999;
}
label.checkbox >.btn {
  padding: 0;
  width: 14px;
  height: 14px;
  line-height: 14px;
  position: absolute;
  left: 0;
}
label.checkbox >.btn > [class*="icon-"] {
  margin: 0;
}

/*  Checkbox Controls */
/*  ---------------- */

.control label.checkbox {
	padding: 6px 0 4px 22px;
}

.shared-controls-checkboxgroup label.checkbox {
    padding-top: 2px;
    padding-bottom: 2px;
}


/*  Key Value Control */
/*  ---------------- */
.shared-controls-keyvaluecontrol .shared-controls-textcontrol {
  margin-right: 10px;
}
.shared-controls-keyvaluecontrol .key-text-control-placeholder,
  .shared-controls-keyvaluecontrol .value-text-control-placeholder {
  float: left;
}


/*  Accumulator Control */
/*  ------------------- */
.accumulator {
  width: 700px;
}
.controls-block .accumulator {
  width: 100%;
}
.accumulator .availableOptionsContainer,
  .accumulator .selectedOptionsContainer {
  float: left;
  width: calc(50% - 10px);
  margin: 0px 20px 0px 0px;
}
.accumulator .addAllLink, .accumulator .removeAllLink {
  float: right;
}
.accumulator .selectedOptionsContainer {
  margin-right:0px;
}
.accumulator .availableOptionsHeader {
  font-weight: normal;
  font-size: 12px;
  width: 200px;
  margin-right: 22px;
  padding-bottom: 5px;
  line-height: 0px;
}
.accumulator .selectedOptionsHeader {
  width: 200px;
  margin-right:0px;
}
.accumulator ul.availableOptions, .accumulator ul.selectedOptions {
  height: 100px;
  overflow: auto;
  list-style: none;
  margin: 0;
  padding: 0;
  border: 1px solid #ccc;
  clear: left;
}
.accumulator .accDisabled ul.availableOptions,
  .accumulator .accDisabled ul.selectedOptions {
  background-color: #f3f3f3;
}
.accumulator ul.availableOptions li, .accumulator ul.selectedOptions li {
  clear: left;
  padding: 4px 5px;
  font-size: 12px;
  cursor: pointer;
  line-height: 1;
}
.accumulator ul.availableOptions li:hover,
  .accumulator ul.selectedOptions li:hover {
  background-color: #ddd;
}
.accumulator ul.availableOptions li span, .accumulator ul.selectedOptions li span {
  margin:0px 8px 0 0;
  display: block;
  float: left;
}
.accumulator ul span.splIcon-arrow-e {
  background-color: #65A637;
}
.accumulator ul.availableOptions li.selected, .accumulator .accDisabled ul li {
  color: #999;
}
.accumulator ul.availableOptions li.selected span.splIcon,
  .accumulator .accDisabled ul li span.splIcon {
  background-color: #ccc;
}
.accumulator .selected {
  background-color: transparent;
}
.control-group.error .accumulator ul {
  border-color: #d6563c;
}
.accumulator .icon-class {
  color: #999;
}
.accumulator div.wide {
  width: 340px;
}

/*  table forms? */
/*  ---------------------- */

/* TODO: figure out what this is for

	<table class="form">
		<tr>
			<td>cell</td>
			<td>
				<div class="help-block">help-block</div>
			</td>
		</tr>
		<tr>
			<td>cell</td>
			<td>
				<div class="help-block">help-block</div>
			</td>
		</tr>
	</table>

*/
table.form td {
	padding-right: 10px;
	padding-bottom: 5px;
}

table.form tr:last-child td {
	padding-bottom: 0;
}

table.form tr:last-child .help-block {
	margin-bottom: 0;
}


/*  Format Dialogs */
/*  --------------- */

/* format controls

	<div class="form-format">
		...
	</div>

*/

.form-format .control-label {
  width: 100px;
}

/*  remove margin from last group */

.form-format .control-group:last-child {
  margin-bottom: 0;
}

.form-format .controls {
  margin-left: 120px;
}

/*  TODO: not sure why this is needed */
.form-horizontal textarea {
	max-height: 250px;
	max-width: 206px;
}

.form-horizontal .control-group {
	margin-bottom: 10px;
}

/*  SPL-72247 - aad margin to help block */
.form-horizontal .controls > .help-block {
	margin-top: 16px / 4;
}

/*  Horizontal form, left-aligned */

.form-horizontal.align-left .control-label {
  width: auto;
  text-align: left;
  display: inline-block;
  float: none;
}

.form-horizontal.align-left .controls {
  margin-left: 15px;
  display: inline-block;
}

/*  Complex Forms */
/*  ===================================== */


/*  Form Justified */
/*  --------------- */
/*  justified forms & block btn-group */
/*  if there's only one input block per control group */

/*
	<form class="form-horizontal form-justified">
		<div class="control-group">
			<label class="control-label" for="inputEmail">Email</label>
			<div class="controls">
				<input type="text" id="inputEmail" placeholder="Email">
			</div>
		</div>
		<div class="control-group">
			<label class="control-label" for="inputPassword">Password</label>
			<div class="controls">
				<input type="password" id="inputPassword" placeholder="Password">
			</div>
		</div>
		<div class="control-group">
			<div class="controls">
				<label class="checkbox">
					<input type="checkbox"> Remember me
				</label>
				<button type="submit" class="btn">Sign in</button>
			</div>
		</div>
	</form>
*/
.form-justified .btn-group,
	.form-justified input[type="text"],
	.form-justified input[type="password"],
	.form-justified textarea,
	.form-justified .uneditable-input
	 {
  width: 100%;
  max-width: 100%;
  box-sizing: border-box;
}
.form-justified input[type="text"],
	.form-justified input[type="password"] {
  min-height: 26px;
  /*  should use a var here maybe */
}
.form-justified .btn-combo {
  display: block;
}
.form-justified .btn {
  width: 100%;
  box-sizing: border-box;
}



/*  Form Complex */
/*  -------------- */

/*
	<form class="form-horizontal form-complex">
		<div class="control-group">
			<label class="control-label" for="">Email</label>
			<div class="controls">
				<input type="text" id="" placeholder="Email">
			</div>
		</div>
		<div class="control-group">
			<label class="control-label" for="">Password</label>
			<div class="controls">
				<input type="password" id="" placeholder="Password">
				<span class="help-block help-outer">
					eg. this is some help text <br>
					that goes outside the form for some reason ;_;
				</span>
			</div>
		</div>
		<div class="control-group">
			<div class="controls">
				<label class="checkbox">
					<input type="checkbox"> Remember me
				</label>
				<button type="submit" class="btn">Sign in</button>
			</div>
		</div>
	</form>

*/
/*  complex forms? maybe use form-narrow? */
.form-complex .controls {
  position: relative;
}
.form-complex .control-group {
  width: 440px;
  /*  magic number ;_; maybe move width to container */
}
.form-complex .control-heading {
  /*  like control-label but without the float */
  padding-top: 5px;
  text-align: right;
  width: 160px;
  font-weight: bold;
}
.form-complex .help-block, .form-complex .help-outer {
  position: absolute;
  top: 4px;
  left: 100%;
  margin-left: 10px;
  margin-top: 0 !important;
  /*  TODO: get rid of important; */
  width: 280px;
}
.form-complex .outline {
  border: 1px solid #ccc;
  border-radius: 3px;
  margin-bottom: 10px;
  /*  TOOD: use var here; */
  margin-top: -5px;
  padding-top: 5px;
}
.form-complex fieldset {
  border: 1px solid transparent;
}
.form-complex .btn-check {
  display: inline-block;
  height: 16px;
  line-height: 16px;
  padding: 0;
  text-align: center;
  vertical-align: middle;
  width: 16px;
}
.form-complex .control-feedback {
  display: block;
  width: 100%;
}

/*  feedback for controls */
.control-feedback {
	color: #999;
	background-color: #eee;
	border-radius: 3px;
	font-size: 85%;
	text-align: center;
	margin-top: 3px;
}

/*  SyntheticRadioControl */
/*  --------------------- */


.shared-controls-syntheticradiocontrol > .tooltip {
  white-space:normal;
}


.shared-controls-syntheticradiocontrol .btn-radio {
  display: block;
  position: relative;
  padding: 3px 0 3px 20px;
  color: #333;
  text-decoration: none;
}


.shared-controls-syntheticradiocontrol .btn-radio:before {
  content:'';
  background: #fff;
  border: 1px solid #333;
  color: #333;
  box-shadow: none;
  text-shadow: none;
  border-radius: 2px;
  line-height: 12px;
  position: absolute;
  left: 0;
  top: 2px;
  box-sizing: border-box;
  width: 16px;
  height: 16px;
  border-radius: 8px;
}


.shared-controls-syntheticradiocontrol .btn-radio.disabled {
  cursor: not-allowed;
  color: #999;
  opacity: 0.65;
}


.shared-controls-syntheticradiocontrol .btn-radio.disabled:before {
  background: #ccc;
  filter: none;
  border-color: #ccc;
}


.shared-controls-syntheticradiocontrol .btn-radio.active:after {
  content:'';
  position: absolute;
  left: 4px;
  top: 6px;
  box-sizing: border-box;
  width: 8px;
  height: 8px;
  border-radius: 4px;
  background-color: currentColor;
}

/*  Button Combo Block */
/*  ------------------- */

/*  btn-combo block , just the combo */
.btn-combo-block {
	display:block;
	width: 100%;
}
/*  box-sizing: border-box; */
.btn-combo-block .btn {
  width: 100%;
  box-sizing: border-box;
}

/*  Block Controls */
/*  ------------------- */

/*
	<form action="#" method="post" class="form-horizontal form-complex">
		<div class="control-group">
			<label for="#" class="control-label">label</label>
			<div class="controls controls-block">
				<div class="btn-combo">
					<button class="btn dropdown-toggle" data-toggle="dropdown">
						dropdown
						<span class="caret"></span>
					</button>
					<ul class="dropdown-menu">
						<li><a href="#">foo</a></li>
					</ul>
				</div><!-- /.btn-combo -->
			</div><!-- /.controls -->
		</div><!-- /.control-group -->
	</form>
*/

/*  for block level controls */
.controls-block .btn-group,
	.controls-block .btn-combo {
  display: block;
}
.controls-block .btn {
  width: 100%;
  box-sizing: border-box;
}
.controls-block input[type="text"], .controls-block .uneditable-input {
  width: 100%;
  box-sizing: border-box;
  min-height: 26px;
  display: block;
}
.controls-block textarea {
  width: 100%;
  max-width: 100%;
  min-height: 2em;
  resize: vertical;
  box-sizing: border-box;
}


/*  Controls Half Block */
/*  --------------------- */

.controls-fill .btn-group,
	.controls-fill .btn-combo {
  display:block;
  display: -ms-flexbox;
  display: flex;
  -ms-flex-direction: row;
  flex-direction: row;
}

.controls-fill .btn {
  box-sizing: border-box;
  -ms-flex: auto;
  flex: auto;
}

.controls-fill input {
  box-sizing: border-box;
  min-height: 26px;
  -ms-flex: auto;
  flex: auto;
}

/*  50% width controls */
.controls-halfblock .btn-group,
	.controls-halfblock .btn-combo {
  display:block;
  display: -ms-flexbox;
  display: flex;
  -ms-flex-direction: row;
  flex-direction: row;
}
.controls-halfblock .btn {
  width: 50%;
  box-sizing: border-box;
  -ms-flex: 1 0 0px;
  flex: 1 0 0px;
}
.controls-halfblock input {
  width: 50%;
  box-sizing: border-box;
  min-height: 26px;
  -ms-flex: 1 0 0px;
  flex: 1 0 0px;
}

/*  1/3 controls */
.controls-thirdblock .btn-group,
	.controls-thirdblock .btn-combo {
  display:block;
  display: -ms-flexbox;
  display: flex;
  -ms-flex-direction: row;
  flex-direction: row;
}
.controls-thirdblock .btn {
  width: 33.333%;
  box-sizing: border-box;
  -ms-flex: auto;
  flex: auto;
}

/*  1/4 controls */
.controls-quarterblock .btn-group,
	.controls-quarterblock .btn-combo {
  display:block;
}
.controls-quarterblock .btn {
  width: 25%;
  box-sizing: border-box;
}

/*  Controls Split */
/*  ------------------- */

/*
	<form action="#" method="post" class="form-horizontal form-complex">
		<div class="control-group">
			<label for="#" class="control-label">in</label>
			<div class="controls controls-split">
				<input type="text" placeholder="5">
				<div class="btn-combo">
					<button class="btn dropdown-toggle" data-toggle="dropdown">
						minutes
						<span class="caret"></span>
					</button>
					<ul class="dropdown-menu">
						<li><a href="#">foo</a></li>
					</ul>
				</div><!-- /.btn-combo -->
			</div><!-- /.controls -->
		</div><!-- /.control-group -->
	</form>
*/

/*  for controls with text & combo */
.controls-split .btn-combo,
	.controls-split .btn-group {
  display:inline-block;
  width: 50%;
  vertical-align: middle;
}
.controls-split .btn-combo .btn, .controls-split .btn-group .btn {
  width: 100%;
}
.controls-split .btn {
  display:block;
  vertical-align: middle;
  box-sizing: border-box;
}
.controls-split input[type="text"]
	{
  box-sizing: border-box;
  width: 50%;
  min-height: 26px;
  vertical-align: middle;
}
/*  FIXME: this doesn't scale well ;_; */
.controls-split .btn-combo + input,
	.controls-split input + .btn-combo,
	.controls-split .btn-combo + .shared-controls-textcontrol,
	.controls-split .btn-group + .shared-controls-textcontrol,
	.controls-split .shared-controls-textcontrol + .btn-combo,
	.controls-split .shared-controls-textcontrol + .btn-group
	{
  margin-left: 0;
}
/*  alert controls */
.controls-split .shared-controls-textcontrol {
  display: inline;
}

/* Small forms
/* ===================================== */


.control-group-small .control-label {
  font-size: 11px;
}

.control-small {
    font-size: 11px;
}

.control-small input[type="text"],
    .control-small .uneditable-input,
    .control-small textarea {
  padding-top: 2px;
  padding-bottom: 2px;
  font-size: inherit;
}

.control-small .uneditable-input {
  min-height: 16px;
}

.control-small .btn, .control-small.btn-group > .btn {
  padding-top: 2px;
  padding-bottom: 2px;
  font-size: 11px;
}

/*  Form add-ons */
/*  ------------ */

.controls.input-append, .controls.input-prepend {
	display: block;
}

.controls-split.input-prepend .btn-group {
    margin-right: -1px;
}

.controls-split.input-append .btn-group {
    margin-left: -1px;
}

.input-append input + .add-on.dropdown-toggle {
	border-top-right-radius: 2px;
	border-bottom-right-radius: 2px;
}

.input-append input.active{
	/* need this to override some weird library rule. */
	border-color: rgba(82,168,236,.8);
}

.input-append input.active:focus {
  background-color: #fff;
}

.input-append input.active:not(:focus) {
  background-color: #fff;
}

a.add-on {
 background: #fff;
 border: 1px solid #333;
 color: #333;
 box-shadow: none;
 text-shadow: none;
 border-radius: 2px;
}

a.add-on:hover {
  background: #efefef;
  border-color: rgb(59, 59, 59);
  border-top-color: #333;
  border-bottom-color: #333;
  background-position: 0 0;
  text-decoration: none;
  text-decoration: none;
}

/*  Error States */
/*  ---------------- */

.error .btn {
  border-color: rgb(192, 135, 124);
  color: #d6563c;
}

.error .btn.active {
  background-image: none;
}

.error .btn:hover {}

.required {
	color: #d6563c;
}

/*  Custom shared form components for color editing */
/*  ------------------------------------------------------ */

.color-square {
  display: block;
  width: 18px;
  height: 18px;
  background: #a2cc3e;
  border: 1px solid #999;
  border-radius: 2px;
}

.color-square:focus {
  border-color: rgba(82, 168, 236, 0.8);
  outline: 0;
  background-position: 0;
  /*  bootstrap tries to animate this on hover & focus */
  background-color: #fff;
  border-collapse: separate;
  /* Fix IE9 Issue with box-shadow */
  box-shadow: none;
}

.color-square-standalone {
	margin-top: 3px;
}

/*  Lite UI */
/*  ================ */
textarea:not(:focus), input[type="text"]:not(:focus), input[type="password"]:not(:focus), input[type="datetime"]:not(:focus), input[type="datetime-local"]:not(:focus), input[type="date"]:not(:focus), input[type="month"]:not(:focus), input[type="time"]:not(:focus), input[type="week"]:not(:focus), input[type="number"]:not(:focus), input[type="email"]:not(:focus), input[type="url"]:not(:focus), input[type="search"]:not(:focus), input[type="tel"]:not(:focus), input[type="color"]:not(:focus), .uneditable-input:not(:focus) {
  border-color: #333;
}
textarea:focus, input[type="text"]:focus, input[type="password"]:focus, input[type="datetime"]:focus, input[type="datetime-local"]:focus, input[type="date"]:focus, input[type="month"]:focus, input[type="time"]:focus, input[type="week"]:focus, input[type="number"]:focus, input[type="email"]:focus, input[type="url"]:focus, input[type="search"]:focus, input[type="tel"]:focus, input[type="color"]:focus, .uneditable-input:focus {
  box-shadow: none;
}
/*  Splunk: Tables */
/*  =================== */
/*  Tables for, you guessed it, tabular data */

/*  BASE TABLES */
/*  ----------------- */

table {
  max-width: 100%;
  background-color: transparent;
  border-collapse: collapse;
  border-spacing: 0;
}



/*  BASELINE STYLES */
/*  --------------- */
.table {
    width: auto;
    min-width: 100%;
    max-width: none;
    margin-bottom: 16px;
}
/*  Cells */
.table th, .table td {
  text-align: left;
  vertical-align: top;
  font-weight: normal;
  padding: 4px 8px;
  line-height: 16px;
  border-top: 1px solid #333;
}
.table th:first-child, .table td:first-child {
  padding-left: 20px;
}
.table th:last-child, .table td:last-child {
  padding-right: 20px;
}
.table th td:focus, .table td td:focus {
  outline: 0;
  text-decoration: none;
  background: rgba(61, 171, 255, 0.12);
  box-shadow: none;
  /* override default focus-link() */
}
.table thead th {
  vertical-align: bottom;
}
/*  Remove top border from thead by default */
.table caption + thead tr:first-child th,
    .table caption + thead tr:first-child td,
    .table colgroup + thead tr:first-child th,
    .table colgroup + thead tr:first-child td,
    .table thead:first-child tr:first-child th,
    .table thead:first-child tr:first-child td {
  border-top: 0;
}
/*  Account for multiple tbody instances */
.table tbody + tbody {
  border-top: 2px solid #333;
}
/*  sorts */
.table .sorts {
  white-space: nowrap;
  cursor: pointer;
}
.table .sorts a {
  color: inherit;
}
.table .sorts a:hover {
  text-decoration: none;
}
.table .sorts:hover {
  background-color: #e4e4e4;
}
.table .sorts .icon-sorts {
  display: inline;
}
.table .sorts .icon-sorts:before {
  font-family: "Splunk Icons";
  content: "\2195";
  padding-left: 5px;
  color: #bbb;
}
.table .sorts .asc:before,
        .table .sorts .Asc:before
        {
  content: "\21A5";
  color: inherit;
}
.table .sorts .desc:before,
        .table .sorts .Desc:before {
  content: "\21A7";
  color: inherit;
}
/*  Nesting */
.table .table {
  background-color: transparent;
}


/* saf3+, chrome1+ */
@media screen and (-webkit-min-device-pixel-ratio:0) {
    /*  fix table headers */
    .table-chrome > thead > tr > th  { position: relative;  }
}




/*  CONDENSED TABLE W/ HALF PADDING */
/*  ------------------------------- */

.table-condensed th,
  .table-condensed td {
  padding: 4px 5px;
}



/*  BORDERED VERSION */
/*  ---------------- */

.table-bordered {
  border: 1px solid #333;
  border-collapse: separate; /*  Done so we can round those corners! */
  border-left: 0;
  border-radius: 2px;

}

.table-bordered th,
  .table-bordered td {
  border-left: 1px solid #333;
}

/*  Prevent a double border */

.table-bordered caption + thead tr:first-child th,
  .table-bordered caption + tbody tr:first-child th,
  .table-bordered caption + tbody tr:first-child td,
  .table-bordered colgroup + thead tr:first-child th,
  .table-bordered colgroup + tbody tr:first-child th,
  .table-bordered colgroup + tbody tr:first-child td,
  .table-bordered thead:first-child tr:first-child th,
  .table-bordered tbody:first-child tr:first-child th,
  .table-bordered tbody:first-child tr:first-child td {
  border-top: 0;
}

/*  For first th/td in the first row in the first thead or tbody */

.table-bordered thead:first-child tr:first-child > th:first-child,
  .table-bordered tbody:first-child tr:first-child > td:first-child,
  .table-bordered tbody:first-child tr:first-child > th:first-child {
  border-top-left-radius: 2px;
}

/*  For last th/td in the first row in the first thead or tbody */

.table-bordered thead:first-child tr:first-child > th:last-child,
  .table-bordered tbody:first-child tr:first-child > td:last-child,
  .table-bordered tbody:first-child tr:first-child > th:last-child {
  border-top-right-radius: 2px;
}

/*  For first th/td (can be either) in the last row in the last thead, tbody, and tfoot */

.table-bordered thead:last-child tr:last-child > th:first-child,
  .table-bordered tbody:last-child tr:last-child > td:first-child,
  .table-bordered tbody:last-child tr:last-child > th:first-child,
  .table-bordered tfoot:last-child tr:last-child > td:first-child,
  .table-bordered tfoot:last-child tr:last-child > th:first-child {
  border-bottom-left-radius: 2px;
}

/*  For last th/td (can be either) in the last row in the last thead, tbody, and tfoot */

.table-bordered thead:last-child tr:last-child > th:last-child,
  .table-bordered tbody:last-child tr:last-child > td:last-child,
  .table-bordered tbody:last-child tr:last-child > th:last-child,
  .table-bordered tfoot:last-child tr:last-child > td:last-child,
  .table-bordered tfoot:last-child tr:last-child > th:last-child {
  border-bottom-right-radius: 2px;
}

/*  Clear border-radius for first and last td in the last row in the last tbody for table with tfoot */

.table-bordered tfoot + tbody:last-child tr:last-child td:first-child {
  border-bottom-left-radius: 0;
}

.table-bordered tfoot + tbody:last-child tr:last-child td:last-child {
  border-bottom-right-radius: 0;
}

/*  Special fixes to round the left border on the first td/th */

.table-bordered caption + thead tr:first-child th:first-child,
  .table-bordered caption + tbody tr:first-child td:first-child,
  .table-bordered colgroup + thead tr:first-child th:first-child,
  .table-bordered colgroup + tbody tr:first-child td:first-child {
  border-top-left-radius: 2px;
}

.table-bordered caption + thead tr:first-child th:last-child,
  .table-bordered caption + tbody tr:first-child td:last-child,
  .table-bordered colgroup + thead tr:first-child th:last-child,
  .table-bordered colgroup + tbody tr:first-child td:last-child {
  border-top-right-radius: 2px;
}


/*  BORDERED LITE */
/*  ----------------- */
/* a stripped-down verison of bootstrap's table-bordered */
.table-bordered-lite th, .table-bordered-lite td {
  border-left: 1px solid #333;
}
.table-bordered-lite th:first-child, .table-bordered-lite td:first-child {
  border-left: none;
}

/*  BORDERED DOTTED */
/*  ----------------- */
.table-dotted td, .table-dotted th {
  border-top: 1px dashed #ccc;
}

/*  ZEBRA-STRIPING */
/*  -------------- */

.table-striped > thead > tr > th {
  background-color: #fff;
  border-top: 1px solid #333;
}

.table-striped > tbody {
  /*  For tables that have manually striped rows due to row-grouping, reset .even to white. */
}

.table-striped > tbody > tr:nth-child(odd) > td,
        .table-striped > tbody > tr:nth-child(odd) > th
        > tr.odd > td,
        .table-striped > tbody > tr.odd > th {
  background-color: #eee;
}

/*  Consider not have the table-striped class and only rely on the row class - Marc */

.table-striped > tbody > tr.even > td,
        .table-striped > tbody > tr.even > th {
  background-color: #fff;
}


/*  CHROME */
/*  ------------------- */

.table-chrome {
    border-top: 1px solid #333;
    border-bottom: 1px solid #333;

}

.table-chrome > thead > tr > th {
  font-weight: normal;
  background: #fff;
  border: 1px solid #333;
  color: #333;
  box-shadow: none;
  text-shadow: none;
  border-radius: 2px;
  box-shadow: none;
}

/*  position: relative; this fixes a rendering bug in Safari 6.0.5 (SPL-67998) - also causes rendering issue in FF */

.table-chrome > thead > tr > th:first-child {
  border-left: none;
}

.table-chrome > thead > tr > th:last-child {
  border-right: none;
}

/*  FF bug fix */

.table-chrome td {
  border-left: 0 solid transparent;
  border-right: 0 solid transparent;
}

/*  sorting */

.table-chrome .sorts {
  font-weight: normal;
}

.table-chrome .sorts:hover {
  text-decoration: none;
  background: #efefef;
  border-color: rgb(59, 59, 59);
  border-top-color: #333;
  border-bottom-color: #333;
  background-position: 0 0;
  text-decoration: none;
}

.table-chrome .sorts a {
  text-decoration: none;
  color: #333;
}

.table-chrome .sorts.active {
  /* .gradient-vertical($interactiveGradientEndColor,$interactiveGradientStartColor); */
  /* box-shadow: inset 1px 1px 2px rgba(0, 0, 0, 0.1); */
}

.table-chrome .sorts.active:hover {
  background: #efefef;
  border-color: rgb(59, 59, 59);
  border-top-color: #333;
  border-bottom-color: #333;
  background-position: 0 0;
  text-decoration: none;
  border-bottom: 1px solid #333;
}

.table-chrome.table-striped > tbody > tr:nth-child(even) > td {
  background-color: #eee;
}

.table-chrome.table-striped > tbody > tr:nth-child(odd) > td {
  background-color: #fff;
}

.table-chrome.table-striped > tbody > tr.even > td {
  background-color: #eee;
}

.table-chrome.table-striped > tbody > tr.odd > td {
  background-color: #fff;
}



/*  TABLE CELL SIZING */
/*  ----------------- */

/*  Reset default grid behavior */
table td[class*="span"],
table th[class*="span"],
.row-fluid table td[class*="span"],
.row-fluid table th[class*="span"] {
  display: table-cell;
  float: none; /*  undo default grid column styles */
  margin-left: 0; /*  undo default grid column styles */
}

/*  Change the column widths to account for td/th padding */
.table td.span1,     .table th.span1     {
  float: none;
  /*  undo default grid column styles */
  width: 44px;
  /*  16 is total padding on left and right of table cells */
  margin-left: 0;
  /*  undo default grid column styles */
}
.table td.span2,     .table th.span2     {
  float: none;
  /*  undo default grid column styles */
  width: 124px;
  /*  16 is total padding on left and right of table cells */
  margin-left: 0;
  /*  undo default grid column styles */
}
.table td.span3,     .table th.span3     {
  float: none;
  /*  undo default grid column styles */
  width: 204px;
  /*  16 is total padding on left and right of table cells */
  margin-left: 0;
  /*  undo default grid column styles */
}
.table td.span4,     .table th.span4     {
  float: none;
  /*  undo default grid column styles */
  width: 284px;
  /*  16 is total padding on left and right of table cells */
  margin-left: 0;
  /*  undo default grid column styles */
}
.table td.span5,     .table th.span5     {
  float: none;
  /*  undo default grid column styles */
  width: 364px;
  /*  16 is total padding on left and right of table cells */
  margin-left: 0;
  /*  undo default grid column styles */
}
.table td.span6,     .table th.span6     {
  float: none;
  /*  undo default grid column styles */
  width: 444px;
  /*  16 is total padding on left and right of table cells */
  margin-left: 0;
  /*  undo default grid column styles */
}
.table td.span7,     .table th.span7     {
  float: none;
  /*  undo default grid column styles */
  width: 524px;
  /*  16 is total padding on left and right of table cells */
  margin-left: 0;
  /*  undo default grid column styles */
}
.table td.span8,     .table th.span8     {
  float: none;
  /*  undo default grid column styles */
  width: 604px;
  /*  16 is total padding on left and right of table cells */
  margin-left: 0;
  /*  undo default grid column styles */
}
.table td.span9,     .table th.span9     {
  float: none;
  /*  undo default grid column styles */
  width: 684px;
  /*  16 is total padding on left and right of table cells */
  margin-left: 0;
  /*  undo default grid column styles */
}
.table td.span10,    .table th.span10    {
  float: none;
  /*  undo default grid column styles */
  width: 764px;
  /*  16 is total padding on left and right of table cells */
  margin-left: 0;
  /*  undo default grid column styles */
}
.table td.span11,    .table th.span11    {
  float: none;
  /*  undo default grid column styles */
  width: 844px;
  /*  16 is total padding on left and right of table cells */
  margin-left: 0;
  /*  undo default grid column styles */
}
.table td.span12,    .table th.span12    {
  float: none;
  /*  undo default grid column styles */
  width: 924px;
  /*  16 is total padding on left and right of table cells */
  margin-left: 0;
  /*  undo default grid column styles */
}



/*  HOVER EFFECT */
/*  ------------ */
.table-hover > tbody > tr:hover > td,
    .table-hover > tbody > tr:hover > th {
  background-color: #e4e4e4;
}


/*  FOCUS EFFECT */
/*  ------------ */

/*  add focus back in, needs to come last */
.table > tbody > tr > td:focus, .table > tbody > tr.even > td:focus, .table > tbody > tr.odd > td:focus {
  outline: 0;
  text-decoration: none;
  background: rgba(61, 171, 255, 0.12);
  box-shadow: none;
  /* override default focus-link() */
}
.table > tbody > tr:focus,
.table > tbody > tr.even:focus,
.table > tbody > tr.odd:focus {
	outline: none;
}
.table > tbody > tr:focus > td, .table > tbody > tr.even:focus > td, .table > tbody > tr.odd:focus > td {
  outline: 0;
  text-decoration: none;
  background: rgba(61, 171, 255, 0.12);
  box-shadow: none;
  /* override default focus-link() */
}





/*  TABLE BACKGROUNDS */
/*  ----------------- */
/*  Exact selectors below required to override .table-striped */

.table tbody tr.success > td {
  background-color: rgb(239, 246, 223);
}

.table tbody tr.error > td {
  background-color: rgb(250, 233, 230);
}

.table tbody tr.warning > td {
  background-color: rgb(253, 244, 221);
}

.table tbody tr.info > td {
  background-color: #d9edf7;
}

/*  Hover states for .table-hover */
.table-hover tbody tr.success:hover > td {
  background-color: rgb(229, 240, 203);
}
.table-hover tbody tr.error:hover > td {
  background-color: rgb(246, 214, 208);
}
.table-hover tbody tr.warning:hover > td {
  background-color: rgb(252, 236, 197);
}
.table-hover tbody tr.info:hover > td {
  background-color: rgb(196, 227, 243);
}




/*  EMBEDDED TABLES */
/*  -------------------- */
/*  tables that appear within other tables. */


.table-embed {
    width:100%;
    border: 0;
}


.table-embed td {
  border-bottom: 1px dashed #ccc;
  border-left: 0;
  padding: 0;
  background-color: transparent !important;
}


.table-embed td:first-child {
  padding-right: 10px;
}




/*  ROW EXPANDING */
/*  -------------------- */


.table-row-expanding {
    width: 100%;
    table-layout: fixed;
    margin-bottom: -1px;
    border-bottom: 1px solid #ccc;
}


.table-row-expanding > tbody > tr > td.expands {
  cursor: pointer;
  border-right:1px solid #d5d5d5;
  padding: 0;
}


.table-row-expanding > tbody > tr > td.expands.disabled {
  color: #bbb;
  cursor: default;
}


.table-row-expanding > tbody > tr > td.expands.disabled > span, .table-row-expanding > tbody > tr > td.expands.disabled a {
  color: inherit;
  cursor: inherit;
}


.table-row-expanding > tbody > tr > td.expands > span, .table-row-expanding > tbody > tr > td.expands a, .table-row-expanding > tbody > tr > td.expands > i {
  color: #333;
  display: block;
  padding: 4px 0 4px 20px;
  width: 15px;
  height: 16px;
  text-decoration: none;
  text-align: left;
}


.table-row-expanding > tbody > tr > td.expands > span:focus, .table-row-expanding > tbody > tr > td.expands a:focus, .table-row-expanding > tbody > tr > td.expands > i:focus {
  outline: 0;
  text-decoration: none;
  background: rgba(61, 171, 255, 0.12);
  box-shadow: none;
  /* override default focus-link() */
}


/*  TODO unify these class names */


.table-row-expanding > tbody > tr.more-info > td,
    .table-row-expanding > tbody > tr.info-row > td {
  border-top: none;
  background-color: #e4e4e4;
}


/*  style for an extra row inserted in the expanded state */


.table-row-expanding > tbody > tr.expanded > td {
  background-color: #e4e4e4;
}


.table-row-expanding > tbody > tr > td > .btn-combo {
  margin: -4px 5px -6px 20px;
}


.table-row-expanding > tbody > tr > td > .btn-combo:first-child {
  margin-left: 0;
}


.table-row-expanding > tbody > tr > td.title > a,
    .table-row-expanding > tbody > tr > td.title > span {
  margin: -4px -8px;
  padding: 4px 8px;
  display: block;
  white-space: nowrap;
  text-overflow: ellipsis;
  overflow: hidden;
  font-size: 14px;
  line-height: 16px;
}


.table-row-expanding > tbody > tr > td.title > a:focus, .table-row-expanding > tbody > tr > td.title > span:focus {
  outline: 0;
  text-decoration: none;
  background: rgba(61, 171, 255, 0.12);
  box-shadow: none;
  /* override default focus-link() */
}


.table-row-expanding > tbody > tr > td.title > .disabled {
  color: #7C7C7C;
}


.table-row-expanding > tbody > tr.expanded > td.title > a {
  white-space: normal;
}


.table-row-expanding th.col-info {
  width:15px;
  padding-left:20px;
  padding-right:0;
  text-align: left;
  vertical-align: top;
  font-size: 100%;
  border-right:1px solid #d5d5d5;
}


.table-row-expanding th.col-info a {
  text-decoration: none;
  color: #000;
}


.table-row-expanding th.col-info .icon-info {
  width:15px;
  display: block;
}


.table-row-expanding td.expands:hover:not(.disabled),
    .table-row-expanding td.col-info:hover:not(.disabled) {
  background-color: #e4e4e4 !important;
  /*  lame but needed to override BS .table-striped */
  border-right:1px solid #d5d5d5 !important;
}


.table-row-expanding td.expands .icon-triangle-right-small:before {
  content: "\203A";
}


.table-row-expanding td.expands .icon-triangle-down-small:before {
  content: "\2C5";
}

/*  remove sorting icons for info column */
.table-chrome .sorts th.col-info:after {
  content: "";
}



/*  SPECIAL COLUMNS AND CELLS */
/*  -------------------- */
/*  custom styles for row numbers */

td.row-number,
th.row-number {
    width: 1px;
}
td.row-number, td.line-num {
    text-align: right;
    color: #999;
}

/*  custom styles for numeric value cells */
th.numeric, td.numeric {
    text-align: right
}

td.end-group {
    border-right:1px solid #d5d5d5;
}


/*  DOCKING AND STATIC TABLE HEADERS */
/*  ----------- */
/*  class for docking table header and scroll bar */

.header-table-docked {
    position: fixed;
    top: 0;
    z-index: 406;
    overflow: hidden;
    box-shadow: 0 4px 8px rgba(0,0,0,0.11);
    background: #fff;
}

.header-table-docked > .disable {
    display: block;
    position: absolute;
    top: 0px;
    right: 0px;
    bottom: 0px;
    left: 0px;
    background-color: #555;
    opacity: 0.30;
}

.header-table-docked > table {
    table-layout: fixed;
    margin-bottom: 0;
    /*  SPL-71945, this prevents the last header cell from appearing un-styled in Firefox and IE */
    max-width: inherit;
}

.table-scroll-bar-docked {
    position: fixed;
    bottom: 0;
    left: 0;
    right: 0;
    overflow-x: auto;
}

 /*  class for static table header and scroll bar */

.header-table-static {
    height: 0;
    position: relative;
    z-index: 406;
}

.header-table-static > table {
  margin-bottom: 0;
}

.header-table-wrapper {
    overflow: hidden;
    border-bottom: 1px solid #333;
}

.header-table-wrapper .table {
  margin-bottom: 0;
}

 /*  need to clean up these two classes to make sense */
.scroll-table-wrapper { /*  used on dashboards and embedded tables, the wrapper scrolls horz and vert */
    height: 380px; /* override */
    width: 100%;
    overflow: auto;
}

.scrolling-table-wrapper { /* tables that will scroll horizontally */
    width: 100%;
    overflow-x: auto;
    position: relative;
}

/*  tables that will scroll vertically, up to consumer to set height or max-height */
.vertical-scrolling-table-wrapper {
    width: 100%;
    overflow-y: auto;
}


/*  MODALIZING ROWS */
/*  ----------- */
.modalize-table-top, .modalize-table-bottom, .modalize-table-overlay {
    position: absolute;
    left: 0;
    background-color: #555;
    opacity: 0.30;
}

.modalize-table-top {
    top: 0;
}

.modalize-table-bottom {
    bottom: 0;
}

.modalize-table-overlay {
    position: fixed;
    top: 0;
    bottom: 0;
    right: 0;
}


/*  DRILLDOWN */
/*  -------------------------------------------------- */

.table-drilldown > tbody > tr > td {
    color: #0095cf;
}

.table-drilldown > tbody > tr > td:hover {
  color: rgb(0, 77, 107);
}

/*  reset for row # */

.table-drilldown > tbody > tr > td.row-number {
  color: #999;
}
.table-drilldown-row > tbody > tr:hover > td {
   color: rgb(0, 77, 107);
}
/*  reset for row # */
.table-drilldown-row > tbody > tr:hover > td.row-number {
  color: #999;
}
.table-drilldown-cell > tbody > tr > td:hover .multivalue-subcell {
  color: #0095cf;
}
.table-drilldown-cell > tbody > tr > td:hover .multivalue-subcell:hover {
  color: rgb(0, 77, 107);
}


/*  MISC */
/*  ----------- */
/*  misc hacks that should probably never been added */
.ui-grid-head-table,
.ui-grid-body-table
{
    margin-bottom: 0;
}

/*  table-scroll? */
.table-scroll tbody {
  max-height: 200px;
  overflow-y: scroll;
}

/*  just the row borders */
.table-border-row {
    border-top: 1px solid #333;
}
.table-border-row th, .table-border-row td {
  border-top: 1px solid #333;
}

/*  fixed width tables */
.table-fixed {
    table-layout:fixed;
}
.table-fixed tr > td:first-child {
  max-width: 300px;
  word-break: break-all;
}

/*  remove the sorting icons for the row number column */
.table-chrome .sorts th.row-number:after {
  content: "";
}

/*  Lite UI */
/*  -------------------------------------------------- */
.table-chrome {
  border-top-width: 0;
  border-bottom-color: #333;
}
.table-chrome > thead > tr > th {
  border-top-width: 0;
  border-left-width: 0;
  border-right-width: 0;
  border-bottom: 1px solid #333;
  font-weight: bold;
}
.table-chrome > thead > tr > th.sorts:hover, .table-chrome > thead > tr > th.sorts.active:hover {
  background: #e4e4e4;
}
.table-chrome > tbody > tr > td {
  border-top-width: 0;
}
.table-chrome > tbody > tr:nth-child(odd) > td {
  background-color: #fff;
}
.table-chrome > tbody > tr:nth-child(even) > td {
  background-color: #eee;
}
.table-chrome > tbody > tr.odd > td {
  background-color: #fff;
}
.table-chrome > tbody > tr.even > td {
  background-color: #eee;
}
.table-chrome .sorts {
  font-weight: bold;
}
.table-chrome .sorts .icon-sorts:before {
  color: #333;
}
.header-table-wrapper, .header-table-wrapper .table-chrome {
  border-bottom-width: 0;
}

/*  Print */
/*  -------------------------------------------------- */


@media print { body table {
    max-width: 100% !important;
    width: 100% !important;
    overflow: hidden !important;
    table-layout: auto !important;
  } body .scrolling-table-wrapper, body .results-wrapper, body .results-table, body .events-viewer-wrapper {
    max-width: 100% !important;
    width: 100% !important;
    overflow: hidden !important;
  } body td,
    body th {
    background: none !important;
    word-break: break-all !important;
    word-wrap: break-word !important;
    overflow-wrap: break-word !important;
    white-space: normal !important;
    width: auto !important;
    page-break-inside: auto;
  } body .table-chrome .sorts:after {
    content: '';
  } body .header-table-docked,
    body .table-scroll-bar-docked {
    display: none !important;
  } }
body.print table {
  max-width: 100% !important;
  width: 100% !important;
  overflow: hidden !important;
  table-layout: auto !important;
}
body.print .scrolling-table-wrapper, body.print .results-wrapper, body.print .results-table, body.print .events-viewer-wrapper {
  max-width: 100% !important;
  width: 100% !important;
  overflow: hidden !important;
}
body.print td,
    body.print th {
  background: none !important;
  word-break: break-all !important;
  word-wrap: break-word !important;
  overflow-wrap: break-word !important;
  white-space: normal !important;
  width: auto !important;
  page-break-inside: auto;
}
body.print .table-chrome .sorts:after {
  content: '';
}
body.print .header-table-docked,
    body.print .table-scroll-bar-docked {
  display: none !important;
}
/*  Splunk: Table Captions */
/*  =================== */
/*  The count, filters and pagination that appear above a listing. */


.table-caption,
.table-caption-inner {
    min-height: 36px;
    text-align: center;}

.table-caption-inner.affix-top {
    left: 0;
    top: 0;
    right: 0;
    background-color: #eee;
    z-index: 406;
    position: fixed;
}

.table-caption h3 {
    font-size: 12px;
    font-weight: normal;
    float: left;
    padding-left: 20px;
    line-height: 36px;
    margin: 0;
    min-width: 140px;
    text-align: left;
}


.table-caption .shared-waitspinner {
    float: left;
    width: 14px;
    height: 14px;
    margin: 10px 2px 2px 2px;
}

.table-caption div.shared-controls-controlgroup {
    display: inline-block;
    margin: 0px 10px 0px 0;
}

.table-caption .pagination {
    min-width: 150px;
    margin: 5px 20px 0 20px;
}


/*  filter forms */
/*  ------------ */
.shared-tablecaption-input {
	position: relative;
}

/*  Lite UI */
/*  -------------------------------------------------- */
.table-caption {
  margin-bottom: 10px;
}
/*  STANDARD TOUR */

.tourbar {
    background-color: #222;
    min-height: 46px;
    position: relative;
}

.tourbar .info-container {
  margin: 0px 200px;
  padding: 10px;
  background-color: #333;
  min-height: 26px;
}

.tourbar .info-container .info {
  font-size: 14px;
  color: #eee;
}

.tourbar .btn {
  background: transparent;
  filter: none;
  border-color: #999;
  color: #eee;
  text-shadow: none;
  box-shadow: none;
  top: 50%;
  margin-top: -13px;
  position: absolute;
}

.tourbar .btn.next {
  right: 158px;
}

.tourbar .btn.previous {
  left: 158px;
}

.tourbar .btn.close-btn {
  right: 10px;
}

.tourbar .close-container {
  float: right;
  margin: 10px 25px 10px 25px;
}

.tourbar .next-container {
  float: right;
  margin: 10px 0px 10px 25px;
}

.tourbar .previous-container {
  float: left;
  margin: 10px 25px;
}

.tour-highlight {
    position: relative;
}

.tour-highlight::after {
  content: "";
  position: absolute;
  right: -20px;
  top: -20px;
  height: 30px;
  width: 30px;
  z-index: 99999;
  background: url(data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+Cjxzdmcgd2lkdGg9IjIwcHgiIGhlaWdodD0iMjBweCIgdmlld0JveD0iMCAwIDIwIDIwIiB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHhtbG5zOnNrZXRjaD0iaHR0cDovL3d3dy5ib2hlbWlhbmNvZGluZy5jb20vc2tldGNoL25zIj4KICAgIDx0aXRsZT5VbnRpdGxlZCAyPC90aXRsZT4KICAgIDxkZXNjcmlwdGlvbj5DcmVhdGVkIHdpdGggU2tldGNoIChodHRwOi8vd3d3LmJvaGVtaWFuY29kaW5nLmNvbS9za2V0Y2gpPC9kZXNjcmlwdGlvbj4KICAgIDxkZWZzPjwvZGVmcz4KICAgIDxnIGlkPSJQYWdlLTEiIHN0cm9rZT0ibm9uZSIgc3Ryb2tlLXdpZHRoPSIxIiBmaWxsPSJub25lIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHNrZXRjaDp0eXBlPSJNU1BhZ2UiPgogICAgICAgIDxwYXRoIGQ9Ik02LjcxNDQ2NjA5LDYuNzE0NDY2MDkgTDAsMCBMMCwyMCBMMjAsMjAgTDEzLjc4NTUzMzksMTMuNzg1NTMzOSBMMjAuMDQ1OTQxNSw3LjUyNTEyNjI3IEwxMi45NzQ4NzM3LDAuNDU0MDU4NDU0IEw2LjcxNDQ2NjA5LDYuNzE0NDY2MDkgWiIgaWQ9IlRyaWFuZ2xlLTEiIGZpbGw9IiNEODVEM0MiIHNrZXRjaDp0eXBlPSJNU1NoYXBlR3JvdXAiPjwvcGF0aD4KICAgIDwvZz4KPC9zdmc+);
  background-size: 30px 30px;
  animation: highlightedElementAnimation 2s infinite alternate;
}

@keyframes highlightedElementAnimationFrames  {
    from { right: -20px; top: -20px; }
    to   { right: -30px; top: -30px; }
}


/*  IMAGE TOUR CAROUSEL */
.image-tour-container .carousel {
  width: 960px;
  height: 718px;
  background: #333;
  margin-bottom: 0;
}
.image-tour-container .carousel .carousel-control {
  top: 52%;
  background: none;
  border: none;
  color: #65A637;
  opacity: 1;
  left: 45px;
  font-size: 48px;
  z-index: 60;
}
.image-tour-container .carousel .carousel-control polygon {
  fill: #65A637;
}
.image-tour-container .carousel .carousel-control:hover polygon{
  fill: rgb(125, 195, 75);
}
.image-tour-container .carousel .carousel-control.disabled {
  display: none;
}
.image-tour-container .carousel .carousel-control:focus {
  box-shadow: none;
}
.image-tour-container .carousel .carousel-control.right {
  right: 45px;
  left: auto;
}
.image-tour-container .carousel .carousel-indicators {
  bottom: 18px;
  top: inherit;
  right: 50%;
  transform: translate(50%, 0);
  z-index: 60;
}
.image-tour-container .carousel .carousel-indicators li {
  height: 6px;
  width: 6px;
  cursor: pointer;
  background: #999;
  border: none;
  margin-left: 10px;
  margin-bottom: 0px;
}
.image-tour-container .carousel .carousel-indicators li.active {
  background-color: #65A637;
}
.image-tour-container .carousel .carousel-indicators li:first-child {
  margin-left: 0;
}
.image-tour-container .carousel .item {
  width: 960px;
  height: 716px;
}
.image-tour-container .carousel .item img {
  width:100%;
}
.image-tour-container .carousel .item.active img:hover {
  cursor: pointer;
}
.image-tour-container .carousel .help-link {
  position: absolute;
  width: 150px;
  height: 30px;
  top: 122px;
  left: 563px;
}
.image-tour-container .carousel a#splunk-answers {
  top: 160px;
  left: 504px;
  width: 140px;
}
.image-tour-container .tour-links {
  position: absolute;
  top: 15px;
  right: 5px;
  padding: 5px;
  text-align: right;
  z-index: 50;
  font-size: 12px;
}
.image-tour-container .tour-links a {
  color: #fff;
  margin-left: 15px;
}
.image-tour-container .tour-links a:hover {
  text-decoration: underline;
}
.image-tour-container .welcome-slide {
  position: absolute;
  top: 0;
  left: 0;
  z-index: 100;
}
.image-tour-container .tour-btn {
  background: rgba(0, 0, 0, 0.3);
  position: absolute;
  top: 300px;
  left: 50%;
  padding: 30px 40px;
  font-size: 30px;
  color: #fff;
  cursor: pointer;
  transform: translate(-50%, 0);
}
.image-tour-container .start-tour,
    .image-tour-container .exit-tour {
  color: #F58220;
}
.image-tour-container .tour-gutter {
  background: rgba(51, 51, 51, 0.9);
  height: 132px;
  width: 962px;
  font-size: 16px;
  color: #fff;
  position: absolute;
  bottom: 0px;
  z-index: 50;
  left: 50%;
  transform: translate(-50%, 0);
}
.image-tour-container .tour-gutter div.gutter-text {
  transform: translate(0, -50%);
  margin: 0 auto;
  position: relative;
  top: 50%;
  line-height: 150%;
  width: 720px;
  text-align: center;
}
.image-tour-container .tour-gutter a {
  color: #fff;
  text-decoration: underline;
}
.image-tour-container .carousel-assets {
  position: absolute;
  height: 132px;
  width: 960px;
  bottom: 0;
}
.image-tour-container .next-tour,
    .image-tour-container .try-it-now {
  display: none;
}
.image-tour-container .try-it-now {
  position: absolute;
  right: 30px;
  z-index: 500;
  bottom: 50px;
}
@media only screen and (max-height: 750px) {
    .image-tour-container .carousel-assets,
        .image-tour-container .tour-gutter {
    position: fixed;
  }
    .image-tour-container .carousel-assets {
    bottom: -132px;
    z-index: 60;
  }
    .image-tour-container .carousel-assets .carousel-control {
    top: inherit;
    bottom: 175px;
  }
    .image-tour-container .carousel-assets .carousel-indicators {
    bottom: 150px;
  }
    .image-tour-container .carousel-assets .tour-links {
    top: inherit;
    bottom: 220px;
  }
    .image-tour-container .carousel-assets .try-it-now {
    top: inherit;
    bottom: 180px;
  }
}

/*  IMAGE TOUR MODAL */
.image-tour .tour-modal {
    width: 960px;
    margin-left: -480px;
    height: 716px;
    background: #333;
    z-index: 1062;
}
.image-tour .tour-modal.fade.in {
  top: 15px;
}
.modal-backdrop.tour-backdrop.fade {
    background: #333;
    z-index: 1061;
}
.modal-backdrop.tour-backdrop.fade.in {
  opacity: 1;
  background: #333;
}

/*  INTERACTIVE TOUR */

.introjs-overlay {
    position: absolute;
    z-index: 999999;
    background-color: #000;
    opacity: 0;
    background: radial-gradient(center,ellipse cover,rgba(0, 0, 0, 0.4) 0,rgba(0, 0, 0, 0.9) 100%);
}
.introjs-fixParent {
    z-index: auto !important;
    opacity: 1.0 !important;
    position: absolute !important;
    transform: none !important;
    display: block !important;
}
.introjs-showElement,
tr.introjs-showElement > td,
tr.introjs-showElement > th {
    z-index: 9999999 !important;
    display: block !important;
}
.introjs-disableInteraction {
    z-index: 99999999 !important;
    position: absolute;
}
a.introjs-showElement {
    display: inline-block !important;
}
.introjs-relativePosition,
tr.introjs-showElement > td,
tr.introjs-showElement > th {
    position: relative;
}
.introjs-helperLayer {
    position: absolute;
    z-index: 9999998;
    background-color: rgba(255, 255, 255, 0.9);
    border: 1px solid rgba(0, 0, 0, 0.5);
    border-radius: 4px;
    box-shadow: 0 2px 15px rgba(0, 0, 0, 0.4);
}
.introjs-tooltipReferenceLayer {
    position: absolute;
    z-index: 10000000;
    background-color: transparent;
}
.introjs-helperLayer *,
.introjs-helperLayer *:before,
.introjs-helperLayer *:after {
    box-sizing: content-box;
}
.introjs-helperNumberLayer {
    position: absolute;
    top: -16px;
    left: -16px;
    z-index: 9999999999 !important;
    padding: 2px;
    font-size: 13px;
    font-weight: bold;
    color: white;
    text-align: center;
    text-shadow: 1px 1px 1px rgba(0, 0, 0, 0.3);
    background: linear-gradient(to bottom, #d6563c 0%, rgb(236, 174, 162) 100%);  /* W3C */
    width: 20px;
    height:20px;
    line-height: 20px;
    border: 3px solid white;
    border-radius: 50%;
    box-shadow: 0 2px 5px rgba(0, 0, 0, 0.4);
}

.introjs-arrow {
    border: 8px solid rgba(51, 51, 51, 0.9);
    content:'';
    position: absolute;
}
.introjs-arrow.top {
    top: -15px;
    border-top-color:transparent;
    border-right-color:transparent;
    border-bottom-color: rgba(51, 51, 51, 0.9);
    border-left-color:transparent;
}
.introjs-arrow.top-right {
    top: -15px;
    right: 10px;
    border-top-color:transparent;
    border-right-color:transparent;
    border-bottom-color: rgba(51, 51, 51, 0.9);
    border-left-color:transparent;
}
.introjs-arrow.top-middle {
    top: -15px;
    left: 50%;
    margin-left: -5px;
    border-top-color:transparent;
    border-right-color:transparent;
    border-bottom-color: rgba(51, 51, 51, 0.9);
    border-left-color:transparent;
}
.introjs-arrow.right {
    right: -15px;
    top: 15px;
    border-top-color:transparent;
    border-right-color:transparent;
    border-bottom-color:transparent;
    border-left-color: rgba(51, 51, 51, 0.9);
}
.introjs-arrow.right-bottom {
    bottom:10px;
    right: -15px;
    border-top-color:transparent;
    border-right-color:transparent;
    border-bottom-color:transparent;
    border-left-color: rgba(51, 51, 51, 0.9);
}
.introjs-arrow.bottom {
    bottom: -15px;
    border-top-color: rgba(51, 51, 51, 0.9);
    border-right-color:transparent;
    border-bottom-color:transparent;
    border-left-color:transparent;
}
.introjs-arrow.left {
    left: -15px;
    top: 10px;
    border-top-color:transparent;
    border-right-color: rgba(51, 51, 51, 0.9);
    border-bottom-color:transparent;
    border-left-color:transparent;
}
.introjs-arrow.left-bottom {
    left: -15px;
    bottom:10px;
    border-top-color:transparent;
    border-right-color: rgba(51, 51, 51, 0.9);
    border-bottom-color:transparent;
    border-left-color:transparent;
}
.introjs-tooltip {
    position: absolute;
    padding: 40px 60px 10px;
    text-align: center;
    color: #fff;
    background-color: rgba(51, 51, 51, 0.9);
    min-width: 400px;
    max-width: 500px;
    border-radius: 0;
    box-shadow: 0 1px 10px rgba(0, 0, 0, 0.4);
}
.introjs-tooltiptext a {
    color: #fff;
    text-decoration: underline;
}
.introjs-tooltipbuttons {
    text-align: right;
    white-space: nowrap;
}
.introjs-button {
    overflow: visible;
    padding: 5px;
    margin: 0;
    color: #65A637;
    fill: #65A637;
    text-decoration: none;
    font-size: 25px;
    cursor: pointer;
    outline: none;
    position: absolute;
    top: 50%;
    transform: translate(0, -45%);
}
.introjs-button:hover polygon{
  fill: rgb(125, 195, 75);
}
.introjs-button.introjs-disabled {
  display: none;
}
.introjs-button:focus {
  box-shadow: none;
  background: none;
}
.introjs-tooltiplinks {
    position: absolute;
    top: 10px;
    right: 5px;
}
.introjs-skipbutton,
.introjs-nexttourbutton {
    font-size: 12px;
    color: #fff;
    position: relative;
}
.introjs-skipbutton:hover, .introjs-nexttourbutton:hover {
  color: #fff;
}
.introjs-skipbutton:focus, .introjs-nexttourbutton:focus {
  color: #fff;
}
.introjs-skipbutton.done {
    color: #65A637;
}
.introjs-prevbutton {
    left: 10px;
}
.introjs-nextbutton {
   right: 10px;
}
.introjs-disabled,
.introjs-disabled:hover,
.introjs-disabled:focus {
    color: #999;
    box-shadow: none;
    cursor: default;
    background-image: none;
    text-decoration: none;
}
.introjs-bullets {
    text-align: center;
    padding-top: 30px;
}
.introjs-bullets ul {
    clear: both;
    margin: 15px auto 0;
    padding: 0;
    display: inline-block;
}
.introjs-bullets ul li {
  list-style: none;
  float: left;
  margin: 0 5px;
}
.introjs-bullets ul li a {
  display: block;
  width: 6px;
  height: 6px;
  background: #ccc;
  border-radius: 10px;
  text-decoration: none;
}
.introjs-bullets ul li a.active {
  background: #65A637;
}
.introjs-progress {
    overflow: hidden;
    height: 10px;
    margin: 10px 0 5px 0;
    border-radius: 4px;
    background-color: #eee;
}
.introjs-progressbar {
    float: left;
    width: 0%;
    height: 100%;
    font-size: 10px;
    line-height: 10px;
    text-align: center;
    background-color: #1e93c6;
}
.introjsFloatingElement {
    position: absolute;
    height: 0;
    width: 0;
    left: 50%;
    top: 50%;
}
.introjs-tooltiptext {
    font-size: 16px;
    line-height: 24px;
}

/*  tour links in product tours modal */
.tours-links {
    text-align: center;
}
.tour-link {
    position: relative;
    padding: 10px;
    margin-right: 20px;
    display: inline-block;
    color: #65A637;
    border: 1px solid #eee;
}
.tour-link:last-child {
  margin-right: 0;
}
.tour-link:hover,
    .tour-link:focus {
  background: rgba(101, 166, 55, 0.1);
  transition: background 0.15s linear;
  text-decoration: none;
}
.tour-link i {
  font-size: 40px;
  padding: 26px 32px;
}

/*  Lite UI */
.tour-link {
  color: #333;
}
.tour-link i {
  color: #F58220;
}
.tour-link:hover,
        .tour-link:focus {
  background: rgba(51, 51, 51, 0.1);
}
.shared-tour-producttours.fade {
  width: 600px;
  margin-left: -300px;
}
.try-it-now.btn-primary,
    .try-it-now.btn-primary:hover {
  background: #F58220;
}
.introjs-button {
  fill: #F58220;
}
.introjs-button:hover polygon {
  fill: rgb(247, 158, 80);
}
.introjs-bullets ul li a.active {
  background: #F58220;
}
.image-tour-container .carousel .carousel-indicators li.active {
  background-color: #F58220;
}
.image-tour-container .carousel .carousel-control polygon {
  fill: #F58220;
}
.image-tour-container .carousel .carousel-control:hover polygon {
  fill: rgb(247, 158, 80);
}
.introjs-skipbutton.done {
  color: #F58220;
}

/*  Components: common */
/*  Splunk: icons */
/*  ================= */
/*  override bootstrap glyph icons and replace with custom font icons */
/*  loosely based on [FontAwesome](http://fortawesome.github.com/Font-Awesome/) */
/*  see splunk [styleguide](http://localhost:8000/static/style-guide.html) for more details */

/*  Icon Font Face */
/*  ----------------- */

@font-face {
    font-family: 'Splunk Icons';
    src: url('/static/fonts/splunkicons-regular-webfont.woff') format('woff');
    font-weight: normal;
    font-style: normal;
    /*  unicode-range: U+00-FF; */
}

[class^="icon-"]:before,
[class*=" icon-"]:before {
    font-family: "Splunk Icons";
    font-style: normal;
    font-weight: normal;
    text-decoration: inherit;
}

a [class^="icon-"],
a [class*=" icon-"] {
    display: inline-block;
    text-decoration: none;
}

 /* makes the font 33% larger relative to the icon container */
.icon-large {
    font-size: 1.3333333333333333em;
    vertical-align: middle;
}

/*  Utils & helpers */
/*  ---------------- */


/*  utility for setting font-family */
/*  TODO: is this used? or needed? */
.font-icon {
    font-family: "Splunk Icons";
    font-size:inherit;
    line-height:inherit;
}

.icon-no-underline:first-child {
    padding-right: 0.3em;
}

.icon-no-underline:last-child {
    padding-left: 0.3em;
}

.icon-no-underline:first-child:last-child {
    padding-right: 0;
    padding-left: 0;
}


.icon-no-underline:before {
    text-decoration: none;
}

.padded-icon {
  margin-right: 0.5em;
}


/*image replace helper*/
.ir {
    position: relative;
    display: inline-block;
    min-width: 0.5em;
    text-indent: -9999px;
    outline:none;
    /*  vertical-align:middle; */
}
.ir:before {
    position: absolute;
    top: 0;
    left: 0;  /* Firefox needs to be explicit here */
    text-indent: 0;
}

/*  FONT ICONS */
/*  -------------- */

/* example

    <a href="#" class="icon-check">Check</a> -
    <a href="#" class="icon-check ir">Check</a>

*/

/*  when possible we should use the Unicode Private Use Area (PUA) to ensure screen
    readers do not read off random characters that represent icons */


/*  convert this ... */
/*      .icon-share:before                  {content: "\EC83 "; } */
/*  into this */
/*      <li class="icon-share"></li> */
/*  Search: */
/*      \.(icon-[^:]+).* */
/*  Replace: */
/*      <li class="$1"></li> */

/*splunk logo*/
.icon-splunk:before                 {content: "splunk"; }
.icon-greater:before                {content: ">"; }
.icon-hunk:before                   {content: "\F000"; }
.icon-enterprise:before             {content: "\F001"; }
.icon-cloud-logo:before             {content: "\F002"; }


/* shapes */
.icon-circle:before                 {content: "\ECD0"; }
.icon-circle-filled:before          {content: "\25CF"; }
.icon-box-filled:before             {content: "\25A0"; }
.icon-triangle-up-small:before      {content: "\25B4"; }
.icon-triangle-right:before         {content: "\25B6"; }
.icon-triangle-right-small:before   {content: "\25B8"; }
.icon-triangle-down:before          {content: "\25BC"; }
.icon-triangle-down-small:before    {content: "\25BE"; }
.icon-triangle-left:before          {content: "\25C0"; }
.icon-triangle-left-small:before    {content: "\25C2"; }


/*arrows & pointers*/
.icon-arrow-up:before               {content: "\EC01"; }
.icon-arrow-right:before            {content: "\27A1"; }
.icon-arrow-down:before             {content: "\EC02"; }
.icon-arrow-left:before             {content: "\EC00"; }

.icon-two-arrows-cycle:before       {content: "\EC12"; }
.icon-external:before               {content: "\EC13"; }

.icon-rotate-counter:before         {content: "\21BA"; }
.icon-rotate:before                 {content: "\21BB"; }

.icon-location:before               {content: "\EC80"; }

.icon-chevron-left:before           {content: "\2039"; }
.icon-chevron-right:before          {content: "\203A"; }
.icon-chevron-up:before             {content: "\2C4"; }
.icon-chevron-down:before           {content: "\2C5"; }



/*actions*/
.icon-trash:before                  {content: "\EC66"; }
.icon-share:before                  {content: "\27A6"; }
.icon-export:before                 {content: "\EC68"; }
.icon-print:before                  {content: "\EC89"; }
.icon-search:before                 {content: "\EC9B"; }
.icon-search-thin:before            {content: "\ECC2"; }
.icon-pivot:before                  {content: "\EC12"; }
.icon-clone:before                  {content: "\ECE8"; }

.icon-pause:before                  {content: "\EC50"; }
.icon-stop:before                   {content: "\25A0"; }
.icon-play:before                   {content: "\25B6"; }

.icon-sort:before                   {content: "\2195"; }
.icon-sorted-up:before              {content: "\21A5"; }
.icon-sorted-down:before            {content: "\21A7"; }

.icon-minus:before                  {content: "\2212"; }
.icon-minus-circle:before           {content: "\2296"; margin-right: 0.25em; }
.icon-plus:before                   {content: "+"; }
.icon-plus-circle:before            {content: "\2295"; }
.icon-x:before                      {content: "\2717"; }
.icon-x-circle:before               {content: "\2297"; }

.icon-close:before,
.icon-cancel:before                 {content: "\2717"; }

.icon-collapse-left:before          {content: "\ECE0"; }
.icon-expand-right:before           {content: "\ECE1"; }

.icon-fullscreen:before             {content: "\ECF3"; }
.icon-fullscreen-exit:before        {content: "\ECF4"; }

/*concepts*/
.icon-activity:before               {content: "\ECAE"; }
.icon-string:before                 {content: "a"; }
.icon-number:before                 {content: "#"; }
.icon-text:before                   {content: "\ECD9"; }
.icon-not-allowed:before            {content: "\EC9E"; }
.icon-data:before                   {content: "\ECA4"; }
.icon-data-input:before             {content: "\ECA3"; }
.icon-settings:before               {content: "\ECA5"; }
.icon-distributed-environment:before             {content: "\ECA6"; }
.icon-visible:before                {content: "\ECC0"; }
.icon-hidden:before                 {content: "\ECC1"; }
.icon-boolean:before                {content: "\ECD2"; }
.icon-menu:before,
.icon-rows:before                   {content: "\EC56"; }
.icon-tiles:before                  {content: "\ECF0"; }


/*misc*/
.icon-info:before                      {content: "i"; }
.icon-info-circle:before               {content: "I"; }
.icon-question:before  {
    font-family: inherit; /* Roboto */
    content: "?";
}
.icon-question-circle:before        {content: "\EC9D"; }
.icon-box-unchecked:before          {content: "\2610"; }
.icon-box-checked:before            {content: "\2611"; }
.icon-check-circle:before           {content: "\ECD3"; }
.icon-alert-circle:before           {content: "\ECD4"; }
.icon-code:before                   {content: "\ECD7"; }
.icon-code-thin:before              {content: "\ECD6"; }
.icon-alert:before,
.icon-error:before                  {content: "\26A0"; }
.icon-warning:before                {content: "\ECE2"; }

/*objects*/
.icon-bell:before                   {content: "\EC9C"; }
.icon-bookmark:before               {content: "\ECA1"; }
.icon-bulb:before                   {content: "\EC98"; }
.icon-calendar:before               {content: "\EC9A"; }
.icon-check:before                  {content: "\2713"; }
.icon-clock:before                  {content: "\231A"; }
.icon-cloud:before                  {content: "\2601"; }
.icon-flag:before                   {content: "\2691"; }
.icon-gear:before                   {content: "\2699"; }
.icon-lightning:before              {content: "\2301"; }
.icon-link:before                   {content: "\ECF1"; }
.icon-lock:before                   {content: "\EC9F"; }
.icon-lock-unlocked:before          {content: "\ECA0"; }
.icon-mail:before                   {content: "\2709"; }
.icon-pencil:before                 {content: "\270F"; }
.icon-speech-bubble:before          {content: "\EC99"; }
.icon-star:before                   {content: "\2605"; }
.icon-user:before                   {content: "\EC84"; }
.icon-clipboard:before              {content: "\ECD5"; }
.icon-paintbrush:before             {content: "\ECCA"; }
.icon-warning-sign:before           {content: "\26A0"; }


/*results and visualizations*/
.icon-chart-area:before             {content: "\ECA9"; }
.icon-chart-bar:before              {content: "\ECAA"; }
.icon-chart-column:before           {content: "\ECAB"; }
.icon-chart-pie:before              {content: "\ECAC"; }
.icon-chart-scatter:before          {content: "\ECAD"; }
.icon-chart-bubble:before           {content: "\ECB8"; }
.icon-chart-line:before             {content: "\ECAE"; }
.icon-single-value:before           {content: "\ECAF"; }
.icon-gauge-radial:before           {content: "\ECA2"; }
.icon-gauge-marker:before           {content: "\ECB0"; }
.icon-gauge-filler:before           {content: "\ECB1"; }
.icon-choropleth-map:before         {content: "\ECB9"; -webkit-font-smoothing: antialiased; -moz-osx-font-smoothing: grayscale; }
.icon-external-viz:before           {content: "\ECF2"; }
.icon-label-rotation--90:before     {content: "\ECE3"; }
.icon-label-rotation--45:before     {content: "\ECE4"; }
.icon-label-rotation-0:before       {content: "\ECE5"; }
.icon-label-rotation-45:before      {content: "\ECE6"; }
.icon-label-rotation-90:before      {content: "\ECE7"; }

.icon-chart-area-plus-table:before             {content: "\ECA9    +  \ECA8"; }
.icon-chart-bar-plus-table:before              {content: "\ECAA    +  \ECA8"; }
.icon-chart-column-plus-table:before           {content: "\ECAB    +  \ECA8"; }
.icon-chart-pie-plus-table:before              {content: "\ECAC    +  \ECA8"; }
.icon-chart-scatter-plus-table:before          {content: "\ECAD    +  \ECA8"; }
.icon-chart-bubble-plus-table:before           {content: "\ECB8    +  \ECA8"; }
.icon-chart-line-plus-table:before             {content: "\ECAE    +  \ECA8"; }
.icon-single-value-plus-table:before           {content: "\ECAF    +  \ECA8"; }
.icon-gauge-radial-plus-table:before           {content: "\ECA2    +  \ECA8"; }
.icon-gauge-marker-plus-table:before           {content: "\ECB0    +  \ECA8"; }
.icon-gauge-filler-plus-table:before           {content: "\ECB1    +  \ECA8"; }
.icon-location-plus-table:before               {content: "\EC80    +  \ECA8"; }
.icon-choropleth-map-plus-table:before         {content: "\ECB9    +  \ECA8"; -webkit-font-smoothing: antialiased; -moz-osx-font-smoothing: grayscale; }
.icon-external-viz-plus-table:before           {content: "\ECF2    +  \ECA8"; }

/*formatting*/
.icon-list:before                   {content: "\ECA7"; }
.icon-table:before                  {content: "\ECA8"; }
.icon-bar-beside:before             {content: "\ECB2"; }
.icon-bar-stacked:before            {content: "\ECB3"; }
.icon-bar-stacked-100:before        {content: "\ECB4"; }
.icon-missing-value-skipped:before  {content: "\ECB5"; }
.icon-missing-value-zero:before     {content: "\ECB6"; }
.icon-missing-value-join:before     {content: "\ECB7"; }


/*documents*/
.icon-folder:before                 {content: "\ECE9"; }
.icon-document:before               {content: "\ECC3"; }
.icon-report:before                 {content: "\ECC3"; }
.icon-report-search:before          {content: "\ECC4"; }
.icon-report-pivot:before           {content: "\ECC5"; }
.icon-dashboard:before              {content: "\ECC6"; }
.icon-panel:before                  {content: "\ECC7"; }
.icon-panel-search:before           {content: "\ECC8"; }
.icon-panel-pivot:before            {content: "\ECC9"; }

/*  Lite UI */
.lite .ir {
  display: none;
}
/*  Splunk: Popdown */
/*  ================ */
/*  TODO: review how this works with dropdown */

/* popdown for variable content

	<div class="popdown">
		<div class="popdown-dialog open">
			<div class="arrow"></div>
			<div class="popdown-dialog-body">
				content ...
			</div>
		</div>
	</div>

*/

/*  Popdown wrapper */
.popdown {
	position: relative
}

/*  popdown container */
.popdown-dialog {
	background-color: #fff;
	border: 1px solid #333;
	/* border-bottom-color: $interactiveBorderBottomColor; */
	/* border-top-color: $interactiveBorderTopColor; */
	/*  remove gradient for IE to fix clipping */
	filter: e(%("progid:DXImageTransform.Microsoft.gradient(enabled = false)"));
	box-shadow: 1px 2px 5px rgba(0,0,0,0.2);
	border-radius: 0;
	top: 100%;
	left: 50%;
	margin: 8px 0 0 -103px;
	display: none;
	position: absolute;
	z-index: 1060;
	/*  placement of arrow */
	white-space: normal;
}
/* prevent inheriting nowrap from btn-group */
.popdown-dialog .arrow {
  width: 0;
  height: 0;
  border-left: 8px solid transparent;
  border-right: 8px solid transparent;
  border-bottom: 8px solid #333;
  position: absolute;
  top: -8px;
  left: 50%;
  margin-left: -4px;
}
/*  generated arrow */
.popdown-dialog .arrow:before {
  content: "";
  display: block;
  width: 0;
  height: 0;
  border-left: 8px solid transparent;
  border-right: 8px solid transparent;
  border-bottom: 8px solid #fff;
  position: absolute;
  top: 1px;
  left: 0;
  margin-left: -8px;
}
.popdown-dialog.up {
  margin-top: 0;
}
/*  placement of arrow */
.popdown-dialog.up > .arrow {
  border-top: 8px solid #333;
  border-bottom: none;
  top: auto;
  bottom: -8px;
}
.popdown-dialog.up > .arrow:before {
  border-top: 8px solid #fff;
  border-bottom: none;
  position: absolute;
  top: auto;
  bottom: 1px;
}
.popdown-dialog.right {
  /* point left */
  margin-left: 5px;
  margin-top: 0;
}
/*  placement of arrow */
.popdown-dialog.right .arrow {
  border-right: 8px solid #333;
  border-top: 8px solid transparent;
  border-bottom: 8px solid transparent;
  border-left: none;
  top: 50%;
  left: -8px;
  margin: -8px 0 0 0 ;
}
.popdown-dialog.right .arrow:before {
  border-right: 8px solid #fff;
  border-top: 8px solid transparent;
  border-bottom: 8px solid transparent;
  border-left: none;
  position: absolute;
  top: 0;
  left: 1px;
  margin: -8px 0 0 0 ;
}
/*  position of arrow when floated right */
.popdown-dialog.pull-right .arrow {
  left: auto;
  right: 8px;
}
/*  open state */
.popdown-dialog.open {
  display: block;
}

/*  SPL-68751 - IE10 box shadow animation artifacts fix */
.popdown-dialog:after
{
    content: "";
    font-size: 0;
    display: inline;
    overflow: hidden;
}

/*  popdown body */
.popdown-dialog-body {
	margin: 0;
	border-radius: 0;
	background-color: #fff;
}
.popdown-dialog-body:before,
    .popdown-dialog-body:after {
  display: table;
  content: "";
  /*  Fixes Opera/contenteditable bug: */
  /*  http://nicolasgallagher.com/micro-clearfix-hack/#comment-36952 */
  line-height: 0;
}
.popdown-dialog-body:after {
  clear: both;
}

/*  popdown body */
.popdown-dialog-footer {
    border-top: 1px solid #ccc;
	padding: 5px;
	border-bottom-left-radius: 0;
	border-bottom-right-radius: 0;
}
.popdown-dialog-footer:before,
    .popdown-dialog-footer:after {
  display: table;
  content: "";
  /*  Fixes Opera/contenteditable bug: */
  /*  http://nicolasgallagher.com/micro-clearfix-hack/#comment-36952 */
  line-height: 0;
}
.popdown-dialog-footer:after {
  clear: both;
}

/*  variations */
/*  ------------ */

/* extends popdown-dialog, adds extra padding

	<div class="popdown">
		<div class="popdown-dialog popdown-dialog-padded open">
			<div class="arrow"></div>
			<div class="popdown-dialog-body">
				content ...
			</div>
		</div>
	</div>

*/
.popdown-dialog-padded {
	padding: 10px;
}

/*  Lite UI */

.popdown-dialog .field-info-header {
  border: 1px solid #333;
  border-bottom-color: #ccc;
  background: #f3f3f3;
}

/*  popdown body */

.popdown-dialog-footer {
  background: #f3f3f3;
}
/*  Splunk: Dropdown arrow/caret */
/*  =========================== */


.dropup,
.dropdown {
  position: relative;
}

.dropdown-toggle:active,
.open .dropdown-toggle {
  outline: 0;
}



/*  Caret / arrow */
/*  ----------- */

/* icon for caret

	<span class="caret"></span>
*/

.caret {
  display: inline-block;
  content: "";
  border:none;
  width: auto;
  height: auto;
  line-height: inherit;
  font-size: inherit;
  margin: 0;
  padding-left: 0.3em;
  text-decoration: none;
  vertical-align: baseline; /*  normally top or middle but this seems to break alignment and btn height */
  font-family: "Splunk Icons";
  font-weight: normal;
}

/*  generated font icon */

.caret:before {
  content: "\2C5";
  font-size: inherit;
  text-decoration: none;
}

.icon-no-underline + .caret {
    padding-left: 0;
}

.caret-char {
  font-weight: normal;
  font-family: "Splunk Icons";
  font-weight: normal;
}

.caret-char:before {
  content: "\25BE";
}

/*  Dropdowns */
/*  --------- */

.dropdown-menu  {
    float: left;
    min-width: 160px;
    list-style: none;
    word-wrap: break-word;
    width: 20em;
    line-height: 1.33333em;
    padding: 0;
    background-clip: padding-box;

    background-color: #fff;

    border: 1px solid #333;

    /* border-bottom-color: $interactiveBorderBottomColor; */

    /* border-top-color: $interactiveBorderTopColor; */

    /*  remove gradient for IE to fix clipping */

    filter: e(%("progid:DXImageTransform.Microsoft.gradient(enabled = false)"));

    box-shadow: 1px 2px 5px rgba(0,0,0,0.2);

    border-radius: 0;

    top: 100%;

    left: 50%;

    margin: 8px 0 0 -103px;

    display: none;

    position: absolute;

    z-index: 1060;

    /*  placement of arrow */

    white-space: normal;
}

.open > .dropdown-menu {
  display: block;
}

/* prevent inheriting nowrap from btn-group */

.dropdown-menu .arrow {
  width: 0;
  height: 0;
  border-left: 8px solid transparent;
  border-right: 8px solid transparent;
  border-bottom: 8px solid #333;
  position: absolute;
  top: -8px;
  left: 50%;
  margin-left: -4px;
}

/*  generated arrow */

.dropdown-menu .arrow:before {
  content: "";
  display: block;
  width: 0;
  height: 0;
  border-left: 8px solid transparent;
  border-right: 8px solid transparent;
  border-bottom: 8px solid #fff;
  position: absolute;
  top: 1px;
  left: 0;
  margin-left: -8px;
}

.dropdown-menu.up {
  margin-top: 0;
}

/*  placement of arrow */

.dropdown-menu.up > .arrow {
  border-top: 8px solid #333;
  border-bottom: none;
  top: auto;
  bottom: -8px;
}

.dropdown-menu.up > .arrow:before {
  border-top: 8px solid #fff;
  border-bottom: none;
  position: absolute;
  top: auto;
  bottom: 1px;
}

.dropdown-menu.right {
  /* point left */
  margin-left: 5px;
  margin-top: 0;
}

/*  placement of arrow */

.dropdown-menu.right .arrow {
  border-right: 8px solid #333;
  border-top: 8px solid transparent;
  border-bottom: 8px solid transparent;
  border-left: none;
  top: 50%;
  left: -8px;
  margin: -8px 0 0 0 ;
}

.dropdown-menu.right .arrow:before {
  border-right: 8px solid #fff;
  border-top: 8px solid transparent;
  border-bottom: 8px solid transparent;
  border-left: none;
  position: absolute;
  top: 0;
  left: 1px;
  margin: -8px 0 0 0 ;
}

/*  position of arrow when floated right */

.dropdown-menu.pull-right .arrow {
  left: auto;
  right: 8px;
}

/*  open state */

.dropdown-menu.open {
  display: block;
}

/*  Dividers (basically an hr) within the dropdown */

.dropdown-menu .divider {
  height: 1px;
  margin: 7px 1px;
  /*  8px 1px */
  overflow: hidden;
  background-color: #ccc;
}

.dropdown-menu li {
  position: relative;
}

/*  link style */

.dropdown-menu li > a {
  display: block;
  clear: both;
  font-weight: normal;
  line-height: 16px;
  position: relative;
  border-top: 1px dotted #ccc;
  color: #0095cf;
  padding: 5px 10px ;
  white-space: normal;
  text-decoration: none;
}

/* link info style */

.dropdown-menu .info, .dropdown-menu .title {
  color: #999;
}

.dropdown-menu ul li.info:not(:first-child) {
  border-top: 1px solid #ccc;
}

.dropdown-menu li.info {
  padding: 5px 10px;
}

.dropdown-menu li > a > .info  {
  display: block;
  font-size: 10.2px;
}

.dropdown-menu li > span.field-value {
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
  display: block;
  word-wrap: normal;
}

.dropdown-menu li.title {
  text-transform: uppercase;
  padding: 3px 10px;
}

/*  menu lists */

.dropdown-menu ul {
  list-style: none;
  margin: 0;
  border-radius: 0;
  background-color: #fff;
  /*  FIXME: this should be separate from popdown */
  overflow-x: hidden;
  overflow-y: auto;
  /* in rare cases that long strings increase the container size, this will minimize the issues */
  max-width: 100%;
  max-height: 270px;
  box-sizing: border-box;
  border-radius:0;
}

.dropdown-menu ul:before,
    .dropdown-menu ul:after {
  display: table;
  content: "";
  /*  Fixes Opera/contenteditable bug: */
  /*  http://nicolasgallagher.com/micro-clearfix-hack/#comment-36952 */
  line-height: 0;
}

.dropdown-menu ul:after {
  clear: both;
}

/*  give spacing to double lists */

.dropdown-menu ul + ul {
  margin-top: -1px;
}

.dropdown-menu ul + ul li:first-child > a, .dropdown-menu ul + ul li.title:first-child {
  border-top: 1px solid #333;
}

/*  rounding for first and last items */

.dropdown-menu .arrow + ul, .dropdown-menu .arrow + ul > li:first-child > a {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
  border-top: none;
}

.dropdown-menu ul:last-child, .dropdown-menu ul:last-child > li:last-child > a {
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
}

/*  for selectable lists */

.dropdown-menu a .icon-check {
  position: absolute;
  left: 5px;
  top: 5px;
}

.dropdown-menu [class^="icon-"], .dropdown-menu [class*=" icon-"] {
  width: 1.25em;
  text-align: center;
}

/*  focus state */

.dropdown-menu li > a:focus {
  outline: 0;
  text-decoration: none;
  background: rgba(61, 171, 255, 0.12);
  box-shadow: none;
  /* override default focus-link() */
}

/*  hover state */

.dropdown-menu li > a:hover{
  color: rgb(0, 77, 107);
  background: #ddd;
  background-color: rgb(221, 221, 221);
  background-image: linear-gradient(to bottom, #ddd, #ddd);
  /*  Standard, IE10 */
  background-repeat: repeat-x;
}

/*  disabled state */

.dropdown-menu > .disabled > a,
        .dropdown-menu > .disabled > a:hover,
        .dropdown-menu > .disabled > a:focus,
        .dropdown-menu li > a.disabled,
        .dropdown-menu li > a.disabled:hover,
        .dropdown-menu li > a.disabled:focus {
  color: #bbb;
  cursor: not-allowed;
}

.dropdown-menu > .disabled > a:hover,
        .dropdown-menu > .disabled > a:focus,
        .dropdown-menu li > a.disabled:hover,
        .dropdown-menu li > a.disabled:focus {
  text-decoration: none;
  background-color: transparent;
  background-image: none;
  /*  Remove CSS gradient */
  filter: e(%("progid:DXImageTransform.Microsoft.gradient(enabled = false)"));
  cursor: default;
}

/*  items with secondary action icons */

.dropdown-menu li > a.primary-link {
  margin-right: 40px;
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
  border-right: 1px dotted  #ccc;
}

.dropdown-menu li > a.secondary-link {
  position: absolute;
  right: 0;
  top: 0;
  bottom: 0;
  width: 40px;
  padding-left:0;
  padding-right: 0;
  font-size: 16px;
  text-align: center;
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}

.dropdown-menu li > a > .link-description {
  color: #999;
  display: block;
  font-size: 0.85em;
}

.dropdown-menu li.message {
  padding: 5px 10px;
}

/*  divider style */

.dropdown-menu .divider {
  margin: 0;
  border: none;
  border-top: 1px solid #333;
  margin-top: 0;
  height: 0;
}

/*  remove top border when there is already a divider */

.dropdown-menu .divider + li > a {
  border-top: none;
}

/* Searchable popdown's width */

.dropdown-menu .search-query {
  margin-left: 2px;
  width: 195px;
}

.dropdown-menu .footer-counter {
  text-align: center;
  border-top: 1px solid #333;
  line-height: 2em;
}

/*  truncated dropdown text */
.dropdown-truncated li > a {
    /*  wrapping */
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
}


/*  Sizes */
/*  ------------------- */


.dropdown-menu-narrow {
	width: 10em;
}

.dropdown-menu-medium {
    width: 25em;
}

.dropdown-menu-wide {
	width: 30em;
}

.dropdown-menu-width-auto {
	width: auto;
	max-width: 20em;

}

.dropdown-menu-width-auto.dropdown-menu-narrow {
  max-width: 10em;
}

.dropdown-menu-width-auto.dropdown-menu-medium {
  max-width: 25em;
}

.dropdown-menu-width-auto.dropdown-menu-wide {
  max-width: 30em;
}


/*  Selectable dropdown */
/*  ------------------- */

.dropdown-menu-selectable li > a { /*   BS 2.2 scoped */
	padding-left: 24px;
}


/*  Bootstrap Override */
/*  ------------------ */


.navbar .nav > li > .dropdown-menu:before,
.navbar .nav > li > .dropdown-menu:after
{
	display: none;
}

/*  hover state of dropdown submenu */
.dropdown-submenu:hover > a,
.dropdown-submenu:focus > a {
 	text-decoration: none;
 	color: rgb(0, 77, 107);
 	background: #ddd;
    background-color: rgb(221, 221, 221);
    background-image: linear-gradient(to bottom, #ddd, #ddd);
    /*  Standard, IE10 */
    background-repeat: repeat-x;
}

.dropdown-submenu > ul {
	overflow-x: hidden;
	overflow-y: auto;
}

.dropdown-header {
	display: block;
	padding: 3px 20px;
	font-size: 12px;
	line-height: 1.42857143;
	color: #999;
}


/*  fixed height dropdowns & popdowns */
/*  --------------------------------- */

.dropdown-menu-tall ul {
    max-height: 20em;
    overflow: auto;
}

.dropdown-menu-short ul {
    max-height: 10em;
    overflow: auto;
}

/*  disable scrolling */
.dropdown-menu-noscroll ul {
	max-height: none;
}


/*  Allow for dropdowns to go bottom up (aka, dropup-menu) */
/*  ------------------------------------------------------ */
/*  Just add .dropup after the standard .dropdown class and you're set, bro. */
/*  TODO: abstract this so that the navbar fixed styles are not placed here? */
/*  Reverse the caret */
.dropup .caret, .navbar-fixed-bottom .dropdown .caret {
  border-top: 0;
  border-bottom: 4px solid #000;
  content: "";
}
/*  Different positioning for bottom up menu */
.dropup .dropdown-menu, .navbar-fixed-bottom .dropdown .dropdown-menu {
  top: auto;
  bottom: 100%;
  margin-bottom: 1px;
}

/*  Sub menus */
/*  --------------------------- */
.dropdown-submenu {
    position: relative;
}
/*  Default dropdowns */
.dropdown-submenu > .dropdown-menu {
    top: 0;
    left: 100%;
    margin-top: -6px;
    margin-left: -1px;
    border-radius: 0 6px 6px 6px;
}
.dropdown-submenu:hover > .dropdown-menu {
    display: block;
}

/*  Dropups */
.dropup .dropdown-submenu > .dropdown-menu {
    top: auto;
    bottom: 0;
    margin-top: 0;
    margin-bottom: -2px;
    border-radius: 5px 5px 5px 0;
}

/*  Caret to indicate there is a submenu */
li.dropdown-submenu > a {
    padding-right: 20px;
}
li.dropdown-submenu > a:after {
  display: block;
  content: " ";
  position: absolute;
  width: 0;
  height: 0;
  border-color: transparent;
  border-style: solid;
  border-width: 5px 0 5px 5px;
  border-left-color: rgb(204, 204, 204);
  top: 50%;
  right: 10px;
  transform: translate(0, -50%);
}

/*  Left aligned submenus */
.dropdown-submenu.pull-left {
    /*  Undo the float */
    /*  Yes, this is awkward since .pull-left adds a float, but it sticks to our conventions elsewhere. */
    float: none;
}
/*  Positioning the submenu */
.dropdown-submenu.pull-left > .dropdown-menu {
  left: -100%;
  margin-left: 10px;
  border-radius: 6px 0 6px 6px;
}

/*  Tweak nav headers */
/*  ----------------- */
/*  Increase padding from 15px to 20px on sides */
.dropdown .dropdown-menu .nav-header {
    padding-left: 20px;
    padding-right: 20px;
}

/*  Typeahead */
/*  --------- */
.typeahead {
    z-index: 1051;
    margin-top: 2px; /*  give it some space to breathe */
    border-radius: 2px;
}


/*  Lite UI */
/*  ================ */
.dropdown-menu li > a {
  border-color: #ccc;
}
.dropdown-menu ul + ul li:first-child > a {
  border-color: #ccc;
}
.dropdown-menu .divider {
  border-top-color: #ccc;
}
/*  Component animations */
/*  -------------------------------------------------- */


.fade {
  opacity: 0;
  transition: opacity .15s linear;
}


.fade.in {
  opacity: 1;
}

.collapse {
  position: relative;
  height: 0;
  overflow: hidden;
  transition: height .35s ease;
}

.collapse.in {
  height: auto;
}
/*  Close icons */
/*  -------------------------------------------------- */


.close {
  float: right;
  
  border-radius: 2px;
  width: 27px;
  height: 27px;
  
  /* hide any placeholder text */
  color: transparent;
  font-size: 0;
  line-height: 0;
  text-align: center;
}


.close:before {
  font-family: "Splunk Icons";
  content: '\2717';
  font-size: 16px;
  color: rgba(51, 51, 51, 0.4);
  line-height: 27px;
}


.close:hover {
  background-color: #ddd;
  cursor: pointer;
  text-decoration: none;
}


.close:hover:before {
  color: rgb(0, 77, 107);
}


.close:focus {
  outline: 0;
  text-decoration: none;
  background: rgba(61, 171, 255, 0.12);
  box-shadow: none;
}


/* override default focus-link() */


.close:focus:before {
  color: rgb(0, 77, 107);
}

/*  Additional properties for button version */
/*  iOS requires the button element instead of an anchor tag. */
/*  If you want the anchor version, it requires `href="#"`. */
button.close {
  padding: 0;
  cursor: pointer;
  background: transparent;
  border: 0;
  -webkit-appearance: none;
}

/*  Components: Buttons & Alerts */
/*  Splunk: Buttons */
/*  =============== */


/*  Base styles & overrides */
/*  -------------------------------------------------- */

/* standard button class for use on a, button

        <a class="btn">Button</a>
        <a class="btn :hover">Button</a>
        <a class="btn active">Button</a>
        <button class="btn">Button</button>
*/

.btn {
    display: inline-block;
    padding: 4px 12px;
    margin-bottom: 0; /*  For input.btn */
    font-size: 12px;
    line-height: 16px;
    text-align: center;
    vertical-align: middle;
    cursor: pointer;

    background: #fff;

    border: 1px solid #333;

    color: #333;

    box-shadow: none;

    text-shadow: none;

    border-radius: 2px;
    border-radius: 2px;
}

/*  this breaks some bootstrap styles */

.btn:hover {
  background: #efefef;
  border-color: rgb(59, 59, 59);
  border-top-color: #333;
  border-bottom-color: #333;
  background-position: 0 0;
  text-decoration: none;
}

.btn.disabled,
    .btn[disabled],
    .btn.disabled:hover,
    .btn[disabled]:hover,
    .btn.disabled:focus,
    .btn[disabled]:focus {
  background: #ccc;
  filter: none;
  border-color: #ccc;
  border-top-color: #ccc;
  border-bottom-color: #ccc;
  cursor: not-allowed;
  color: #999;
  text-shadow: none;
  opacity: 0.65;
  box-shadow: none;
}

.btn.active {
  background: #efefef;
  border-color: rgb(59, 59, 59);
  border-top-color: #333;
  border-bottom-color: #333;
  background-position: 0 0;
  text-decoration: none;
  filter: none;
  color: #333;
}

.btn:focus {
  border-color: rgba(82, 168, 236, 0.8);
  outline: 0;
  background-position: 0;
  /*  bootstrap tries to animate this on hover & focus */
  background-color: #fff;
  border-collapse: separate;
  /* Fix IE9 Issue with box-shadow */
  box-shadow: none;
}

/*  Primary */
/*  ------------------- */

/* Provides extra visual weight and identifies the primary action in a set of buttons.

        <a class="btn btn-primary">Primary</a>
        <a class="btn btn-primary :hover">Primary</a>
        <a class="btn btn-primary active">Primary</a>
        <button class="btn btn-primary">Primary</button>
*/
.btn-primary {
    background: #333;
    border: 1px solid #333;
    color: #fff;
    box-shadow: none;
    text-shadow: none;
    border-radius: 2px;
}
.btn-primary:hover {
  background-color: #464646;
  color: #fff;
  text-decoration: none;
}
.btn-primary.active {
  background-color: #464646;
  color: #fff;
  text-decoration: none;
  filter: none;
  color: #fff;
}
.btn-primary:focus {
  border-color: rgba(82, 168, 236, 0.8);
  outline: 0;
  background-position: 0;
  /*  bootstrap tries to animate this on hover & focus */
  background-color: #fff;
  border-collapse: separate;
  /* Fix IE9 Issue with box-shadow */
  box-shadow: none;
  background: #333
}


/*  Other buttons */
/*  ------------------------- */

/*  Danger and error appear as red */
.btn-danger {
  /*  gradientBar will set the background to a pleasing blend of these, to support IE<=9 */
  color: #fff;
  text-shadow: 0 -1px 0 rgba(0,0,0,.25);
  background-color: rgb(218, 79, 73);
  background-image: linear-gradient(to bottom, #ee5f5b, #bd362f);
  /*  Standard, IE10 */
  background-repeat: repeat-x;
  border-color: rgba(0,0,0,.1) rgba(0,0,0,.1) rgba(0,0,0,.25);
  filter: e(%("progid:DXImageTransform.Microsoft.gradient(enabled = false)"));
}
/*  in these cases the gradient won't cover the background, so we override */
.btn-danger:hover, .btn-danger:focus, .btn-danger:active, .btn-danger.active, .btn-danger.disabled, .btn-danger[disabled] {
  color: #fff;
  background-color: #bd362f;
}
/*  Success appears as green */
.btn-success {
  /*  gradientBar will set the background to a pleasing blend of these, to support IE<=9 */
  color: #fff;
  text-shadow: 0 -1px 0 rgba(0,0,0,.25);
  background-color: rgb(91, 183, 91);
  background-image: linear-gradient(to bottom, #62c462, #51a351);
  /*  Standard, IE10 */
  background-repeat: repeat-x;
  border-color: rgba(0,0,0,.1) rgba(0,0,0,.1) rgba(0,0,0,.25);
  filter: e(%("progid:DXImageTransform.Microsoft.gradient(enabled = false)"));
}
/*  in these cases the gradient won't cover the background, so we override */
.btn-success:hover, .btn-success:focus, .btn-success:active, .btn-success.active, .btn-success.disabled, .btn-success[disabled] {
  color: #fff;
  background-color: #51a351;
}


/*  Links */
/*  ------------------------- */

/* pager style button pill
    Note: this does not inherit or extend btn base styles and is meant for links only

        <a href="#" class="btn-pill">Pill</a>
        <a href="#" class="btn-pill :hover">Pill</a>
        <a href="#" class="btn-pill :hover :active">Pill</a>
        <a href="#" class="btn-pill active">Pill</a>
*/
.btn-pill {
    display: inline-block;
    padding: 0 10px; /*  note the vertical padding will be funky unless it's block, inline-block, or floated */
    line-height: 27px;

    box-shadow: none !important;
}
/*  states */
.btn-pill:hover,
    .btn-pill.active,
    .btn-pill:focus
    {
  background-color: #ddd;
  text-decoration: none;
  border-radius: 2px;
}
.btn-pill.active
    {
  color: #999;
}
.btn-pill:focus {
  outline: 0;
  text-decoration: none;
  background: rgba(61, 171, 255, 0.12);
  box-shadow: none;
  /* override default focus-link() */
}
.btn-pill.disabled,
    .btn-pill.disabled:hover {
  color: #bbb;
  background: transparent;
  cursor: default;
}
.btn-pill.btn-square {
  padding: 0;
  height: 27px;
  width: 27px;
  text-align: center;
}


/*  Link buttons */
/*  -------------------------------------------------- */

/*  Make a button look and behave like a link */
.btn-link,
.btn-link:active,
.btn-link[disabled] {
  background-color: transparent;
  background-image: none;
  box-shadow: none;
}
.btn-link {
  border-color: transparent;
  cursor: pointer;
  color: #0095cf;
  border-radius: 0;
}
.btn-link:hover,
.btn-link:focus {
  color: rgb(0, 77, 107);
  text-decoration: underline;
  background-color: transparent;
}
.btn-link[disabled]:hover,
.btn-link[disabled]:focus {
  color: #333;
  text-decoration: none;
}


/*  Block button */
/*  ------------------------- */

.btn-block {
  display: block;
  width: 100%;
  padding-left: 0;
  padding-right: 0;
  box-sizing: border-box;
}

/*  Vertically space out multiple block buttons */
.btn-block + .btn-block {
  margin-top: 5px;
}

/*  Specificity overrides */
input[type="submit"].btn-block, input[type="reset"].btn-block, input[type="button"].btn-block {
  width: 100%;
}



/*  Draggable */
/*  ------------------------- */

/* draggable button styles

        <a class="btn btn-draggable">Draggable</a>
        <button class="btn btn-draggable">Draggable</button>
        <div class="btn-combo">
                <div class="btn btn-draggable">Combo</div>
                <div class="btn"><i class="icon-pencil"></i></div>
        </div>

*/
.btn-draggable {
    cursor:move;
    padding-left:15px;
    width: 113px; /*  160px - padding, border, etc */
    overflow: hidden;
    white-space: nowrap;
    text-overflow: ellipsis;
    text-align:left;
    position: relative;
}
/*  generated handle */
.btn-draggable:before, .btn-draggable .before {
  content: "";
  position: absolute;
  height: 18px;
  width: 7px;
  background: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAAECAYAAACp8Z5+AAAAG0lEQVQIW2M0Njb+f/bsWUYYzciABuAyOFUAAKKMEAXhn6ySAAAAAElFTkSuQmCC) repeat;
  top: 3px;
  left: 4px;
  opacity: 0.50;
}
/*  sizes */
.btn-draggable.btn-small:before{
  height: 14px;
}
.btn-draggable.btn-mini:before{
  height: 12px;
}



/*  Button Sizes */
/*  -------------------------------------------------- */

/*  Large */
.btn-large {
  padding: 11px 19px;
  font-size: 15px;
  border-radius: 6px;
}
.btn-large [class^="icon-"],
.btn-large [class*=" icon-"] {
  margin-top: 4px;
}

/*  Small */
.btn-small {
  padding: 2px 10px;
  font-size: 10.2px;
  border-radius: 3px;
}
.btn-small [class^="icon-"],
.btn-small [class*=" icon-"] {
  margin-top: 0;
}
.btn-mini [class^="icon-"],
.btn-mini [class*=" icon-"] {
  margin-top: -1px;
}

/*  Mini */
.btn-mini {
  padding: 0 6px;
  border-radius: 3px;
}

.btn-mini,
.btn-group > .btn-mini {
  font-size: 11px;
    line-height: 18px;
}

/*  Print */
/*  -------------------------------------------------- */
@media print {

    .btn {
        background: none !important;
        border: none !important;
        padding: 0 !important;
        color: #333 !important;
        text-shadow: none !important;
        box-shadow: none !important;
    }
    .caret {
        display: none !important;
    }
}
/*  Splunk: Button Groups */
/*  ===================== */
/*  BTN-GROUP handles rounding & spacing on btns & btn-combo */
/*  BTN-COMBO handles rounding on dropdowns & splits only, behaves like group but without grouping or spacing */

/* button combos, grouping and toolbar

    <div class="btn-toolbar">
        <div class="btn-group">
            <button class="btn">1</button> <button class="btn">2</button> <button class="btn">3</button>
            <div class="btn-combo">
                <button class="btn">Action</button>
                <button class="btn dropdown-toggle" data-toggle="dropdown">
                    <span class="caret"></span>
                </button>
                <ul class="dropdown-menu">
                    <li>
                        <a href="#">item 1</a>
                    </li>
                    <li>
                        <a href="#">item 2</a>
                    </li>
                    <li>
                        <a href="#">item 3</a>
                    </li>
                </ul>
            </div><!-- /.btn-combo -->
        </div><!-- /.btn-group -->
    </div><!-- /.btn-toolbar -->


*/
/*  Make the div behave like a button */
.btn-group {
    position: relative;
    display: inline-block;

    font-size: 0; /*  remove as part 1 of font-size inline-block hack */
    vertical-align: middle; /*  match .btn alignment given font-size hack above */
    white-space: nowrap; /*  prevent buttons from wrapping when in tight spaces (e.g., the table on the tests page) */
}

/*  Space out series of button groups */
.btn-group + .btn-group,
.btn-combo + .btn-combo  {
    margin-left: 10px;
}

 /*  Make the div behave like a button */
.btn-combo {
    position: relative;
    font-size: 0; /*  inline-block hack */
    white-space: nowrap;
    display:inline-block;
}

/*  Optional: Group multiple button groups together for a toolbar */
.btn-toolbar {
    font-size: 0; /*  Hack to remove whitespace that results from using inline-block */
    margin-top: 8px;
    margin-bottom: 8px;
}
/*  display inline for toolbar */
.btn-toolbar .btn-combo {
  display: inline-block;
}
.btn-toolbar > .btn + .btn,
    .btn-toolbar > .btn-group + .btn,
    .btn-toolbar > .btn + .btn-group,
    .btn-toolbar > .btn-combo + .btn,
    .btn-toolbar > .btn + .btn-combo {
  margin-left: 5px;
}


/*  Float them, remove border radius, then re-add to first and last elements */
.btn-group > .btn,
.btn-group > .btn-combo > .btn  {
    position: relative;
    border-radius: 0;
}
.btn-group > .btn + .btn {
    margin-left: -1px;
}


/*  Reset fibt sizes */
.btn-group > .btn,
.btn-group > .dropdown-menu,
.btn-group > .popover {
    font-size: 12px; /*  redeclare as part 2 of font-size inline-block hack */
}

/*  Reset fonts for other sizes */
.btn-group > .btn-mini {
    font-size: 9px;
}
.btn-group > .btn-small {
    font-size: 10.2px;
}
.btn-group > .btn-large {
    font-size: 15px;
}

/*  special case for btn-combo */
.btn-combo > .btn:first-child
{
    border-top-right-radius: 0;
    border-bottom-right-radius: 0;
}
/*  special case for btn-combo */
.btn-combo > .btn:last-child,
.btn-combo > .dropdown-toggle
{
    border-top-left-radius: 0;
    border-bottom-left-radius: 0;
}

/*  reset margin when in a group */
.btn-group > .btn-combo + .btn-combo ,
.btn-group > .btn-combo + .btn,
.btn-group > .btn + .btn-combo,
.btn-combo > .btn + .btn
{
    margin-left: -1px;
}

.btn-group > .btn,
.btn-combo > .btn,
.btn-group > .dropdown-menu,
.btn-combo > .dropdown-menu,
.btn-group > .btn-pill,
.btn-combo > .btn-pill,
.btn-group ul,
.btn-combo ul,
.btn-group .popdown-dialog,
.btn-combo .popdown-dialog,
.btn-group .dropdown-toggle,
.btn-combo .dropdown-toggle
{
    font-size: 12px; /*  redeclare as part 2 of font-size inline-block hack */
}

.btn-group > .btn-small,
.btn-combo > .btn-small,
.btn-group > .btn-mini,
.btn-combo > .btn-mini
{
    font-size: 11px; /*  redeclare as part 2 of font-size inline-block hack */
}

.btn-combo > .btn-large {
    font-size: 16px;
}


/*  Set corners individual because sometimes a single button can be in a .btn-group and we need :first-child and :last-child to both match */
.btn-group > .btn:first-child,
.btn-group > .btn-combo:first-child > .btn:first-child ,
.btn-group > .btn-combo:first-child > .drodown-toggle ,
.btn-combo:first-child > .btn:first-child,
.btn-group > .btn-combo:first-child > .btn:first-child
{
    margin-left: 0;
    border-top-left-radius: 2px;
    border-bottom-left-radius: 2px;
}
/*  Need .dropdown-toggle since :last-child doesn't apply given a .dropdown-menu immediately after it */
.btn-group > .btn:last-child,
.btn-group > .dropdown-toggle,
.btn-group > .btn-combo:last-child > .btn:last-child,
.btn-group > .btn-combo:last-child > .dropdown-toggle,
.btn-combo > .dropdown-toggle
{
    border-top-right-radius: 2px;
    border-bottom-right-radius: 2px;
}
/*  Reset corners for large buttons */
.btn-group > .btn.large:first-child,
.btn-group > .btn-combo:first-child > .btn.large:first-child {
    margin-left: 0;
    border-top-left-radius: 6px;
    border-bottom-left-radius: 6px;
}
.btn-group > .btn.large:last-child,
.btn-group > .large.dropdown-toggle,
.btn-group > .btn-combo:last-child > .btn.large:last-child,
.btn-group > .btn-combo:last-child > .large.dropdown-toggle {
    border-top-right-radius: 6px;
    border-bottom-right-radius: 6px;
}

/*  On hover/focus/active, bring the proper btn to front */
.btn-group > .btn:hover,
.btn-group > .btn:focus,
.btn-group > .btn:active,
.btn-group > .btn.active,
.btn-group > .btn-combo > .btn:hover,
.btn-group > .btn-combo > .btn:focus,
.btn-group > .btn-combo > .btn:active,
.btn-group > .btn-combo > .btn.active {
    z-index: 2;
}

/*  On active and open, don't show outline */
.btn-group .dropdown-toggle:active,
.btn-group.open .dropdown-toggle {
    outline: 0;
}



/*  Split button dropdowns */
/*  ---------------------- */


/*  Give the line between buttons some depth */
.btn-group > .btn-combo > .btn + .dropdown-toggle,
.btn-combo > .btn + .dropdown-toggle {
    padding-left: 8px;
    padding-right: 8px;
    box-shadow: inset 1px 0 0 rgba(255,255,255,.125), inset 0 1px 0 rgba(255,255,255,.2), 0 1px 2px rgba(0,0,0,.05);
}
.btn-group > .btn-mini + .dropdown-toggle,
.btn-group > .btn-combo > .btn-mini + .dropdown-toggle  {
    padding-left: 5px;
    padding-right: 5px;
}
.btn-group > .btn-large + .dropdown-toggle,
.btn-group > .btn-combo > .btn-large + .dropdown-toggle {
    padding-left: 12px;
    padding-right: 12px;
}

/*  Remove the gradient and set the same inset shadow as the :active state */

.btn-group.open .dropdown-toggle {
  background-image: none;
  box-shadow: inset 0 2px 4px rgba(0,0,0,.15), 0 1px 2px rgba(0,0,0,.05);
}

/*  Keep the hover's background when dropdown is open */

.btn-group.open .btn.dropdown-toggle {
  background-color: #efefef;
}

/*  The clickable button for toggling the menu */

.btn-group.open .btn-primary.dropdown-toggle {
  background-color: #464646;
}

.btn-group.open .btn-danger.dropdown-toggle {
  background-color: rgb(246, 218, 213);
}

.btn-group.open .btn-success.dropdown-toggle {
  background-color: #464646;
}

/* Prevent Tooltip from spacing two buttons */
.btn-group > .btn + div.tooltip + .btn {
    margin-left: -1px;
}

/* Square Buttons */
.btn-group .btn-square {
    padding: 0;
    height: 20px;
    width: 22px;
    font-size: 15px;
}
.btn-group .btn-square > i {
  line-height: 20px;
}

/*  Vertical button groups */
/*  ---------------------- */

.btn-group-vertical {
    display: inline-block; /*  makes buttons only take up the width they need */

}
.btn-group-vertical > .btn {
    display: block;
    float: none;
    max-width: 100%;
    border-radius: 0;
}
.btn-group-vertical > .btn + .btn {
    margin-left: 0;
    margin-top: -1px;
}
.btn-group-vertical > .btn:first-child {
    border-radius: 2px 2px 0 0;
}
.btn-group-vertical > .btn:last-child {
    border-radius: 0 0 2px 2px;
}
.btn-group-vertical > .btn-large:first-child {
    border-radius: 6px 6px 0 0;
}
.btn-group-vertical > .btn-large:last-child {
    border-radius: 0 0 6px 6px;
}



/*  input prepend fix */
.input-prepend .add-on:first-child,
.input-prepend .btn:first-child {
    border-radius: 2px 0 0 2px;
}

/*  input append fix for color ranges */
.input-append .add-on.color-picker-add-on,
.input-append.delta-time-range .btn:first-child {
    border-radius: 0 2px 2px 0;
}

.btn-group-radio > .btn {
  text-overflow: ellipsis;
  overflow: hidden;
}

.btn-group-radio > .btn.active, .btn-group-radio > .btn.active:hover {
  cursor: default;
  box-shadow: inset 0px 2px 2px rgba(0, 0, 0, 0.125);
  background-color: #efefef;
  color: #333;
}

.btn-group-radio > .btn.active:focus {
  cursor: default;
  box-shadow+: 0 0 8px rgba(82, 168, 236, 0.6);
}

/*  For synthetic radio with the "locale-responsive-layout" class, align the items vertically to accommodate long words (SPL-83062). */
body.locale-de .btn-group-radio.locale-responsive-layout {
  display: block;
}
body.locale-de .btn-group-radio.locale-responsive-layout .btn {
  border-radius: 0;
  display: block;
  width: 100%;
  margin-left: 0;
  border-bottom-width: 0;
}
body.locale-de .btn-group-radio.locale-responsive-layout .btn:first-child {
  border-radius: 2px 2px 0 0;
}
body.locale-de .btn-group-radio.locale-responsive-layout .btn:last-child {
  border-radius: 0 0 2px 2px;
  border-bottom-width: 1px;
}
/*  Splunk: Alerts */
/*  =================== */


/*  Alerts Container */
/*  ------------------------- */
.alerts:not(.alerts-view) {
    max-height: 500px;
    overflow-y: auto;
}


/*  Base styles */
/*  ------------------------- */

.alert {
    margin-bottom: 16px;
    border-radius: 2px;
    position: relative;
    padding: 8px 35px 8px 27px;
    word-wrap: break-word;
    color: #333;
}

.alert .icon-alert {
  font-size: 200%;
  position: absolute;
  left: 0px;
  top: 8px;
}

.alert h4 {
  color: inherit;
  margin: 0;
}

.alert .close {
  position: relative;
  top: -2px;
  right: -21px;
  line-height: 16px;
}

.alert-inline {
    display: inline-block;
    border: 0;
    margin-bottom: 0;
}



/*  Alert Levels */
/*  ------------------------- */

.alert-warning  .icon-alert {
    color: #f2b827;
}

.alert-warning  .icon-alert:before {
  content: '\ECE2';
}

.alert-info .icon-alert {
    color: #65A637;
}

.alert-info .icon-alert:before {
  content: 'I';
}

.alert-404 .icon-alert, .alert-error .icon-alert {
  color: #d6563c;
}


/*  Lite */
/*  ------------------------- */

.alert-info .icon-alert {
  color: #333;
}

/*  Components: Nav */
/*  Splunk: navs */
/*  ================================ */
/*  navigation styles and components */


/*  BASE CLASS */
/*  ---------- */

.nav {
  margin-left: 0;
  margin-bottom: 16px;
  list-style: none;
}

/*  Make links block level */
.nav > li > a {
  display: block;
}
.nav > li > a:hover,
.nav > li > a:focus {
  text-decoration: none;
  background-color: #eee;
}

/*  Redeclare pull classes because of specifity */
.nav > .pull-right {
  float: right;
}

/*  Nav headers (for dropdowns and lists) */
.nav-header {
  display: block;
  padding: 3px 15px;
  font-size: 11px;
  font-weight: bold;
  line-height: 16px;
  color: #999;
  text-shadow: 0 1px 0 rgba(255,255,255,.5);
  text-transform: uppercase;
}
/*  Space them out when they follow another list item (link) */
.nav li + .nav-header {
  margin-top: 9px;
}


/*  NAV LIST */
/*  -------- */

.nav-list {
  padding-left: 15px;
  padding-right: 15px;
  margin-bottom: 0;
}
.nav-list > li > a,
.nav-list .nav-header {
  margin-left:  -15px;
  margin-right: -15px;
  text-shadow: 0 1px 0 rgba(255,255,255,.5);
}
.nav-list > li > a {
  padding: 3px 15px;
}
.nav-list > .active > a,
.nav-list > .active > a:hover,
.nav-list > .active > a:focus {
  color: #fff;
  text-shadow: 0 -1px 0 rgba(0,0,0,.2);
  background-color: #0095cf;
}
.nav-list [class^="icon-"],
.nav-list [class*=" icon-"] {
  margin-right: 2px;
}
/*  Dividers (basically an hr) within the dropdown */
.nav-list .divider {
  height: 1px;
  margin: 7px 1px;
  /*  8px 1px */
  overflow: hidden;
  background-color: #ccc;
}



/*  TABS AND PILLS */
/*  ------------- */

/*  Common styles */
.nav-tabs:before,
    .nav-tabs:after,
    .nav-pills:before,
    .nav-pills:after {
  display: table;
  content: "";
  /*  Fixes Opera/contenteditable bug: */
  /*  http://nicolasgallagher.com/micro-clearfix-hack/#comment-36952 */
  line-height: 0;
}
.nav-tabs:after, .nav-pills:after {
  clear: both;
}
.nav-tabs > li,
.nav-pills > li {
  float: left;
}
.nav-tabs > li > a,
.nav-pills > li > a {
  padding-right: 12px;
  padding-left: 12px;
  margin-right: 2px;
  line-height: 14px; /*  keeps the overall height an even number */
}


/*  Tabs */
/*  ================== */


/* splunk style tabs
    * extends: nav
    * overrides: bootstrap default nav-tabs

    <ul class="nav nav-tabs">
        <li><a href="#">tab</a></li>
        <li class="active"><a href="#">tab</a></li>
        <li><a href="#">tab</a></li>
    </ul>

*/

.nav-tabs {
    background: #fff;
    border: 1px solid #333;
    color: #333;
    box-shadow: none;
    text-shadow: none;
    border-radius: 2px;
    border-left: none;
    border-right: none;
    padding: 0;
    height: 24px;
}

.nav-tabs > li {
  position: relative;
  margin: -1px 0 -1px -1px;
}

.nav-tabs > li:first-child {
  margin-left: -10px;
  padding-left: 10px;
}

.nav-tabs > li:before {
  content: '';
  display: block;
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  transform: skew(20deg, 0);
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
  /*  See https://github.com/twitter/bootstrap/issues/5319 */
  -webkit-backface-visibility: visible;
  backface-visibility: visible;
  background: #fff;
  border: 1px solid #333;
  color: #333;
  box-shadow: none;
  text-shadow: none;
  border-radius: 2px;
}

.nav-tabs > li:hover:before  {
  background: #efefef;
  border-color: rgb(59, 59, 59);
  border-top-color: #333;
  border-bottom-color: #333;
  background-position: 0 0;
  text-decoration: none;
  box-shadow: none;
}

.nav-tabs > li > a {
  border-radius: 0;
  border: none;
  padding: 0 30px 0 20px;
  margin: 0;
  line-height: 26px;
  color:#333;
  position: relative;
  background: none !important;
}

.nav-tabs > li > a:focus {
  box-shadow: 0 0 2px 1px #52A8EC;
  z-index:1;
}

/*  active state */

.nav-tabs > .active, .nav-tabs > .active:hover {
  margin: -1px 10px -1px -10px;
  border-bottom: 1px solid #fff;
}

.nav-tabs > .active:first-child, .nav-tabs > .active:hover:first-child {
  padding-left: 0;
}

.nav-tabs > .active:before, .nav-tabs > .active:hover:before {
  background: #fff;
  border: 1px solid #333;
  border-top-color: #333;
  border-bottom: 1px solid #fff;
  transform: skew(-20deg, 0);
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
  /*  See https://github.com/twitter/bootstrap/issues/5319 */
  -webkit-backface-visibility: visible;
  backface-visibility: visible;
  bottom: 0;
}

.nav-tabs > .active:after, .nav-tabs > .active:hover:after {
  content: '';
  display: block;
  position: absolute;
  top: 0;
  right: -10px;
  bottom: 0;
  width: 20px;
  background: #fff;
  border-right: 1px solid #333;
  border-top: 1px solid #333;
  border-bottom: 1px solid #fff;
  transform: skew(20deg, 0);
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
  /*  See https://github.com/twitter/bootstrap/issues/5319 */
  -webkit-backface-visibility: visible;
  backface-visibility: visible;
}

.nav-tabs > .active > a, .nav-tabs > .active > a:hover, .nav-tabs > .active > a:focus, .nav-tabs > .active:hover > a, .nav-tabs > .active:hover > a:hover, .nav-tabs > .active:hover > a:focus {
  position:relative;
  z-index: 1;
  filter: e(%("progid:DXImageTransform.Microsoft.gradient(enabled = false)"));
  border: none;
  outline-offset: -3px;
  padding: 0 30px;
  margin-right: -10px;
}/*  nav-tabs */



/*  PILLS */
/*  ----- */

/*  Links rendered as pills */
.nav-pills > li > a {
  padding-top: 8px;
  padding-bottom: 8px;
  margin-top: 2px;
  margin-bottom: 2px;
  border-radius: 5px;
}

/*  Active state */
.nav-pills > .active > a,
.nav-pills > .active > a:hover,
.nav-pills > .active > a:focus {
  color: #fff;
  background-color: #0095cf;
}







/*  STACKED NAV */
/*  ----------- */

/*  Stacked tabs and pills */
.nav-stacked > li {
  float: none;
}
.nav-stacked > li > a {
  margin-right: 0; /*  no need for the gap between nav items */
}

/*  Tabs */
.nav-tabs.nav-stacked {
  border-bottom: 0;
}
.nav-tabs.nav-stacked > li > a {
  border: 1px solid #ddd;
  border-radius: 0;
}
.nav-tabs.nav-stacked > li:first-child > a {
  border-top-right-radius: 4px;
  border-top-left-radius: 4px;
}
.nav-tabs.nav-stacked > li:last-child > a {
  border-bottom-right-radius: 4px;
  border-bottom-left-radius: 4px;
}
.nav-tabs.nav-stacked > li > a:hover,
.nav-tabs.nav-stacked > li > a:focus {
  border-color: #ddd;
  z-index: 2;
}

/*  Pills */
.nav-pills.nav-stacked > li > a {
  margin-bottom: 3px;
}
.nav-pills.nav-stacked > li:last-child > a {
  margin-bottom: 1px; /*  decrease margin to match sizing of stacked tabs */
}






/*  DROPDOWNS */
/*  --------- */

.nav-tabs .dropdown-menu {
  border-radius: 0 0 6px 6px; /*  remove the top rounded corners here since there is a hard edge above the menu */
}
.nav-pills .dropdown-menu {
  border-radius: 6px; /*  make rounded corners match the pills */
}

/*  Default dropdown links */
/*  ------------------------- */
/*  Make carets use linkColor to start */
.nav .dropdown-toggle .caret {
  border-top-color: #0095cf;
  border-bottom-color: #0095cf;
  margin-top: 6px;
}
.nav .dropdown-toggle:hover .caret,
.nav .dropdown-toggle:focus .caret {
  border-top-color: rgb(0, 77, 107);
  border-bottom-color: rgb(0, 77, 107);
}
/* move down carets for tabs */
.nav-tabs .dropdown-toggle .caret {
  margin-top: 8px;
}

/*  Active dropdown links */
/*  ------------------------- */
.nav .active .dropdown-toggle .caret {
  border-top-color: #fff;
  border-bottom-color: #fff;
}
.nav-tabs .active .dropdown-toggle .caret {
  border-top-color: #555;
  border-bottom-color: #555;
}

/*  Active:hover/:focus dropdown links */
/*  ------------------------- */
.nav > .dropdown.active > a:hover,
.nav > .dropdown.active > a:focus {
  cursor: pointer;
}

/*  Open dropdowns */
/*  ------------------------- */
.nav-tabs .open .dropdown-toggle,
.nav-pills .open .dropdown-toggle,
.nav > li.dropdown.open.active > a:hover,
.nav > li.dropdown.open.active > a:focus {
  color: #fff;
  background-color: #999;
  border-color: #999;
}
.nav li.dropdown.open .caret,
.nav li.dropdown.open.active .caret,
.nav li.dropdown.open a:hover .caret,
.nav li.dropdown.open a:focus .caret {
  border-top-color: #fff;
  border-bottom-color: #fff;
  opacity: 1.0;
}

/*  Dropdowns in stacked tabs */
.tabs-stacked .open > a:hover,
.tabs-stacked .open > a:focus {
  border-color: #999;
}



/*  TABBABLE */
/*  -------- */


/*  COMMON STYLES */
/*  ------------- */

/*  Clear any floats */
.tabbable:before,
    .tabbable:after {
  display: table;
  content: "";
  /*  Fixes Opera/contenteditable bug: */
  /*  http://nicolasgallagher.com/micro-clearfix-hack/#comment-36952 */
  line-height: 0;
}
.tabbable:after {
  clear: both;
}
.tab-content {
  overflow: auto; /*  prevent content from running below tabs */
}

/*  Remove border on bottom, left, right */
.tabs-below > .nav-tabs,
.tabs-right > .nav-tabs,
.tabs-left > .nav-tabs {
  border-bottom: 0;
}

/*  Show/hide tabbable areas */
.tab-content > .tab-pane,
.pill-content > .pill-pane {
  display: none;
}
.tab-content > .active,
.pill-content > .active {
  display: block;
}


/*  BOTTOM */
/*  ------ */

.tabs-below > .nav-tabs {
  border-top: 1px solid #ddd;
}
.tabs-below > .nav-tabs > li {
  margin-top: -1px;
  margin-bottom: 0;
}
.tabs-below > .nav-tabs > li > a {
  border-radius: 0 0 4px 4px;
}
.tabs-below > .nav-tabs > li > a:hover,
  .tabs-below > .nav-tabs > li > a:focus {
  border-bottom-color: transparent;
  border-top-color: #ddd;
}
.tabs-below > .nav-tabs > .active > a,
.tabs-below > .nav-tabs > .active > a:hover,
.tabs-below > .nav-tabs > .active > a:focus {
  border-color: transparent #ddd #ddd #ddd;
}

/*  LEFT & RIGHT */
/*  ------------ */

/*  Common styles */
.tabs-left > .nav-tabs > li,
.tabs-right > .nav-tabs > li {
  float: none;
}
.tabs-left > .nav-tabs > li > a,
.tabs-right > .nav-tabs > li > a {
  min-width: 74px;
  margin-right: 0;
  margin-bottom: 3px;
}

/*  Tabs on the left */
.tabs-left > .nav-tabs {
  float: left;
  margin-right: 19px;
  border-right: 1px solid #ddd;
}
.tabs-left > .nav-tabs > li > a {
  margin-right: -1px;
  border-radius: 4px 0 0 4px;
}
.tabs-left > .nav-tabs > li > a:hover,
.tabs-left > .nav-tabs > li > a:focus {
  border-color: #eee #ddd #eee #eee;
}
.tabs-left > .nav-tabs .active > a,
.tabs-left > .nav-tabs .active > a:hover,
.tabs-left > .nav-tabs .active > a:focus {
  border-color: #ddd transparent #ddd #ddd;
}

/*  Tabs on the right */
.tabs-right > .nav-tabs {
  float: right;
  margin-left: 19px;
  border-left: 1px solid #ddd;
}
.tabs-right > .nav-tabs > li > a {
  margin-left: -1px;
  border-radius: 0 4px 4px 0;
}
.tabs-right > .nav-tabs > li > a:hover,
.tabs-right > .nav-tabs > li > a:focus {
  border-color: #eee #eee #eee #ddd;
}
.tabs-right > .nav-tabs .active > a,
.tabs-right > .nav-tabs .active > a:hover,
.tabs-right > .nav-tabs .active > a:focus {
  border-color: #ddd #ddd #ddd transparent;
}



/*  DISABLED STATES */
/*  --------------- */

/*  Gray out text */
.nav > .disabled > a {
  color: #999;
}
/*  Nuke hover/focus effects */
.nav > .disabled > a:hover,
.nav > .disabled > a:focus {
  text-decoration: none;
  background-color: transparent;
  cursor: default;
}


/*  Lite */
/*  -------------------------------------------------- */

.nav-tabs {
  border-top-color: #ccc;
}

.nav-tabs > li.active a {
  font-weight: bold;
}

.nav-tabs > li:not(.active):before {
  border-top-color: #ccc;
  border-right-color: #ccc;
  border-left-color: #ccc;
}

.nav-tabs > li.active + li:before {
  border-left-color: #333;
}

/*  nav-tabs-lite */

.nav-tabs-lite {
  background: #fff;
  border: 1px solid #333;
  color: #333;
  box-shadow: none;
  text-shadow: none;
  border-radius: 2px;
  border: none;
  background: none !important;
  padding: 0;
  height: 24px;
}

.nav-tabs-lite li {
  display: inline-block;
  margin-right: 10px;
}

.nav-tabs-lite li > a {
  border: none;
  padding: 0 10px;
  margin: 0;
  line-height: 26px;
  color: #333;
  background: none !important;
}

.nav-tabs-lite li.active, .nav-tabs-lite li:hover {
  border-bottom: 2px solid #333;
}

.nav-tabs-lite li.active {
  font-weight: bold;
}

/*  nav-tabs-lite */

/*  fixes an alignment issue with out font based carets. */
.nav .dropdown-toggle .caret,
.nav-tabs .dropdown-toggle .caret,
.navbar .nav .dropdown-toggle .caret {
    margin-top: 0;
}

/*  Print */
@media print {
    header,
    .app-bar {
        display: none !important;
    }

    .main-tabs {
        border: none !important;
    }

    .main-tabs li:not(.active) {
    display: none !important;
  }

    .main-tabs li.active:before, .main-tabs li.active:after {
    display:none !important;
  }
}
/*  Navbars (Redux) */
/*  -------------------------------------------------- */


/*  COMMON STYLES */
/*  ------------- */

/*  Base class and wrapper */
.navbar {
  overflow: visible;
  margin-bottom: 16px;
}

/*  Inner for background effects */
/*  Gradient is applied to its own element because overflow visible is not honored by IE when filter is present */
.navbar-inner {
  min-height: 40px;
  padding-left:  20px;
  padding-right: 20px;
  background-color: rgb(173, 173, 173);
  background-image: linear-gradient(to bottom, #ffffff, #333);
  /*  Standard, IE10 */
  background-repeat: repeat-x;
  border: 1px solid rgb(20, 20, 20);
  border-radius: 2px;
  box-shadow: 0 1px 4px rgba(0,0,0,.065);
}
/*  Prevent floats from breaking the navbar */
.navbar-inner:before,
    .navbar-inner:after {
  display: table;
  content: "";
  /*  Fixes Opera/contenteditable bug: */
  /*  http://nicolasgallagher.com/micro-clearfix-hack/#comment-36952 */
  line-height: 0;
}
.navbar-inner:after {
  clear: both;
}

/*  Set width to auto for default container */
/*  We then reset it for fixed navbars in the #gridSystem mixin */
.navbar .container {
  width: auto;
}

/*  Override the default collapsed state */
.nav-collapse.collapse {
  height: auto;
  overflow: visible;
}


/*  Brand: website or project name */
/*  ------------------------- */
.navbar .brand {
  float: left;
  display: block;
  /*  Vertically center the text given $navbarHeight */
  padding: 12px 20px 12px;
  margin-left: -20px; /*  negative indent to left-align the text down the page */
  font-size: 20px;
  font-weight: 200;
  color: #777;
  text-shadow: 0 1px 0 #ffffff;
}
.navbar .brand:hover,
  .navbar .brand:focus {
  text-decoration: none;
}

/*  Plain text in topbar */
/*  ------------------------- */
.navbar-text {
  margin-bottom: 0;
  line-height: 40px;
  color: #777;
}

/*  Janky solution for now to account for links outside the .nav */
/*  ------------------------- */
.navbar-link {
  color: #777;
}
.navbar-link:hover,
  .navbar-link:focus {
  color: #333;
}

/*  Dividers in navbar */
/*  ------------------------- */
.navbar .divider-vertical {
  height: 40px;
  margin: 0 9px;
  border-left: 1px solid #333;
  border-right: 1px solid #ffffff;
}

/*  Buttons in navbar */
/*  ------------------------- */
.navbar .btn,
.navbar .btn-group {
  margin-top: 5px; /*  Vertically center in navbar */
}
.navbar .btn-group .btn,
.navbar .input-prepend .btn,
.navbar .input-append .btn,
.navbar .input-prepend .btn-group,
.navbar .input-append .btn-group {
  margin-top: 0; /*  then undo the margin here so we don't accidentally double it */
}

/*  Navbar forms */
/*  ------------------------- */
.navbar-form {
  margin-bottom: 0;
}
/*  remove default bottom margin */
.navbar-form:before,
    .navbar-form:after {
  display: table;
  content: "";
  /*  Fixes Opera/contenteditable bug: */
  /*  http://nicolasgallagher.com/micro-clearfix-hack/#comment-36952 */
  line-height: 0;
}
.navbar-form:after {
  clear: both;
}
.navbar-form input,
  .navbar-form select,
  .navbar-form .radio,
  .navbar-form .checkbox {
  margin-top: 5px;
  /*  Vertically center in navbar */
}
.navbar-form input,
  .navbar-form select,
  .navbar-form .btn {
  display: inline-block;
  margin-bottom: 0;
}
.navbar-form input[type="image"],
  .navbar-form input[type="checkbox"],
  .navbar-form input[type="radio"] {
  margin-top: 3px;
}
.navbar-form .input-append,
  .navbar-form .input-prepend {
  margin-top: 5px;
  white-space: nowrap;
}
/*  preven two  items from separating within a .navbar-form that has .pull-left */
.navbar-form .input-append input, .navbar-form .input-prepend input {
  margin-top: 0;
  /*  remove the margin on top since it's on the parent */
}

/*  Navbar search */
/*  ------------------------- */
.navbar-search {
  position: relative;
  float: left;
  margin-top: 5px; /*  Vertically center in navbar */
  margin-bottom: 0;
}
.navbar-search .search-query {
  margin-bottom: 0;
  padding: 4px 14px;
  font-family: Georgia, "Times New Roman", Times, serif;
  font-size: 13px;
  font-weight: normal;
  line-height: 1;
  border-radius: 15px;
  /*  redeclare because of specificity of the type attribute */
}



/*  Static navbar */
/*  ------------------------- */

.navbar-static-top {
  position: static;
  margin-bottom: 0;
}

/*  remove 18px margin for default navbar */

.navbar-static-top .navbar-inner {
  border-radius: 0;
}



/*  Fixed navbar */
/*  ------------------------- */

/*  Shared (top/bottom) styles */
.navbar-fixed-top,
.navbar-fixed-bottom {
  position: fixed;
  right: 0;
  left: 0;
  z-index: 1030;
  margin-bottom: 0; /*  remove 18px margin for default navbar */
}
.navbar-fixed-top .navbar-inner,
.navbar-static-top .navbar-inner {
  border-width: 0 0 1px;
}
.navbar-fixed-bottom .navbar-inner {
  border-width: 1px 0 0;
}
.navbar-fixed-top .navbar-inner,
.navbar-fixed-bottom .navbar-inner {
  padding-left:  0;
  padding-right: 0;
  border-radius: 0;
}

/*  Reset container width */
/*  Required here as we reset the width earlier on and the grid mixins don't override early enough */
.navbar-static-top .container,
.navbar-fixed-top .container,
.navbar-fixed-bottom .container {
  width: 940px;
}

/*  Fixed to top */
.navbar-fixed-top {
  top: 0;
}
.navbar-fixed-top .navbar-inner, .navbar-static-top .navbar-inner {
  box-shadow: 0 1px 10px rgba(0,0,0,.1);
}

/*  Fixed to bottom */
.navbar-fixed-bottom {
  bottom: 0;
}
.navbar-fixed-bottom .navbar-inner {
  box-shadow: 0 -1px 10px rgba(0,0,0,.1);
}



/*  NAVIGATION */
/*  ---------- */

.navbar .nav {
  position: relative;
  left: 0;
  display: block;
  float: left;
  margin: 0 10px 0 0;
}
.navbar .nav.pull-right {
  float: right; /*  redeclare due to specificity */
  margin-right: 0; /*  remove margin on float right nav */
}
.navbar .nav > li {
  float: left;
}

/*  Links */
.navbar .nav > li > a {
  float: none;
  /*  Vertically center the text given $navbarHeight */
  padding: 12px 15px 12px;
  color: #777;
  text-decoration: none;
  text-shadow: 0 1px 0 #ffffff;
}
.navbar .nav .dropdown-toggle .caret {
  margin-top: 8px;
}

/*  Hover/focus */
.navbar .nav > li > a:focus,
.navbar .nav > li > a:hover {
  background-color: transparent; /*  "transparent" is default to differentiate :hover/:focus from .active */
  color: #333;
  text-decoration: none;
}

/*  Active nav items */
.navbar .nav > .active > a,
.navbar .nav > .active > a:hover,
.navbar .nav > .active > a:focus {
  color: #555;
  text-decoration: none;
  background-color: rgb(38, 38, 38);
  box-shadow: inset 0 3px 8px rgba(0,0,0,.125);
}

/*  Navbar button for toggling navbar items in responsive layouts */
/*  These definitions need to come after '.navbar .btn' */
.navbar .btn-navbar {
  display: none;
  float: right;
  padding: 7px 10px;
  margin-left: 5px;
  margin-right: 5px;
  /*  gradientBar will set the background to a pleasing blend of these, to support IE<=9 */
  color: #fff;
  text-shadow: 0 -1px 0 rgba(0,0,0,.25);
  background-color: rgb(160, 160, 160);
  background-image: linear-gradient(to bottom, rgb(242, 242, 242), rgb(38, 38, 38));
  /*  Standard, IE10 */
  background-repeat: repeat-x;
  border-color: rgba(0,0,0,.1) rgba(0,0,0,.1) rgba(0,0,0,.25);
  filter: e(%("progid:DXImageTransform.Microsoft.gradient(enabled = false)"));
  box-shadow: inset 0 1px 0 rgba(255,255,255,.1), 0 1px 0 rgba(255,255,255,.075);
}
/*  in these cases the gradient won't cover the background, so we override */
.navbar .btn-navbar:hover, .navbar .btn-navbar:focus, .navbar .btn-navbar:active, .navbar .btn-navbar.active, .navbar .btn-navbar.disabled, .navbar .btn-navbar[disabled] {
  color: #fff;
  background-color: rgb(38, 38, 38);
}
.navbar .btn-navbar .icon-bar {
  display: block;
  width: 18px;
  height: 2px;
  background-color: #f5f5f5;
  border-radius: 1px;
  box-shadow: 0 1px 0 rgba(0,0,0,.25);
}
.btn-navbar .icon-bar + .icon-bar {
  margin-top: 3px;
}



/*  Dropdown menus */
/*  -------------- */

/*  Menu position and menu carets */
.navbar .nav > li > .dropdown-menu:before {
  content: '';
  display: inline-block;
  border-left:   7px solid transparent;
  border-right:  7px solid transparent;
  border-bottom: 7px solid #ccc;
  border-bottom-color: #ccc;
  position: absolute;
  top: -7px;
  left: 9px;
}
.navbar .nav > li > .dropdown-menu:after {
  content: '';
  display: inline-block;
  border-left:   6px solid transparent;
  border-right:  6px solid transparent;
  border-bottom: 6px solid #fff;
  position: absolute;
  top: -6px;
  left: 10px;
}
/*  Menu position and menu caret support for dropups via extra dropup class */
.navbar-fixed-bottom .nav > li > .dropdown-menu:before {
  border-top: 7px solid #ccc;
  border-top-color: #ccc;
  border-bottom: 0;
  bottom: -7px;
  top: auto;
}
.navbar-fixed-bottom .nav > li > .dropdown-menu:after {
  border-top: 6px solid #fff;
  border-bottom: 0;
  bottom: -6px;
  top: auto;
}

/*  Caret should match text color on hover/focus */
.navbar .nav li.dropdown > a:hover .caret,
.navbar .nav li.dropdown > a:focus .caret {
  border-top-color: #333;
  border-bottom-color: #333;
}

/*  Remove background color from open dropdown */
.navbar .nav li.dropdown.open > .dropdown-toggle,
.navbar .nav li.dropdown.active > .dropdown-toggle,
.navbar .nav li.dropdown.open.active > .dropdown-toggle {
  background-color: rgb(38, 38, 38);
  color: #555;
}
.navbar .nav li.dropdown > .dropdown-toggle .caret {
  border-top-color: #777;
  border-bottom-color: #777;
}
.navbar .nav li.dropdown.open > .dropdown-toggle .caret,
.navbar .nav li.dropdown.active > .dropdown-toggle .caret,
.navbar .nav li.dropdown.open.active > .dropdown-toggle .caret {
  border-top-color: #555;
  border-bottom-color: #555;
}

/*  Right aligned menus need alt position */
.navbar .pull-right > li > .dropdown-menu,
.navbar .nav > li > .dropdown-menu.pull-right {
  left: auto;
  right: 0;
}
.navbar .pull-right > li > .dropdown-menu:before, .navbar .nav > li > .dropdown-menu.pull-right:before {
  left: auto;
  right: 12px;
}
.navbar .pull-right > li > .dropdown-menu:after, .navbar .nav > li > .dropdown-menu.pull-right:after {
  left: auto;
  right: 13px;
}
.navbar .pull-right > li > .dropdown-menu .dropdown-menu, .navbar .nav > li > .dropdown-menu.pull-right .dropdown-menu {
  left: auto;
  right: 100%;
  margin-left: 0;
  margin-right: -1px;
  border-radius: 6px 0 6px 6px;
}


/*  Inverted navbar */
/*  ------------------------- */

.navbar-inverse .navbar-inner {
  background-color: rgb(27, 27, 27);
  background-image: linear-gradient(to bottom, #222222, #111111);
  /*  Standard, IE10 */
  background-repeat: repeat-x;
  border-color: #252525;
}

.navbar-inverse .brand,
  .navbar-inverse .nav > li > a {
  color: #999;
  text-shadow: 0 -1px 0 rgba(0,0,0,.25);
}

.navbar-inverse .brand:hover,
    .navbar-inverse .brand:focus,
    .navbar-inverse .nav > li > a:hover,
    .navbar-inverse .nav > li > a:focus {
  color: #fff;
}

.navbar-inverse .brand {
  color: #999;
}

.navbar-inverse .navbar-text {
  color: #999;
}

.navbar-inverse .nav > li > a:focus,
  .navbar-inverse .nav > li > a:hover {
  background-color: transparent;
  color: #fff;
}

.navbar-inverse .nav .active > a,
  .navbar-inverse .nav .active > a:hover,
  .navbar-inverse .nav .active > a:focus {
  color: #fff;
  background-color: #111111;
}

/*  Inline text links */

.navbar-inverse .navbar-link {
  color: #999;
}

.navbar-inverse .navbar-link:hover,
    .navbar-inverse .navbar-link:focus {
  color: #fff;
}

/*  Dividers in navbar */

.navbar-inverse .divider-vertical {
  border-left-color: #111111;
  border-right-color: #222222;
}

/*  Dropdowns */

.navbar-inverse .nav li.dropdown.open > .dropdown-toggle,
  .navbar-inverse .nav li.dropdown.active > .dropdown-toggle,
  .navbar-inverse .nav li.dropdown.open.active > .dropdown-toggle {
  background-color: #111111;
  color: #fff;
}

.navbar-inverse .nav li.dropdown > a:hover .caret,
  .navbar-inverse .nav li.dropdown > a:focus .caret {
  border-top-color: #fff;
  border-bottom-color: #fff;
}

.navbar-inverse .nav li.dropdown > .dropdown-toggle .caret {
  border-top-color: #999;
  border-bottom-color: #999;
}

.navbar-inverse .nav li.dropdown.open > .dropdown-toggle .caret,
  .navbar-inverse .nav li.dropdown.active > .dropdown-toggle .caret,
  .navbar-inverse .nav li.dropdown.open.active > .dropdown-toggle .caret {
  border-top-color: #fff;
  border-bottom-color: #fff;
}

/*  Navbar search */

.navbar-inverse .navbar-search .search-query {
  color: #fff;
  background-color: rgb(82, 82, 82);
  border-color: #111111;
  box-shadow: inset 0 1px 2px rgba(0,0,0,.1), 0 1px 0 rgba(255,255,255,.15);
  transition: none;
}

.navbar-inverse .navbar-search .search-query::-webkit-input-placeholder {
  color: #ccc;
}

.navbar-inverse .navbar-search .search-query::-moz-placeholder {
  color: #ccc;
}

.navbar-inverse .navbar-search .search-query:-ms-input-placeholder {
  color: #ccc;
}

.navbar-inverse .navbar-search .search-query::placeholder {
  color: #ccc;
}

.navbar-inverse .navbar-search .search-query:focus {
  padding: 5px 15px;
  color: #333;
  text-shadow: 0 1px 0 #fff;
  background-color: #fff;
  border: 0;
  box-shadow: 0 0 3px rgba(0,0,0,.15);
  outline: 0;
}

/*  Navbar collapse button */

.navbar-inverse .btn-navbar {
  /*  gradientBar will set the background to a pleasing blend of these, to support IE<=9 */
  color: #fff;
  text-shadow: 0 -1px 0 rgba(0,0,0,.25);
  background-color: rgb(14, 14, 14);
  background-image: linear-gradient(to bottom, rgb(20, 20, 20), rgb(5, 5, 5));
  /*  Standard, IE10 */
  background-repeat: repeat-x;
  border-color: rgba(0,0,0,.1) rgba(0,0,0,.1) rgba(0,0,0,.25);
  filter: e(%("progid:DXImageTransform.Microsoft.gradient(enabled = false)"));
}

/*  in these cases the gradient won't cover the background, so we override */

.navbar-inverse .btn-navbar:hover, .navbar-inverse .btn-navbar:focus, .navbar-inverse .btn-navbar:active, .navbar-inverse .btn-navbar.active, .navbar-inverse .btn-navbar.disabled, .navbar-inverse .btn-navbar[disabled] {
  color: #fff;
  background-color: rgb(5, 5, 5);
}
/*  Splunk: Component: paginator */
/*  ============================ */
/*  TODO: should this be in base? */

/* pagination styles and overrides

    <div class="pagination">
        <ul>
            <li><a href="#">Prev</a></li>
            <li><a href="#">1</a></li>
            <li><a href="#">2</a></li>
            <li><a href="#">3</a></li>
            <li><a href="#">4</a></li>
            <li><a href="#">Next</a></li>
        </ul>
    </div>

*/

.pagination {
    height: auto;

}

.pagination > ul {
  display: inline-block;
  /*  Reset default ul styles */
  margin-left: 0;
  margin-bottom: 0;
  list-style: none;
}

.pagination > ul > li {
  float: left;
}

.pagination > ul > li > span,
        .pagination > ul > li > a {
  float: left;
  text-decoration: none;
  border: 1px solid transparent;
  line-height: 20px;
  min-width: 10px;
  padding: 2px 8px;
  text-align: center;
  border-radius: 2px;
}

.pagination > ul > li > span:focus, .pagination > ul > li > a:focus {
  outline: 0;
  text-decoration: none;
  background: rgba(61, 171, 255, 0.12);
  box-shadow: none;
  /* override default focus-link() */
}

/*  hover & active state */

.pagination > ul > li > a:hover,
        .pagination > ul .active > a
        {
  background-color: #ddd;
}

.pagination > ul .active > a {
  cursor: default;
}

.pagination > ul .icon-chevron-left, .pagination > ul .icon-triangle-left-small {
  padding-right: 3px;
}

.pagination > ul .icon-chevron-right, .pagination > ul .icon-triangle-right-small {
  padding-left: 3px;
}

.pagination > ul > .disabled > span,
            .pagination > ul > .disabled > a,
            .pagination > ul > .disabled > a:hover,
            .pagination > ul > .disabled > a:focus {
  background-color: transparent;
  color: #bbb;
  cursor: default;
}

.pagination .max-events-per-bucket {
  color: #f2b827;
  font-size: 18px;
}

/*  missing sequence dots */

.pagination .dots,
    .pagination .dots:hover {
  width: 20px;
  padding: 0px;
}/*  .pagination */



/*  Alignment */
/*  -------------------------------------------------- */

.pagination-centered {
  text-align: center;
}
.pagination-right {
  text-align: right;
}

/*  Large */
/*  -------------------------------------------------- */
.pagination-large ul > li > a,
  .pagination-large ul > li > span {
  padding: 11px 19px;
  font-size: 15px;
}
.pagination-large ul > li:first-child > a,
  .pagination-large ul > li:first-child > span {
  border-top-left-radius: 6px;
  border-bottom-left-radius: 6px;
}
.pagination-large ul > li:last-child > a,
  .pagination-large ul > li:last-child > span {
  border-top-right-radius: 6px;
  border-bottom-right-radius: 6px;
}

/*  Small and mini */
/*  -------------------------------------------------- */
.pagination-mini ul > li:first-child > a,
  .pagination-mini ul > li:first-child > span,
  .pagination-small ul > li:first-child > a,
  .pagination-small ul > li:first-child > span {
  border-top-left-radius: 3px;
  border-bottom-left-radius: 3px;
}
.pagination-mini ul > li:last-child > a,
  .pagination-mini ul > li:last-child > span,
  .pagination-small ul > li:last-child > a,
  .pagination-small ul > li:last-child > span {
  border-top-right-radius: 3px;
  border-bottom-right-radius: 3px;
}

/*  Small */
/*  -------------------------------------------------- */
.pagination-small ul > li > a,
  .pagination-small ul > li > span {
  padding: 2px 10px;
  font-size: 10.2px;
}
/*  Mini */
/*  -------------------------------------------------- */
.pagination-mini ul > li > a,
  .pagination-mini ul > li > span {
  padding: 0 6px;
  font-size: 9px;
}
/*  Pager pagination */
/*  -------------------------------------------------- */


.pager {
  margin: 16px 0;
  list-style: none;
  text-align: center;
}


.pager:before,
    .pager:after {
  display: table;
  content: "";
  /*  Fixes Opera/contenteditable bug: */
  /*  http://nicolasgallagher.com/micro-clearfix-hack/#comment-36952 */
  line-height: 0;
}


.pager:after {
  clear: both;
}
.pager li {
  display: inline;
}
.pager li > a,
.pager li > span {
  display: inline-block;
  padding: 5px 14px;
  background-color: #fff;
  border: 1px solid #ddd;
  border-radius: 15px;
}
.pager li > a:hover,
.pager li > a:focus {
  text-decoration: none;
  background-color: #f5f5f5;
}
.pager .next > a,
.pager .next > span {
  float: right;
}
.pager .previous > a,
.pager .previous > span {
  float: left;
}
.pager .disabled > a,
.pager .disabled > a:hover,
.pager .disabled > a:focus,
.pager .disabled > span {
  color: #999;
  background-color: #fff;
  cursor: default;
}

/*  Components: Popovers */
/*  Splunk: Modals */
/*  ============== */

/*  TODO: the close button seems to have issues on placement */

/* modal windows

    <div class="modal fade">
        <div class="modal-header">
            <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>
            <h3>Modal header</h3>
        </div>
        <div class="modal-body">
            <p>One fine body…</p>
        </div>
        <div class="modal-footer">
            <a href="#" class="btn">Close</a>
            <a href="#" class="btn btn-primary">Save changes</a>
        </div>
    </div>

    <!-- static example -->
    <div style="position: relative; top: auto; left: auto; margin: 0 auto 20px; z-index: 1; max-width: 100%;" class="modal">
        <div class="modal-header">
            <button aria-hidden="true" data-dismiss="modal" class="close" type="button">×</button>
            <h3>Modal header</h3>
         </div>
        <div class="modal-body">
            <p>One fine body…</p>
         </div>
        <div class="modal-footer">
            <a class="btn" href="#">Close</a>
            <a class="btn btn-primary" href="#">Save changes</a>
        </div>
    </div>

*/

/*  Background */
.modal-backdrop {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 1040;
  background-color: #000;
}
/*  Fade for backdrop */
.modal-backdrop.fade {
  opacity: 0;
}

.modal-backdrop,
.modal-backdrop.fade.in {
    opacity: 0.40;
}

 /*  modal container */
.modal {
    position: fixed;
    top: 40px;
    left: 50%;
    width: 450px;
    margin-left: -225px;
    z-index: 1050;
    background-color: #fff;
    border: none;
    border-radius: 6px;
    box-shadow: 0 3px 7px rgba(0,0,0,0.3);
    background-clip: padding-box;
    /*  Remove focus outline from opened modal */
    outline: none;
}
.modal.fade {
  transition: opacity .2s linear, top .2s ease-out;
  top: 0;
}
.modal.fade.in {
  top: 40px
}/*  modal */

/*  SPL-68751 - IE10 box shadow animation artifacts fix */
.modal:after {
    content: "";
    font-size: 0;
    display: inline;
    overflow: hidden;
}

/*  modal header */

.modal-header {
    border: none;
    border-bottom: 1px solid #ccc;
    position: relative;
    background: #f3f3f3;
    padding: 15px 0 15px 20px;
    border-top-left-radius: 8px;
    border-top-right-radius: 8px;
}

/*  heading */

.modal-header h3, .modal-header .modal-title {
  line-height: 22px;
  margin: 0;
  overflow-wrap: break-word;
  padding-right: 40px;
}

.modal-header h3 {
  line-height: 30px;
  /*  This doesn't appear to do anything in the standard modal because .modal-title has greater specificity. */
}

/*  close button */

.modal-header .close {
  top: 15px;
  right: 15px;
  position: absolute;
}
/*  modal body */
.modal-body {
    position: relative;
    overflow-y: auto;
    padding: 20px;
    overflow: visible;
    max-height:360px;
}

/*  Remove bottom margin if need be */
.modal-form {
    margin-bottom: 0;
}

.modal-body-scrolling {
    overflow-y: auto;
}
/*  modal footer */
.modal-footer {
    padding: 10px;
    margin-bottom: 0;
    text-align: right; /*  right align buttons */
    background: #f3f3f3;
    border-top: 1px solid #ccc;
    border-radius: 0 0 8px 8px; /*  clear it in case folks use .pull-* classes on buttons */
}
.modal-footer:before,
    .modal-footer:after {
  display: table;
  content: "";
  /*  Fixes Opera/contenteditable bug: */
  /*  http://nicolasgallagher.com/micro-clearfix-hack/#comment-36952 */
  line-height: 0;
}
.modal-footer:after {
  clear: both;
}
/*  Properly space out buttons */
.modal-footer .btn + .btn {
  margin-left: 5px;
  margin-bottom: 0;
  /*  account for input[type="submit"] which gets the bottom margin like all other inputs */
}
/*  but override that for button groups */
.modal-footer .btn-group .btn + .btn {
  margin-left: -1px;
}
/*  and override it for block buttons as well */
.modal-footer .btn-block + .btn-block {
  margin-left: 0;
}

/*  Modal Varations */
/*  =============== */

/*  extends modal; sets width & offset */
.modal-wide {
    width: 800px;
    margin-left: -400px;
}

/*  Disconnect needs to be above other modals */
.modal.disconnection-warning-modal {
    z-index: 1090;
}

.shared-splunkbar-messages-noconnectionoverlay .modal-backdrop {
    z-index: 1080;
}

/*  loading ... */
.modal-loading {
    text-align: center;
    color: #999;
}


/*  What's New Dialog */
/*  -------------- */

.modal.shared-whatsnewdialog {
    width: 900px;
    margin-left: -450px;
}

.modal.shared-whatsnewdialog .modal-body {
    padding-right: 0;
}

.shared-whatsnewdialog h2 {
    font-weight: 200;
    font-size: 24px;
    margin: 0 0 20px -20px;
    padding-left: 20px;
}

.shared-whatsnewdialog .feature {
    display:inline-block;
    width: 260px;
    margin: 0 20px 20px 0;
    position: relative;
    vertical-align: top;
}

.shared-whatsnewdialog .feature > h3 {
    margin: 0 0 5px 0;
}

.shared-whatsnewdialog .feature > img {
    display: block;
    width: 100%;
    height: 170px;
    border: 1px solid #ccc;
    margin-bottom: 10px;
}

.shared-whatsnewdialog .feature > p {
    margin: 0;
}

.shared-whatsnewdialog .feature + h2 {
    padding-top: 20px;
    border-top: 1px dotted #ccc;
}


/*  responsive modal adjustments */
/*  ---------------------------- */

/*  small screen */
@media only screen and (max-height: 449px) {
    .modal {
        top: 10px;
    }
    .modal.fade {
    top: 0;
  }
    .modal.fade.in {
    top: 10px
  }
    .modal .modal-body {
    max-height:180px;
  }
}

/*  medium screen */
@media only screen and (min-height: 449px) and (max-height: 550px) {
    .modal {
        top: 20px;
    }
    .modal.fade {
    top: 0;
  }
    .modal.fade.in {
    top: 20px
  }
    .modal .modal-body {
    max-height:280px;
  }
}

/*  large screen */
@media only screen and (min-height: 650px) and (max-height: 749px) {
    .modal .modal-body {
        max-height:450px;
    }
}

/*  xlarge screen */
@media only screen and (min-height: 750px) {
    .modal .modal-body {
        max-height:550px;
    }
}

/*  Lite UI */
.modal {
  border: 1px solid #333;
  border-radius: 0;
}
.modal .close {
  opacity: 1.0;
}
.modal .close:before {
  color: #333;
}
.modal-header {
  border-bottom-color: #999;
}
.modal-footer {
  border-top-color: #999;
}
/*  Tooltips */
/*  -------------------------------------------------- */


/*  Base class */
.tooltip {
  position: absolute;
  z-index: 1070;
  display: block;
  visibility: visible;
  font-size: 11px;
  line-height: 1.4;
  opacity: 0.0;
}
.tooltip.in     {
  opacity: 0.80;
}
.tooltip.top    {
  margin-top:  -3px;
  padding: 5px 0;
}
.tooltip.right  {
  margin-left:  3px;
  padding: 0 5px;
}
.tooltip.bottom {
  margin-top:   3px;
  padding: 5px 0;
}
.tooltip.left   {
  margin-left: -3px;
  padding: 0 5px;
}

/*  Wrapper for the tooltip content */
.tooltip-inner {
  max-width: 200px;
  padding: 8px;
  color: #fff;
  text-align: center;
  text-decoration: none;
  background-color: rgba(0,0,0,0.9);
  border-radius: 2px;
}

/*  Arrows */
.tooltip-arrow {
  position: absolute;
  width: 0;
  height: 0;
  border-color: transparent;
  border-style: solid;
}
.tooltip.top .tooltip-arrow {
  bottom: 0;
  left: 50%;
  margin-left: -5px;
  border-width: 5px 5px 0;
  border-top-color: rgba(0,0,0,0.9);
}
.tooltip.right .tooltip-arrow {
  top: 50%;
  left: 0;
  margin-top: -5px;
  border-width: 5px 5px 5px 0;
  border-right-color: rgba(0,0,0,0.9);
}
.tooltip.left .tooltip-arrow {
  top: 50%;
  right: 0;
  margin-top: -5px;
  border-width: 5px 0 5px 5px;
  border-left-color: rgba(0,0,0,0.9);
}
.tooltip.bottom .tooltip-arrow {
  top: 0;
  left: 50%;
  margin-left: -5px;
  border-width: 0 5px 5px;
  border-bottom-color: rgba(0,0,0,0.9);
}

/*  Components: Misc */
/*  Thumbnails */
/*  -------------------------------------------------- */


/*  Note: `.thumbnails` and `.thumbnails > li` are overriden in responsive files */

/*  Make wrapper ul behave like the grid */
.thumbnails {
  margin-left: -20px;
  list-style: none;
}
.thumbnails:before,
    .thumbnails:after {
  display: table;
  content: "";
  /*  Fixes Opera/contenteditable bug: */
  /*  http://nicolasgallagher.com/micro-clearfix-hack/#comment-36952 */
  line-height: 0;
}
.thumbnails:after {
  clear: both;
}
/*  Fluid rows have no left margin */
.row-fluid .thumbnails {
  margin-left: 0;
}

/*  Float li to make thumbnails appear in a row */
.thumbnails > li {
  float: left; /*  Explicity set the float since we don't require .span* classes */
  margin-bottom: 16px;
  margin-left: 20px;
}

/*  The actual thumbnail (can be `a` or `div`) */
.thumbnail {
  display: block;
  padding: 4px;
  line-height: 16px;
  border: 1px solid #ddd;
  border-radius: 2px;
  box-shadow: 0 1px 3px rgba(0,0,0,.055);
  transition: all .2s ease-in-out;
}
/*  Add a hover/focus state for linked versions only */
a.thumbnail:hover,
a.thumbnail:focus {
  border-color: #0095cf;
  box-shadow: 0 1px 4px rgba(0,105,214,.25);
}

/*  Images and captions */
.thumbnail > img {
  display: block;
  max-width: 100%;
  margin-left: auto;
  margin-right: auto;
}
.thumbnail .caption {
  padding: 9px;
  color: #555;
}
/*  Labels & Badges Overrides */
/*  ======================== */



/*  Base classes */
.label,
.badge {
  display: inline-block;
  padding: 2px 4px;
  font-size: 10.152px;
  font-weight: bold;
  line-height: 14px; /*  ensure proper line-height if floated */
  color: #fff;
  vertical-align: baseline;
  white-space: nowrap;
  text-shadow: 0 -1px 0 rgba(0,0,0,.25);
  background-color: #999;
}
/*  Set unique padding and border-radii */
.label {
  border-radius: 3px;
}
.badge {
  padding-left: 9px;
  padding-right: 9px;
  border-radius: 9px;
}

/*  Empty labels/badges collapse */
.label:empty, .badge:empty {
  display: none;
}

/*  Hover/focus state, but only for links */
a.label:hover,
  a.label:focus,
  a.badge:hover,
  a.badge:focus {
  color: #fff;
  text-decoration: none;
  cursor: pointer;
}

/*  Colors */
/*  Only give background-color difference to links (and to simplify, we don't qualifty with `a` but [href] attribute) */
/*  Important (red) */
.label-important,         .badge-important         {
  background-color: rgb(250, 233, 230);
}
.label-important[href],   .badge-important[href]   {
  background-color: rgb(242, 195, 187);
}
/*  Warnings (orange) */
.label-warning,           .badge-warning           {
  background-color: #ed8440;
}
.label-warning[href],     .badge-warning[href]     {
  background-color: rgb(229, 104, 21);
}
/*  Success (green) */
.label-success,           .badge-success           {
  background-color: #a2cc3e;
}
.label-success[href],     .badge-success[href]     {
  background-color: rgb(132, 169, 45);
}
/*  Info (turquoise) */
.label-info,              .badge-info              {
  background-color: #3a87ad;
}
.label-info[href],        .badge-info[href]        {
  background-color: rgb(45, 104, 134);
}
/*  Inverse (black) */
.label-inverse,           .badge-inverse           {
  background-color: #333;
}
.label-inverse[href],     .badge-inverse[href]     {
  background-color: rgb(26, 26, 26);
}

/*  Quick fix for labels/badges in buttons */
.btn .label,
  .btn .badge {
  position: relative;
  top: -1px;
}
.btn-mini .label,
  .btn-mini .badge {
  top: 0;
}



/*  Labels */
/*  ------ */

/*  TODO: use vars here */
.label {
	padding: 1px 4px 0 4px;
	border-radius: 4px;
	line-height: 17px;
	font-size: 11px;
	font-weight: normal;
	text-transform: uppercase;
	color: #333;
	text-shadow: none;
	background-color: #ccc;
	border: 1px solid #333;
}
/*  icons in labels */
.label [class*="icon-"]{
  font-size: 16px;
  margin-right: 3px;
  vertical-align: middle;
}
/*  Important (red) */
.label-important {
  background-color: rgb(250, 233, 230);
  border-color: #d6563c;
  color: #d6563c;
}
/*  Warnings (orange) */
.label-warning {
  background-color: rgb(252, 237, 227);
  border-color: #ed8440;
  color: #ed8440;
}
/*  Success (green) */
.label-success {
  background-color: rgb(239, 246, 223);
  border-color: #a2cc3e;
  color: #a2cc3e;
}
/*  Info (yellow) */
.label-info {
  background-color: rgb(253, 244, 221);
  border-color: rgb(217, 159, 13);
  color: rgb(217, 159, 13);
}
/*  Inverse (black) */
.label-inverse {
  background-color: #555;
  border-color: #333;
  color: #fff;
}
/*  Splunk: Progress Bars */
/*  ================ */


/*  ANIMATIONS */
/*  ---------- */

@keyframes progress-bar-stripes {
  from  { background-position: 40px 0; }
  to    { background-position: 0 0; }
}



/*  Spinners */
/*  ---------------------------- */

.spinner-small-gray {
	background-image: url("/static/img/skins/default/loading_small_gray.png");
	background-position: left top;
	width: 14px;
	height: 14px;
	background-size: 112px 14px;
}



.spinner-medium-green {
	background-image: url("/static/img/skins/default/loading_medium_green.png");
	background-position: left top;
	width: 19px;
	height: 19px;
	background-size: 152px 19px;
}


@media (-webkit-min-device-pixel-ratio: 2), (min-resolution: 192dpi) {
	.spinner-small-gray {
		background-image: url("/static/img/skins/default/loading_small_gray_2x.png");
	}

	.spinner-medium-green {
		background-image: url("/static/img/skins/default/loading_medium_green_2x.png");
	}
}


/*  Progress */
/*  ---------------------------- */
/* This is suppose to match Bootstrap, but it doesn't. */
.progress {
    overflow: hidden;
    height: 16px;
    margin-bottom: 16px;
    background-color: rgb(247, 247, 247);
    background-image: linear-gradient(to bottom, #f5f5f5, #f9f9f9);
    /*  Standard, IE10 */
    background-repeat: repeat-x;
	box-shadow: inset 0 1px 2px rgba(0,0,0,.1);
	background-color: #f3f3f3;
	border-radius: 2px;
}
/* Bootstrap uses the .bar class, but our standard components use .progress-bar */
.progress .bar,
    .progress .progress-bar {
  width: 0%;
  height: 100%;
  color: #fff;
  float: left;
  font-size: 12px;
  text-align: center;
  transition: width .6s ease;
}
.progress .bar {
  background-color: rgb(31, 154, 208);
  background-image: linear-gradient(to bottom, #1e93c6, rgb(33, 165, 222));
  /*  Standard, IE10 */
  background-repeat: repeat-x;
  box-shadow: inset 0 -1px 0 rgba(0,0,0,.15);
  box-sizing: border-box;
}
.progress .bar + .bar {
  box-shadow: inset 1px 0 0 rgba(0,0,0,.15), inset 0 -1px 0 rgba(0,0,0,.15);
}
.progress .progress-bar {
  line-height: 16px;
  background-color: #65A637;
}
.progress .progress-striped.progress-bar {
  background-color: #65A637;
  background-image: linear-gradient(45deg, rgba(255,255,255,.15) 25%, transparent 25%, transparent 50%, rgba(255,255,255,.15) 50%, rgba(255,255,255,.15) 75%, transparent 75%, transparent);
  background-size: 40px 40px;
}
.progress .progress-bar {
  background-color: #F58220;
}
.progress.progress-striped .progress-bar {
  background-color: #F58220;
  background-image: linear-gradient(45deg, rgba(255,255,255,.15) 25%, transparent 25%, transparent 50%, rgba(255,255,255,.15) 50%, rgba(255,255,255,.15) 75%, transparent 75%, transparent);
  background-size: 40px 40px;
}

/*  Striped bars */
.progress-striped .bar {
    background-color: #1e93c6;
    background-image: linear-gradient(45deg, rgba(255,255,255,.15) 25%, transparent 25%, transparent 50%, rgba(255,255,255,.15) 50%, rgba(255,255,255,.15) 75%, transparent 75%, transparent);
    background-size: 40px 40px;
}

/*  Call animation for the active one */
.progress.active .bar,
.active.progress-bar {
    animation: progress-bar-stripes 2s linear infinite;
}

/*  PROGRESS STATES */
/*  --------------- */
/*  These have been inherited from Bootstrap and are not used on Core. */

/*  Danger (red) */
.progress-danger .bar, .progress .bar-danger {
    background-color: rgb(221, 81, 76);
    background-image: linear-gradient(to bottom, #ee5f5b, #c43c35);
    /*  Standard, IE10 */
    background-repeat: repeat-x;
}
.progress-danger.progress-striped .bar, .progress-striped .bar-danger {
    background-color: #ee5f5b;
    background-image: linear-gradient(45deg, rgba(255,255,255,.15) 25%, transparent 25%, transparent 50%, rgba(255,255,255,.15) 50%, rgba(255,255,255,.15) 75%, transparent 75%, transparent);
}

/*  Success (green) */
.progress-success .bar, .progress .bar-success {
    background-color: rgb(94, 185, 94);
    background-image: linear-gradient(to bottom, #62c462, #57a957);
    /*  Standard, IE10 */
    background-repeat: repeat-x;
}
.progress-success.progress-striped .bar, .progress-striped .bar-success {
    background-color: #62c462;
    background-image: linear-gradient(45deg, rgba(255,255,255,.15) 25%, transparent 25%, transparent 50%, rgba(255,255,255,.15) 50%, rgba(255,255,255,.15) 75%, transparent 75%, transparent);
}

/*  Info (teal) */
.progress-info .bar, .progress .bar-info {
    background-color: rgb(75, 177, 207);
    background-image: linear-gradient(to bottom, #5bc0de, #339bb9);
    /*  Standard, IE10 */
    background-repeat: repeat-x;
}
.progress-info.progress-striped .bar, .progress-striped .bar-info {
    background-color: #5bc0de;
    background-image: linear-gradient(45deg, rgba(255,255,255,.15) 25%, transparent 25%, transparent 50%, rgba(255,255,255,.15) 50%, rgba(255,255,255,.15) 75%, transparent 75%, transparent);
}

/*  Warning (orange) */
.progress-warning .bar, .progress .bar-warning {
    background-color: rgb(241, 160, 106);
    background-image: linear-gradient(to bottom, rgb(244, 178, 134), #ed8440);
    /*  Standard, IE10 */
    background-repeat: repeat-x;
}
.progress-warning.progress-striped .bar, .progress-striped .bar-warning {
    background-color: rgb(244, 178, 134);
    background-image: linear-gradient(45deg, rgba(255,255,255,.15) 25%, transparent 25%, transparent 50%, rgba(255,255,255,.15) 50%, rgba(255,255,255,.15) 75%, transparent 75%, transparent);
}
/*  Splunk: Accordian */
/*  ================ */


/* Accordian for expanding content

	 <div class="accordion" id="accordion2">
		 <div class="accordion-group">
			 <div class="accordion-heading">
				 <a class="accordion-toggle" data-toggle="collapse" data-parent="#accordion2" href="#collapseOne">
					 <i class="icon-accordion-arrow"></i>
					 Collapsible Group Item #1</a>
			 </div>
			 <div id="collapseOne" class="accordion-body collapse in">
				 <div class="accordion-inner">
					 Anim pariatur cliche...
				 </div>
			 </div>
		 </div><!-- /.accordion-group -->
		 <div class="accordion-group">
			 <div class="accordion-heading">
				 <a class="accordion-toggle" data-toggle="collapse" data-parent="#accordion2" href="#collapseTwo">
					 <i class="icon-accordion-arrow"></i>
					 Collapsible Group Item #2</a>
			 </div>
			 <div id="collapseTwo" class="accordion-body collapse">
				 <div class="accordion-inner">
					 Anim pariatur cliche...
				 </div>
			 </div>
		 </div><!-- /.accordion-group -->
	 </div><!-- /.accordion -->

*/

  /*  Parent container */
.accordion {
    margin-bottom: 0;
    background: #fff;
}

/*  Group == heading + body */
.accordion-group {
	margin-bottom: 0;
	border: none;
	border-radius: 0;
}
/*  Heading */
.accordion-heading {
	border-bottom: 0;
	position: relative;
}

/*  Heading Toggle */
.accordion-heading .accordion-toggle {
    display: block;
	padding: 6px 15px 6px 20px;
	line-height: 16px;
	background: #fff;
	border: 1px solid #333;
	color: #333;
	box-shadow: none;
	text-shadow: none;
	border-radius: 2px;
	border-left: none;
	border-right: none;
	text-decoration: none;
	border-bottom: none;
    cursor: pointer;
	border-radius: 0;
}
.accordion-heading .accordion-toggle .icon-triangle-right-small:before {
  content: "\203A";
}
.accordion-heading .accordion-toggle .icon-triangle-down-small:before {
  content: "\2C5";
}
.accordion-group:first-child  .accordion-toggle {
	border-top-left-radius: 0;
	border-top-right-radius: 0;
	border-top: none;
}

.accordion-group:last-child  .accordion-toggle,
.accordion-group.active:last-child  .accordion-body {
	 border-bottom: 1px solid #333;
	 border-bottom-left-radius: 0;
	 border-bottom-right-radius: 0;
	 border-bottom: none;
}

.accordion-group.active .accordion-toggle {
	background: #fff;
	border-bottom: none;
	cursor: default;
}

.accordion-group.active:last-child  .accordion-toggle {
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
}

.accordion-group:not(.active) .accordion-toggle:hover {
	background: #efefef;
	border-color: rgb(59, 59, 59);
	border-top-color: #333;
	border-bottom-color: #333;
	background-position: 0 0;
	text-decoration: none;
	box-shadow: none;
}

.accordion-group .accordion-toggle:focus {
	outline: 0;
	text-decoration: none;
	background: rgba(61, 171, 255, 0.12);
	box-shadow: none;
	/* override default focus-link() */
	filter: e(%("progid:DXImageTransform.Microsoft.gradient(enabled = false)"));
}

/*  Heading Toggle Icon */
.icon-accordion-toggle {
	position: absolute;
	left: 8px;
}

/*  Body */
.accordion-body {
	background-color: #fff;
}

.accordion-inner {
	padding: 10px 20px 20px 20px;
	border: none;
	position: relative;
}

.accordion-inner:before,
    .accordion-inner:after {
  display: table;
  content: "";
  /*  Fixes Opera/contenteditable bug: */
  /*  http://nicolasgallagher.com/micro-clearfix-hack/#comment-36952 */
  line-height: 0;
}

.accordion-inner:after {
  clear: both;
}

/*  Lite */
.accordion-heading .accordion-toggle {
  border-color: #ccc;
  font-weight: bold;
}
.accordion-group:not(.active) .accordion-toggle {
  background-color: #f3f3f3;
}
.accordion-group:not(.active) .accordion-toggle:hover {
  background-color: #ddd;
  border-color: #ccc;
}
/*  Carousel */
/*  -------------------------------------------------- */


.carousel {
  position: relative;
  margin-bottom: 16px;
  line-height: 1;
}

.carousel-inner {
  overflow: hidden;
  width: 100%;
  position: relative;
}

.carousel-inner > .item {
  display: none;
  position: relative;
  transition: .6s ease-in-out left;
}

/*  Account for jankitude on images */

.carousel-inner > .item > img,
    .carousel-inner > .item > a > img {
  display: block;
  line-height: 1;
}

.carousel-inner > .active,
  .carousel-inner > .next,
  .carousel-inner > .prev {
  display: block;
}

.carousel-inner > .active {
  left: 0;
}

.carousel-inner > .next,
  .carousel-inner > .prev {
  position: absolute;
  top: 0;
  width: 100%;
}

.carousel-inner > .next {
  left: 100%;
}

.carousel-inner > .prev {
  left: -100%;
}

.carousel-inner > .next.left,
  .carousel-inner > .prev.right {
  left: 0;
}

.carousel-inner > .active.left {
  left: -100%;
}

.carousel-inner > .active.right {
  left: 100%;
}

/*  Left/right controls for nav */
/*  --------------------------- */

.carousel-control {
  position: absolute;
  top: 40%;
  left: 15px;
  width: 40px;
  height: 40px;
  margin-top: -20px;
  font-size: 60px;
  font-weight: 100;
  line-height: 30px;
  color: #fff;
  text-align: center;
  background: #222;
  border: 3px solid #fff;
  border-radius: 23px;
  opacity: 0.50;

  /*  we can't have this transition here */
  /*  because webkit cancels the carousel */
  /*  animation if you trip this while */
  /*  in the middle of another animation */
  /*  ;_; */
  /*  transition: opacity .2s linear; */
}

/*  Reposition the right one */

.carousel-control.right {
  left: auto;
  right: 15px;
}

/*  Hover/focus state */

.carousel-control:hover,
  .carousel-control:focus {
  color: #fff;
  text-decoration: none;
  opacity: 0.90;
}

/*  Carousel indicator pips */
/*  ----------------------------- */
.carousel-indicators {
  position: absolute;
  top: 15px;
  right: 15px;
  z-index: 5;
  margin: 0;
  list-style: none;
}
.carousel-indicators li {
  display: block;
  float: left;
  width: 10px;
  height: 10px;
  margin-left: 5px;
  text-indent: -999px;
  background-color: #ccc;
  background-color: rgba(255,255,255,.25);
  border-radius: 5px;
}
.carousel-indicators .active {
  background-color: #fff;
}

/*  Caption for text below images */
/*  ----------------------------- */

.carousel-caption {
  position: absolute;
  left: 0;
  right: 0;
  bottom: 0;
  padding: 15px;
  background: #333;
  background: rgba(0,0,0,.75);
}
.carousel-caption h4,
.carousel-caption p {
  color: #fff;
  line-height: 16px;
}
.carousel-caption h4 {
  margin: 0 0 5px;
}
.carousel-caption p {
  margin-bottom: 0;
}

/*  Utility classes */
/*  Utility classes */
/*  -------------------------------------------------- */


/*  Quick floats */
.pull-right {
  float: right;
}
.pull-left {
  float: left;
}

/*  Toggling content */
.hide {
  display: none;
}
.show {
  display: block;
}

/*  Visibility */
.invisible {
  visibility: hidden;
}

/*  For Affix plugin */
.affix {
  position: fixed;
}

/* Proxy mixin s */
.clearfix:before,
    .clearfix:after {
  display: table;
  content: "";
  /*  Fixes Opera/contenteditable bug: */
  /*  http://nicolasgallagher.com/micro-clearfix-hack/#comment-36952 */
  line-height: 0;
}
.clearfix:after {
  clear: both;
}

.hide-text {
    font: 0/0 a;
    color: transparent;
    text-shadow: none;
    background-color: transparent;
    border: 0;
}

.input-block-level {
    display: block;
    width: 100%;
    min-height: 26px;
    /*  Make inputs at least the height of their button counterpart (base line-height + padding + border) */
    box-sizing: border-box;
    /*  Makes inputs behave like true block-level elements */
} /*  Has to be last to override when necessary */

/*  3rd party */
/*  Splunk: jquery UI theme */
/*  ======================= */


/*  generic widgets */
/*  --------------- */

.ui-widget {
	font-family: inherit;
}
.ui-widget-header {
	font-weight: normal;
	background: transparent;
	border: 0;
	color: #333;
}
.ui-widget-header a {
  color: #000;
}
.ui-corner-all {
	border-radius: 0;
}
.ui-icon {
	font-family: "Splunk Icons";
	width: 16px;
	height: 16px;
}


/*  Tabs */
/*  ----------- */

/*jq-ui adds background to tabs which is shared by other components*/

.ui-tabs .ui-widget-header {
  background: none;
  border-bottom:1px solid #ccc;
  border-radius: 0;
}

/*  override default tabs borders */

.ui-tabs .ui-tabs-nav li {
  border-bottom: 1px solid #ccc !important;
  /*need important to override jq-ui bs*/
  margin-bottom:-1px;
}

/*  selected state */

.ui-tabs .ui-tabs-nav li.ui-tabs-selected {
  border-bottom:1px solid #ccc !important;
  /*need important to override the other important*/
}


/*  Accordiion */
/*  ------------ */

.ui-accordion .ui-accordion-header .ui-icon {
  left: 0.5em;
  margin-top: -8px;
  position: absolute;
  top: 50%;
}

.ui-accordion-icons .ui-accordion-header a {
  padding-left: 2.2em;
}


/*  Datepicker */
/*  ------------- */

#ui-datepicker-div {
	display:none; /*  jquery ui adds this id by default ;_; */
	z-index: 1070 !important; /*  need to override jquery inline z-index nonsense ;_; */
}

.ui-datepicker {
	width: 17em;
	height: auto;
	position: relative;
	padding: 5px;

	box-shadow: 1px 2px 5px rgba(0,0,0,0.3);
	border: 1px solid #333;
	border-top-color: #333;
	border-bottom-color: #333;
	background-color: #fff;

}

.ui-datepicker .ui-datepicker-header {
  position: relative;
  padding: 0.2em 0;
  background: transparent;
}

/* header */

.ui-datepicker .ui-datepicker-title {
  margin: 0 2.3em;
  line-height: 1.8em;
  text-align: center;
}

.ui-datepicker .ui-datepicker-prev, .ui-datepicker .ui-datepicker-next {
  position: absolute;
  text-decoration: none;
  width: 24px;
  height: 24px;
}

.ui-datepicker .ui-datepicker-prev .ui-icon,.ui-datepicker .ui-datepicker-next .ui-icon{
  font: 0/0 a;
  color: transparent;
  text-shadow: none;
  background-color: transparent;
  border: 0;
  /*  override hide-text for ie-7 */
}

.ui-datepicker .ui-datepicker-prev .ui-icon:after, .ui-datepicker .ui-datepicker-next .ui-icon:after {
  display: block;
  position: absolute;
  left: 50%;
  top: 50%;
  width: 16px;
  height: 16px;
  margin-left: -8px;
  margin-top: -9px;
  text-indent: 0;
  font-size: 11px;
  font-family: "Splunk Icons";
  line-height: 20px;
  text-decoration: none;
  color: #333;
}

/* prev-next */

.ui-datepicker .ui-datepicker-prev {
  top: 0;
  left: 0;
  border-radius: 2px;
}

.ui-datepicker .ui-datepicker-prev .ui-icon:after {
  content: "\25C0";
  margin-left: -4px
}

.ui-datepicker .ui-datepicker-next {
  top: 0;
  right: 0;
  border-radius: 2px;
}

.ui-datepicker .ui-datepicker-next .ui-icon:after {
  content: "\25B6";
  margin-left: -3px;
  /*  not sure why this doesn't match up */
}

.ui-datepicker table {
  margin-bottom: 0;
  width: 100%;
  border-collapse: collapse;
  margin: 0 0 0.4em;
}

.ui-datepicker .ui-datepicker-calendar {
  /*  table */
  margin: 0;
}

.ui-datepicker .ui-datepicker-calendar th {
  line-height: 10px;
  padding: 0.7em 0.3em;
  padding-top: 20px;
  color: #999;
  text-align: center;
  border: 0;
  font-weight: normal;
}

.ui-datepicker .ui-datepicker-calendar td {
  padding: 1px;
}

.ui-datepicker .ui-datepicker-calendar td a {
  display: block;
  padding: 0.2em;
  text-align: right;
}

.ui-datepicker .ui-datepicker-calendar a {
  border: 1px solid #ccc;
}

.ui-datepicker .ui-datepicker-calendar a:hover {
  text-decoration: none;
}

.ui-datepicker .ui-datepicker-calendar .ui-state-default {
  background: #f3f3f3;
  border:1px solid #ccc;
  color: #0095cf;
}

.ui-datepicker .ui-datepicker-calendar .ui-state-active {
  background-color: rgb(218, 218, 218);
  background-image: linear-gradient(to bottom, #ccc, #eee);
  /*  Standard, IE10 */
  background-repeat: repeat-x;
  box-shadow: inset 0px 2px 2px rgba(0, 0, 0, 0.125);
  border-color: #333;
  border-top-color: #333;
  font-weight: bold;
  color: #333;
}

.ui-datepicker .ui-datepicker-calendar .ui-state-hover {
  border: 1px solid rgb(0, 77, 107);
  background: #fff;
  font-weight: bold;
  color: rgb(0, 77, 107);
}

/*  calendar */

.ui-datepicker a.ui-corner-all {
  padding: 0;
  /*  txt */
  font-size: 12px;
  font-weight: normal;
  line-height: 25px;
  /*  color */
  color: #333;
  background-color: #fff;
  background-color: rgb(249, 249, 249);
  background-image: linear-gradient(to bottom, rgb(245, 245, 245), rgb(255, 255, 255));
  /*  Standard, IE10 */
  background-repeat: repeat-x;
  /*  border */
  border: 1px solid #fff;
  border-radius: 2px;
  border-color: #333;
  border-top-color: #333;
  border-bottom-color: #333;
  box-shadow: 0 1px 1px rgba(0,0,0,0.3);
}

.ui-datepicker a.ui-corner-all:hover {
  cursor: pointer;
  /*  ensure pointer if missing href */
  border-color: #333;
  border-top-color: #333;
  border-bottom-color: #333;
  color: #333;
  background: #fff;
  font-weight: normal;
}/* .ui-datepicker */


/*
 * jQuery UI Resizable $VERSION
 *
 * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://docs.jquery.com/UI/Resizable#theming
 */
.ui-resizable { position: relative;}
.ui-resizable-handle { position: absolute;font-size: 0.1px;z-index: 99999; display: block; }
.ui-resizable-disabled .ui-resizable-handle, .ui-resizable-autohide .ui-resizable-handle { display: none; }
.ui-resizable-n { cursor: n-resize; height: 7px; width: 100%; top: -5px; left: 0; }
.ui-resizable-s { cursor: s-resize; height: 7px; width: 100%; bottom: -5px; left: 0; }
.ui-resizable-e { cursor: e-resize; width: 7px; right: -5px; top: 0; height: 100%; }
.ui-resizable-w { cursor: w-resize; width: 7px; left: -5px; top: 0; height: 100%; }
.ui-resizable-se { cursor: se-resize; width: 12px; height: 12px; right: 1px; bottom: 1px; }
.ui-resizable-sw { cursor: sw-resize; width: 9px; height: 9px; left: -5px; bottom: -5px; }
.ui-resizable-nw { cursor: nw-resize; width: 9px; height: 9px; left: -5px; top: -5px; }
.ui-resizable-ne { cursor: ne-resize; width: 9px; height: 9px; right: -5px; top: -5px;}


.ui-resizable-handle {
    width: 100%;
    height: 9px;
    background-color: transparent;
    z-index: 1000;
	cursor: ns-resize;
    cursor: row-resize;
    bottom: 0;
}


.ui-resizable-handle:before {
  content: "";
  position: absolute;
  top: 50%;
  left: 50%;
  transform: translate(-50%, -50%);
  margin-top:-1px;
  display: block;
  border-radius: 3px;
  border: none;
  height: 6px;
  width: 6px;
  background-color: rgba(0, 0, 0, 0.25);
}


.ui-resizable-handle:hover {
  /*   .gradient-vertical($interactiveGradientStartColorHover, $interactiveGradientEndColorHover); */
}


.ui-resizable-handle .ui-draggable-dragging {
  position: relative;
}


.ui-resizable:hover .ui-resizable-handle {
  visibility: visible;
}
/*  Splunk: Page: Dashboard Simple */
/*  ============================= */
/*  FIXME: split this into more components */

/*  fix z-index for map controls */

.leaflet-container {
  z-index: 1;
}

.dashboard-wrapper {
  padding-top: 20px;
}

.dashboard-body {
  padding: 0 20px 15px 20px;

    color:#333;
    background-color: #f3f3f3;
    min-height: 500px;
    /*  using three color so we can set color stop even though its only 2 colors */
}

.preload .dashboard-row, .preload .fieldset, .preload .preload-hidden {
  display: none;
}

.preload .dashboard-header:after {
  content: "Loading...";
  margin: auto;
  padding: 50px 0;
}

.progress-bar {
    top:0;
    bottom: auto;
}

.dashboard-header {
  margin-bottom: 10px;
  padding-top: 10px;
  min-height: 28px;

  /* .dashboard-view-controls { */
  /*   > a:first-child { */
  /*     margin-right: 10px; */
}

.dashboard-header h2 {
  font-size: 24px;
  margin: 0;
  padding: 0;
  font-weight: 200;
  padding-left: 0;
}

.dashboard-header .untitled {
  font-style: italic;
}

.dashboard-header .edit-dashboard-menu {
  padding: 2px 0px 0px 20px;
}

.dashboard-header .edit-dashboard-menu .dashboard-source-type {
  color: #999;
  float: right;
}

.dashboard-header .edit-dashboard-menu .tooltip-inner {
  white-space: normal;
}

.dashboard-header p.description {
  margin: 0 200px 0 0;
}

/* } */

.dashboard-header .edit-done {
  margin-left: 10px;
}

/*   } */

.dashboard-header .dashboard-menu .edit-btn {
  margin-right: 5px;
}

.dashboard-header .dashboard-menu .edit-export {
  margin-right: 5px;
}

.dashboard-header .dashboard-menu .edit-other {
  /*  TODO: replace with icon */
  font-size: 18px;
}

.alert-box {
    padding: 14px;
    padding-left: 45px;
    position: relative;
    line-height: 1.2;
    margin-bottom: 5px;
    z-index: 10;
}

.alert-box i {
  left: 20px;
}

.dashboard-error .alert {
  padding: 14px;
  padding-left: 45px;
  position: relative;
  line-height: 1.2;
  margin-bottom: 5px;
  z-index: 10;
  margin: 100px 50px;
}

.dashboard-error .alert i {
  left: 20px;
}
.empty-dashboard {
  padding: 100px 50px;
}
.empty-dashboard .alert {
  padding: 14px;
  padding-left: 45px;
  position: relative;
  line-height: 1.2;
  margin-bottom: 5px;
  z-index: 10;
}
.empty-dashboard .alert i {
  left: 20px;
}

#dashboard-editor{
  width:100%;
  min-height: 500px;
  height:100%;
}


.add-content-master {
  width: 300px;
}


.add-content-master .header input {
  border-radius: 15px;
}


.add-content-master .header .clear-filter {
  position: relative;
  left: -20px;
  background-color: #ccc;
  border-radius: 5px;
  height: 10px;
  width: 10px;
  display: inline-block;
  color: inherit;
}


.add-content-master .header .clear-filter i {
  font-size: 8px;
  position: relative;
  top: -4px;
  left: 2px;
}


.add-content-master .panel-contents {
  width: 100%;
  display: inline-block;
  overflow-y: auto;
  position: absolute;
  top: 65px;
  bottom: 0;
  padding: 0;
  box-sizing: border-box;
}


.add-content-master .panel-contents .accordion-group {
  border-left: none;
  border-right: none;
  border-top: none;
  border-radius: 0;
  margin: 0;
}


.add-content-master .panel-contents .accordion-group .collapse:not(.in) {
  visibility: hidden;
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}


.add-content-master .panel-contents .accordion-group .collapse.in {
  visibility: visible;
}


.add-content-master .panel-contents .accordion-group .accordion-toggle:before {
  content: "\2C5";
  font-family: "Splunk Icons";
  font-style: normal;
  font-weight: normal;
  text-decoration: inherit;
  display: inline-block;
  width: 13px;
}


.add-content-master .panel-contents .accordion-group .accordion-toggle.collapsed:before {
  content: "\203A";
}


.add-content-master .panel-contents .accordion-group .accordion-inner {
  border-top: none;
  padding: 0;
}


.add-content-master .panel-contents a:hover {
  text-decoration: none;
  color: rgb(0, 77, 107);
  background: #ddd;
}


.add-content-master .panel-contents a:focus {
  outline: 0;
  text-decoration: none;
  background: rgba(61, 171, 255, 0.12);
  box-shadow: none;
  /* override default focus-link() */
}


.add-content-master .panel-contents ul {
  margin: 0;
  list-style: none;
}


.add-content-master .panel-contents ul li.panel-content {
  position: relative;
}


.add-content-master .panel-contents ul li.panel-content a {
  position: relative;
  padding: 7px 10px 7px 31px;
  overflow: hidden;
  text-overflow: ellipsis;
  line-height: 16px;
  display: block;
  white-space: nowrap;
}


.add-content-master .panel-contents ul li.panel-content a .icons {
  position: relative;
  top: 2px;
  font-size: 14px;
  width: 40px;
  text-align: center;
  margin-left: -15px;
  display: inline-block;
}


.add-content-master .panel-contents ul li.panel-content a .icons i {
  margin-right: 3px;
}


.add-content-master .panel-contents ul li.panel-content a .icons i.icon-plus {
  font-size: 12px;
}


.add-content-master .panel-contents ul li.panel-content .accordion-group ul a {
  padding-left: 48px;
}


.add-content-master .panel-contents ul li.parser-error a, .add-content-master .panel-contents ul li.clone-error a {
  color: #999;
  cursor: default;
}


.add-content-master .panel-contents ul li.selected a {
  color: #fff;
  background: #3863a0;
}

.add-content-name.tooltip {
  word-break: break-all;
}

.sidebar .header {
  padding: 10px;
  height: 45px;
  background-color: #f3f3f3;
}

.sidebar .header h3 {
  margin-top: 0;
  margin-bottom: 3px;
}

.sidebar .footer {
  position: absolute;
  bottom: 0;
}

.sidebar .content-title-control {
  margin-top: 10px;
}

.sidebar .shared-timerangepicker .btn .time-label {
  display: inline;
  vertical-align: baseline;
}

.sidebar .time-range-scope {
  margin-bottom: 0;
}

.sidebar .time-range-scope .controls {
  float: left;
  margin-right: 10px;
}

.sidebar .preview-body .dashboard-cell {
  width: 100%;
}

.sidebar .preview-body .dashboard-cell .dashboard-panel {
  margin-right: 0;
}

.sidebar .preview-body .shared-controls-textareacontrol textarea {
  height: 80px;
}

.sidebar .preview-body .view-results {
  visibility: hidden;
}

.time-range-scope .controls {
  margin-bottom: 10px;
}

.input.hidden {
  display: none;
}

.edit-mode .input.hidden {
  display: inline-block;
}

.form-settings {
  float: right;
}

.edit-mode .dashboard-header .title-editor {
  display: block;
  width: 100%;
  background-color: transparent;
  line-height:normal;
}

.edit-mode .dashboard-header .title-editor:hover,.edit-mode .dashboard-header .title-editor:focus{
  background-color: #fff;
}

.edit-mode .dashboard-header .label-editor {
  font-size: 24px;
  font-weight: 200;
  margin-bottom: 0;
}

.edit-mode .dashboard-header .description-editor {
  height: 26px;
  word-break: break-all;
}


.edit-mode .title-editor {
  box-shadow: none;
  box-sizing: border-box;
  height: auto;
  border-color: transparent;
  font-size: inherit;
  font-weight: inherit;
}


.edit-mode .title-editor:hover:not(:focus) {
  border-color: #ccc;
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.075);
}


.edit-mode .title-editor:focus {
  border-color: rgba(82, 168, 236, 0.8);
  outline: 0;
}

.edit-mode .dashboard-row .dashboard-panel h2.panel-title {
  padding: 3px 55px 3px 5px;
  padding-right: 50px;
  height: 27px;
  border-bottom: 1px solid #eee;
}

.edit-mode .dashboard-row .dashboard-panel h2.panel-title > .title-editor {
  font-size: inherit;
  color:inherit;
  text-transform: inherit;
  margin-bottom: 5px;
  padding: 4px 6px 4px 6px;
  width: 100%;
  margin-right: 60px;
  border-color: transparent;
}

.edit-mode .dashboard-row .dashboard-panel h2.panel-title > .title-editor:hover:not(:focus) {
  border-color: #ccc;
}

.edit-mode .dashboard-row .dashboard-panel h2.panel-title > .title-editor:focus {
  border-color: rgba(82, 168, 236, 0.8);
  outline: 0;
}

.edit-mode .dashboard-row .dashboard-panel .panel-head > h3 {
  padding: 2px 0 2px 5px;
  margin-right: 177px;
}

.edit-mode .dashboard-row .dashboard-panel .panel-head > h3 > .title-editor {
  margin-top: 1px;
  margin-bottom: 1px;
  width: 100%;
  margin-right: 150px;
}

.edit-mode .dashboard-row .dashboard-panel .dashboard-element-editor {
  position: relative;
}

.edit-mode .dashboard-row .dashboard-panel .panel-element-row {
  border-top: 1px solid #eee !important;
}

.edit-mode .dashboard-row .dashboard-panel .dashboard-panel-editor {
  position: absolute;
  right: 0;
  top: 16px;
}

.edit-mode .dashboard-row .dashboard-panel .dashboard-panel-editor .dropdown-toggle {
  border-radius: 0;
  display: inline-block;
  padding: 0 10px;
  line-height: 27px;
  box-shadow: none !important;
}

.edit-mode .dashboard-row .dashboard-panel .dashboard-panel-editor .dropdown-toggle > [class^="icon-"] {
  font-size: 1.5em;
}

.edit-mode .dashboard-row .dashboard-panel .dashboard-panel-editor .dropdown-toggle .caret {
  padding-left: 0.15em;
  vertical-align:middle;
}

.edit-mode .dashboard-row .dashboard-panel .dashboard-panel-editor .panel-type-label {
  padding: 3px 10px;
  color: #999;
  text-transform: uppercase;
}

.view-mode .dashboard-panel h2.panel-title.empty {
  display: none;
}
.view-mode .dashboard-element.table {
  margin-top: -1px;
}

.edit-mode .dashboard-row {
  margin-right: -10px;
}

.dashboard-row:before,
    .dashboard-row:after {
  display: table;
  content: "";
  /*  Fixes Opera/contenteditable bug: */
  /*  http://nicolasgallagher.com/micro-clearfix-hack/#comment-36952 */
  line-height: 0;
}

.dashboard-row:after {
  clear: both;
}

.dashboard-row .dashboard-cell {
  float: left;
}

.dashboard-row .dashboard-panel {
  background: white;
  margin: 0 5px 5px 0;
  /*  overflow: hidden; // moved overflow to panel-body due to SPL-71571 */
  position: relative;
}

.dashboard-row .dashboard-panel:before,
    .dashboard-row .dashboard-panel:after {
  display: table;
  content: "";
  /*  Fixes Opera/contenteditable bug: */
  /*  http://nicolasgallagher.com/micro-clearfix-hack/#comment-36952 */
  line-height: 0;
}

.dashboard-row .dashboard-panel:after {
  clear: both;
}

.dashboard-row .dashboard-panel h2.panel-title {
  font-size: 16px;
  line-height: 1;
  font-weight:normal;
  margin: 0;
  padding: 12px 55px 7px 12px;
  word-wrap: break-word;
  text-rendering: initial;
}

.dashboard-row .dashboard-panel:hover .ui-resizable-handle {
  visibility: visible;
}

.dashboard-row .dashboard-panel .ui-resizable-handle {
  margin-bottom: -1px;
  position:absolute;
}

.dashboard-row .dashboard-panel .panel-element-row {
  clear: both;
}

.dashboard-row .dashboard-panel .panel-element-row div.single {
  float: left;
  min-width: 200px;
}

.dashboard-row .dashboard-panel .panel-element-row .table {
  margin-bottom: 0px;
}

.dashboard-row .dashboard-panel .panel-element-row .ui-resizable-handle {
  display: none;
}

.dashboard-row .dashboard-panel .panel-element-row:hover .ui-resizable-handle {
  display: block;
}

.dashboard-row .dashboard-panel .panel-title.empty + .fieldset.empty + .panel-element-row {
  border-top:none;
}

.dashboard-row .dashboard-panel .dashboard-element {
  position: relative;
}

.dashboard-row .dashboard-panel .dashboard-element .panel-footer {
  clear: both;
}

.dashboard-row .dashboard-panel .panel-head h3 {
  line-height: 1;
  margin: 0;
  padding: 12px 55px 10px 12px;
  color: #333;
  text-rendering: initial;
  word-wrap: break-word;
  font-weight: bold;
  font-size: 14px;
}

.dashboard-row .dashboard-panel .panel-head h3 .untitled {
  color: #999;
}

.dashboard-row .dashboard-panel .panel-footer {
  clear: both;
  height:0;
  overflow:hidden;
}

.dashboard-row .dashboard-panel .panel-footer:before,
    .dashboard-row .dashboard-panel .panel-footer:after {
  display: table;
  content: "";
  /*  Fixes Opera/contenteditable bug: */
  /*  http://nicolasgallagher.com/micro-clearfix-hack/#comment-36952 */
  line-height: 0;
}

.dashboard-row .dashboard-panel .panel-footer:after {
  clear: both;
}

.dashboard-row .dashboard-panel .panel-footer.show, .dashboard-row .dashboard-panel .dashboard-element:hover .panel-footer {
  box-sizing:border-box;
  height:30px;
  padding: 5px 15px 5px 12px;
  border: 1px solid #fff;
  border-top:none;
  margin: 0 0 -30px 0;
  background-color: rgba(224, 224, 224, 0.9);
  position:relative;
  z-index: 3;
}

.dashboard-row .dashboard-panel .view-results .inspector-link {
  display: inline-block;
  margin-right: 20px;
}

.dashboard-row .dashboard-panel .view-results .btn-pill {
  padding: 0;
  height: 20px;
  line-height: 20px;
  width: 22px;
  font-size: 15px;
  text-align: center;
}

.dashboard-row .dashboard-panel .view-results .btn-pill + .btn-pill {
  margin-left: 0;
}

.dashboard-row .dashboard-panel .panel-body {
  overflow: hidden;
  /* SPL-71571 */
  clear: both;
}

.dashboard-row .dashboard-panel .panel-body.html, .dashboard-row .dashboard-panel .panel-body.splunk-html {
  padding: 10px 10px;
}

.dashboard-row .dashboard-panel .panel-body.html p,
        .dashboard-row .dashboard-panel .panel-body.html .splunk-radiogroup,
        .dashboard-row .dashboard-panel .panel-body.html .splunk-dropdown,
        .dashboard-row .dashboard-panel .panel-body.html .splunk-multidropdown,
        .dashboard-row .dashboard-panel .panel-body.html .splunk-textinput,
        .dashboard-row .dashboard-panel .panel-body.html .splunk-checkbox,
        .dashboard-row .dashboard-panel .panel-body.html .splunk-checkboxgroup,
        .dashboard-row .dashboard-panel .panel-body.html .splunk-timerange,
        .dashboard-row .dashboard-panel .panel-body.splunk-html p,
        .dashboard-row .dashboard-panel .panel-body.splunk-html .splunk-radiogroup,
        .dashboard-row .dashboard-panel .panel-body.splunk-html .splunk-dropdown,
        .dashboard-row .dashboard-panel .panel-body.splunk-html .splunk-multidropdown,
        .dashboard-row .dashboard-panel .panel-body.splunk-html .splunk-textinput,
        .dashboard-row .dashboard-panel .panel-body.splunk-html .splunk-checkbox,
        .dashboard-row .dashboard-panel .panel-body.splunk-html .splunk-checkboxgroup,
        .dashboard-row .dashboard-panel .panel-body.splunk-html .splunk-timerange {
  padding: 0px;
}

.dashboard-row .dashboard-panel .panel-body .splunk-paginator {
  float: right;
  padding-right: 15px;
  padding-top: 3px;
}

.dashboard-row .dashboard-panel .panel-body .splunk-paginator:empty {
  height: 0;
  padding: 0;
  margin: 0;
}

.dashboard-row .dashboard-panel .panel-body .table-row-expanding > tbody > tr > td.expands a,
      .dashboard-row .dashboard-panel .panel-body .table-row-expanding th.col-info,
      .dashboard-row .dashboard-panel .panel-body .results-table table tr>td:first-child,
      .dashboard-row .dashboard-panel .panel-body .results-table table tr>th:first-child   {
  padding-left: 12px;
}

.dashboard-row .dashboard-panel .panel-body .results-table table tr>td:last-child,
      .dashboard-row .dashboard-panel .panel-body .results-table table tr>th:last-child,
      .dashboard-row .dashboard-panel .panel-body .table th:last-child,
      .dashboard-row .dashboard-panel .panel-body .table td:last-child {
  padding-right: 12px;
}

.dashboard-row .dashboard-panel .panel-body .results-table table tr>th:last-child .btn-col-format {
  margin-right: -12px;
}

.dashboard-row .dashboard-panel .panel-body .splunk-message-container .alert, .dashboard-row .dashboard-panel .panel-body .lazy-view-container.loading .alert, .dashboard-row .dashboard-panel .panel-body .visualization-message .alert {
  text-align: center;
  color: #999;
  border-style: none;
  font-size: 13px;
}

.dashboard-row .dashboard-panel .panel-body .splunk-message-container .alert.alert-info i, .dashboard-row .dashboard-panel .panel-body .lazy-view-container.loading .alert.alert-info i, .dashboard-row .dashboard-panel .panel-body .visualization-message .alert.alert-info i {
  display: none;
}

.dashboard-row .dashboard-panel .panel-body .splunk-message-container .alert .icon-alert, .dashboard-row .dashboard-panel .panel-body .lazy-view-container.loading .alert .icon-alert, .dashboard-row .dashboard-panel .panel-body .visualization-message .alert .icon-alert {
  float: none;
  color: rgb(179, 179, 179);
  position: static;
  margin-right: 0.25em;
  vertical-align: middle;
}

.dashboard-row .dashboard-panel .panel-body .splunk-message-container.compact .alert, .dashboard-row .dashboard-panel .panel-body .lazy-view-container.loading.compact .alert, .dashboard-row .dashboard-panel .panel-body .visualization-message.compact .alert {
  padding-top: 4px;
  padding-bottom: 4px;
  margin-bottom: 0;
  text-align: left;
  display: inline;
}

.dashboard-row .dashboard-panel .panel-body .splunk-message-container.compact .alert .icon-alert, .dashboard-row .dashboard-panel .panel-body .lazy-view-container.loading.compact .alert .icon-alert, .dashboard-row .dashboard-panel .panel-body .visualization-message.compact .alert .icon-alert {
  font-size: 150%;
  top: 4px;
}

.dashboard-row .dashboard-panel .panel-body .lazy-view-container.loading, .dashboard-row .dashboard-panel .panel-body .visualization-message {
  padding-top: 54px;
}

/*  single value */

.dashboard-row .dashboard-panel .panel-body .splunk-single {
  min-height: 40px;
  text-align: center;
}

.dashboard-row .dashboard-panel .panel-body .msg .single-result {
  color: #999;
}

.dashboard-row .dashboard-panel .panel-body .splunk-table {
  margin-top: 12px;
}

.dashboard-row .dashboard-panel .panel-body .splunk-table:before,
    .dashboard-row .dashboard-panel .panel-body .splunk-table:after {
  display: table;
  content: "";
  /*  Fixes Opera/contenteditable bug: */
  /*  http://nicolasgallagher.com/micro-clearfix-hack/#comment-36952 */
  line-height: 0;
}

.dashboard-row .dashboard-panel .panel-body .splunk-table:after {
  clear: both;
}

.dashboard-row .dashboard-panel .panel-body .splunk-table .splunk-paginator {
  float: right;
  padding-right: 15px;
}

.dashboard-row .dashboard-panel .panel-body p {
  padding: 0px 10px;
}

.dashboard-row .dashboard-panel .panel-body .splunk-radiogroup,
      .dashboard-row .dashboard-panel .panel-body .splunk-dropdown,
      .dashboard-row .dashboard-panel .panel-body .splunk-multidropdown,
      .dashboard-row .dashboard-panel .panel-body .splunk-textinput,
      .dashboard-row .dashboard-panel .panel-body .splunk-checkbox,
      .dashboard-row .dashboard-panel .panel-body .splunk-checkboxgroup,
      .dashboard-row .dashboard-panel .panel-body > .splunk-timerange,
      .dashboard-row .dashboard-panel .panel-body .splunk-searchbar,
      .dashboard-row .dashboard-panel .panel-body > button {
  margin: 5px 10px;
}

.dashboard-row .dashboard-panel .shared-eventsviewer {
  border-left: none;
}

.dashboard-row .dashboard-panel ul.shared-eventsviewer {
  margin-bottom: 5px;
  border-top-style: none;
}

.dashboard-row .dashboard-panel .error-details {
  display: block;
  float: right;
  padding: 9px 12px 5px 5px;
}

.dashboard-row .dashboard-panel .error-details i {
  color: #f2b827;
}

.dashboard-row .dashboard-panel .error-details.severe i {
  color: #d6563c;
}

.dashboard-row .dashboard-panel .error-details.severe .error-indicator:hover i {
  color: rgb(217, 159, 13);
}

.dashboard-row .dashboard-panel .error-details.severe .error-indicator:hover i {
  color: rgb(185, 64, 39);
}

.dashboard-row .dashboard-panel .error-details .error-indicator {
  padding: 0;
  height: 20px;
  line-height: 20px;
  width: 22px;
  font-size: 15px;
  text-align: center;
  border-radius: 3px;
  margin-left: 3px;
  display: block;
}

.dashboard-row .dashboard-panel .error-details .error-indicator:hover {
  background-color: #efefef;
}

.dashboard-row .dashboard-panel .error-details .error-indicator i {
  font-size: 18px;
}

.dashboard-row .dashboard-panel .error-details li {
  padding: 5px 10px 5px 25px;
  position: relative;
}

.dashboard-row .dashboard-panel .error-details li:first-child {
  border-top: none;
}

.dashboard-row .dashboard-panel .error-details li > i {
  font-size: 18px;
  position: absolute;
  left: 3px;
  top: 5px;
}

.dashboard-row .dashboard-panel .error-details li.warning > i {
  color: #f2b827;
}

.dashboard-row .dashboard-panel .error-details li.error > i {
  color: #d6563c;
}

.dashboard-row .dashboard-panel .progress-bar .progress-msg {
  font-size: 11px;
  color: #999;
  display: inline-block;
}

.view-mode .refresh-time-indicator {
  padding:0 10px;
  z-index: 10;
  height: 14px;
}

.view-mode .refresh-time-indicator .time-freshness {
  font-size: 11px;
  color: #999;
  cursor: default;
  padding: 0;
  margin: 0;
}

.view-mode .with-title .fieldset.empty + .panel-element-row:not(.grouped) .error-details {
  position: absolute;
  top: -31px;
  right: 0;
}

.view-mode .element-footer {
  border-bottom: 1px solid transparent;
}

.view-mode .element-footer .menus {
  display: none;
  position: absolute;
  right: 10px;
  background: #fff;
  border: 1px solid #ccc;
  border-top: 1px solid #fff;
  margin-top: -1px;
  padding-left: 5px;
  border-bottom-left-radius: 5px;
  border-bottom-right-radius: 5px;
  border-top-right-radius: 2px;
  border-top-left-radius: 2px;
  z-index: 999;
}

.view-mode .element-footer .menus .btn-pill {
  padding: 1px 5px 1px 5px;
  border-radius: 0;
  line-height: 22px;
  font-size: 15px;
}

.view-mode .element-footer .menus .refresh-time-indicator {
  display: inline;
}

.view-mode .dashboard-element:hover .element-footer {
  border-bottom: 1px solid #ccc;
}

.view-mode .dashboard-element:hover .element-footer .menus {
  display: block;
}

.view-mode .element-footer:hover {
  border-bottom: 1px solid #ccc;
}

.view-mode .element-footer:hover .menus {
  display: block;
}

.preview-body .element-footer {
  display: none;
}

.edit-mode .element-footer {
  display: none;
}

.edit-mode .refresh-time-indicator {
  display: none;
}

.dashboard-cell.hidden, .dashboard-row.hidden {
  display: none;
}

.edit-mode .dashboard-cell.hidden, .edit-mode .dashboard-row.hidden {
  display: block;
}

.edit-mode .dashboard-cell.hidden .dashboard-panel, .edit-mode .dashboard-row.hidden .dashboard-panel {
  border-style: dashed;
}
.dashboard-element.hidden {
  display: none;
}
.edit-mode .dashboard-element.hidden {
  display: block;
}
.edit-mode .dashboard-element.hidden .panel-body, .edit-mode .dashboard-element.hidden .panel-footer {
  opacity: .5;
}
.edit-mode .dashboard-element.hidden .panel-head h3 {
  color: #bbb;
}
.edit-mode .dashboard-element.hidden .panel-editor {
  z-index: 99;
}

.dashboard-panel > .drag-handle {
  height: 8px;
  margin: 5px 5px 0px 5px;
  cursor: move;
  z-index: 3;
}

.dashboard-panel > .drag-handle .handle-inner {
  background: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAAECAYAAACp8Z5+AAAAG0lEQVQIW2M0Njb+f/bsWUYYzciABuAyOFUAAKKMEAXhn6ySAAAAAElFTkSuQmCC) repeat;
  opacity: 0.5;
  cursor: move;
  height: 8px;
  margin-right: 14px;
}

.dashboard-panel > .drag-handle > .delete-panel {
  display: inline-block;
  float: right;
  font-size: 17px;
  padding: 0 3px;
  color: #97999B;
  margin-right: -3px;
  margin-top: -4px;
  background: #fff;
}

.dashboard-panel > .drag-handle > .delete-panel:hover, .dashboard-panel > .drag-handle > .delete-panel:focus {
  text-decoration: none;
  color: rgb(0, 77, 107);
}

.dashboard-panel > .drag-handle > .delete-panel:hover {
  background: #ddd;
}

.dashboard-panel > .drag-handle > .delete-panel:focus {
  outline: 0;
  text-decoration: none;
  background: rgba(61, 171, 255, 0.12);
  box-shadow: none;
  /* override default focus-link() */
}

.initial-placeholder {
  height: 234px;
}

.initial-placeholder.placeholder-visualizations-singlevalue {
  height: 80px;
}

.dragndrop-enabled .dashboard-row.empty {
  min-height: 20px;
}

.dragndrop-enabled .dashboard-row .dashboard-panel.drag-hover {
  border-color: rgb(187, 187, 187);
}

.dragndrop-enabled .dashboard-row .panel-head h3 {
  padding: 11px 15px 8px 15px;
}

.dragndrop-enabled .dashboard-row .panel-element-row + .panel-element-row .panel-head {
  border-top: 1px solid #ccc;
}

.dragndrop-enabled .dashboard-row .dashboard-panel .panel-body .splunk-message-container .alert .icon-alert {
  color: #d6563c;
}

.dragndrop-enabled .sortable-placeholder {
  min-width: 10px;
  float: left;
}

.dragndrop-enabled .sortable-placeholder .dashboard-panel {
  min-height: 200px;
  background: transparent;
  border: 1px dashed rgb(179, 179, 179);
  box-shadow: none;
}

.dragndrop-enabled .dashboard-cell {
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}

.dragndrop-enabled .dashboard-cell.ui-sortable-helper .dashboard-panel {
  box-shadow: 2px 2px 5px rgba(0, 0, 0, 0.2);
}

.dragndrop-enabled .dashboard-row {
  min-height: 100px;
}

.dragndrop-enabled .shared-eventsviewer .table-chrome {
  border-top: none;
}

.html h1 {
  font-size: 20px;
  font-weight: bold;
}

.html h2 {
  font-size: 16px;
  margin: 10px 0;
  font-weight: normal;
}

.html h3 {
  font-size: 14px;
  font-weight: bold;
}

.html h4 {
  font-size: 12px;
  font-weight: bold;
  margin: 0;
}

.html h5 {
  font-size: 10.2px;
}

.html .panel-head > h3 {
  font-size: 16px;
  font-weight: normal;
}

/*  Licensing tab content */
.page-licensing .tab-content {
  background-color: rgb(253, 253, 253);
  /* Old browsers */
  background-image: linear-gradient(to bottom, #fff 0, #f3f3f3 25px);
  /* W3C */
}

.view-mode .dashboard-row .dashboard-cell:last-child .dashboard-panel,
.view-mode .dashboard-row .dashboard-cell.last-visible .dashboard-panel {
  margin-right: 0;
}

.dashboards-table-controls-convertdashboard .shared-controls-controlgroup .controls-halfblock .help-block {
  width: 50%;
  text-align: center;
}

.more-info {
  width: 400px;
}

.more-info .popdown-dialog-body {
  padding: 20px 20px 10px 20px;
}

/*  radio forms */
.splunk-radiogroup .choice {
  margin-bottom: 4px;
}
.splunk-radiogroup input {
  margin: 0px 10px 0px 2px;
}
.splunk-radiogroup label {
  display: inline-block;
  margin-left: 1em;
  margin-bottom: 0;
  vertical-align: middle;
}

.dropdown-menu .dashboard-source-type {
  float: right;
  color: #999;
}

/*  make search edit a bit taller with no limit */
.edit-search-string .controls textarea,
.add-panel-wrapper .controls textarea {
  height: 15em;
  max-height: none;
}

/*  input editor */
/*  TODO: break out to component */
.input-editor-body {
  border-bottom: 1px solid #ccc;
}
/*  TODO: make this block, float, width, etc. */
.input-editor-body .input-editor-type {
  display: inline-block;
  vertical-align: top;
  list-style: none;
  margin: 0;
}
.input-editor-body .input-editor-type li {
  margin: 0;
}
/*  hover state */
.input-editor-body .input-editor-type li > a:hover {
  position: relative;
  color: rgb(0, 77, 107);
  background: #ddd;
}
.input-editor-body .input-editor-type li > a:focus {
  position: relative;
  outline: 0;
  text-decoration: none;
  background: rgba(61, 171, 255, 0.12);
  box-shadow: none;
  /* override default focus-link() */
}
.input-editor-body .input-editor-type li > a.selected {
  position: relative;
  color: #fff;
  background: #3863a0;
  border: none;
}
/*  link style */
.input-editor-body .input-editor-type li > a {
  /*  BS 2.2 scoping */
  border-top: 1px dotted #ccc;
  color: #0095cf;
  /*  first and last elements have rounded corners that should not be seen. */
  /*  There should not be space between <a> and concertina-body so updating  */
  /*  padding and margin-right below */
  padding: 5px 16px;
  /*  BS 2.2.x breaks this ... */
  margin-right: -4px;
  white-space: normal;
  display: block;
  /*  BS 2.3 breaks this */
  text-decoration: none;
}
/*  rounding for first and last items */
.input-editor-body .input-editor-type li:first-child > a {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
  border-top: none;
}
.input-editor-body .input-editor-type li:last-child > a {
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
}
.input-editor-body .input-editor-type [class^="icon-"], .input-editor-body .input-editor-type [class*=" icon-"] {
  width: 1.25em;
  text-align: center;
}
/*  .dropdown-menu */
.input-editor-body .input-editor-format {
  display: inline-block;
  position: relative;
  width: 385px;
  border-left: 1px solid #ccc;
  vertical-align: top;
}
.input-editor-body .input-editor-format .concertina .concertina-body {
  position: static;
  max-height: 500px;
  min-height: 100px;
}
.input-editor-body .input-editor-format .splunk-choice-input-message {
  height: auto;
}
.input-editor-body .input-editor-format .shared-controls-textcontrol input {
  width: 186px;
}
.input-editor-body .input-editor-format .shared-controls-textareacontrol textarea {
  width: 186px;
}
.input-editor-body .input-editor-format .splunk-dropdown, .input-editor-body .input-editor-format .splunk-multidropdown {
  width: 186px;
}
.input-editor-body .input-editor-format .shared-controls-syntheticselectcontrol .link-label {
  float: left;
  width: 162px;
  overflow: hidden;
  text-align: left;
}
.input-editor-body .input-editor-format .token-input-settings-body .splunk-choice-input-message {
  clear: both;
}
.input-editor-body .input-editor-format .token-input-settings-body .shared-timerangepicker {
  margin-left: 0px;
}
.input-editor-body .input-editor-format .token-input-settings-body .splunkjs-mvc-simpleform-edit-tokenpreviewcontrol .shared-controls-labelcontrol {
  width: 200px;
}
.input-editor-body .input-editor-format .token-input-settings-body .splunkjs-mvc-simpleform-edit-tokenpreviewcontrol .shared-controls-labelcontrol span {
  word-break: break-all;
  white-space: pre-wrap;
}
.input-editor-body .input-editor-format .static-input-settings-body .static-options-heading {
  margin-bottom: 8px;
}
.input-editor-body .input-editor-format .static-input-settings-body .static-options-heading .static-options-heading-name {
  width: 114px;
  margin-left: 40px;
  float: left;
}
.input-editor-body .input-editor-format .static-input-settings-body .static-options-heading .static-options-heading-value {
  margin-left: 180px;
}
.input-editor-body .input-editor-format .static-input-settings-body .static-options-body {
  margin-bottom: 8px;
}
.input-editor-body .input-editor-format .static-input-settings-body .static-options-body .static-option-pair .drag-handle {
  display: inline-block;
  margin-left: 20px;
  width: 10px;
  height: 18px;
  background: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAAECAYAAACp8Z5+AAAAG0lEQVQIW2M0Njb+f/bsWUYYzciABuAyOFUAAKKMEAXhn6ySAAAAAElFTkSuQmCC) repeat;
  opacity: 0.5;
  cursor: move;
}
.input-editor-body .input-editor-format .static-input-settings-body .static-options-body .static-option-pair .static-option-label, .input-editor-body .input-editor-format .static-input-settings-body .static-options-body .static-option-pair .static-option-value {
  display: inline-block;
  margin-left: 5px;
}
.input-editor-body .input-editor-format .static-input-settings-body .static-options-body .static-option-pair .static-option-label input, .input-editor-body .input-editor-format .static-input-settings-body .static-options-body .static-option-pair .static-option-value input {
  width: 100px;
}
.input-editor-body .input-editor-format .static-input-settings-body .static-options-body .static-option-pair .static-option-remove {
  margin-left: 5px;
}
.input-editor-body .input-editor-format .static-input-settings-body .static-options-add {
  margin-right: 20px;
  margin-bottom: 10px;
}
.input-editor-body .input-editor-format .dynamic-input-settings-body .splunk-timerange {
  margin-bottom: 10px;
}
.input-editor-body .input-editor-format .dynamic-input-settings-body .search-field-wrapper {
  width: 220px;
}
.input-editor-body .control-label {
  width: 125px;
  float: left;
  padding-top: 5px;
  text-align: right;
}
.input-editor-body .controls {
  margin-left: 135px;
}
.input-editor-body .alert.alert-error {
  margin-left: 20px;
  margin-bottom: 0;
}
.input-editor-body .alerts.shared-flashmessages {
  border-top: 1px solid #ccc;
}

.input-editor-cancel, .input-editor-apply {
  margin: 10px;
}

.input-timerangepicker .shared-timerangepicker, .input-time .shared-timerangepicker {
  width: 95%;
}

.input-timerangepicker .shared-timerangepicker .btn, .input-time .shared-timerangepicker .btn {
  width: 95%;
  text-align: left;
}

.input-timerangepicker .shared-timerangepicker .btn .time-label, .input-time .shared-timerangepicker .btn .time-label {
  max-width: 90%;
  display: inline-block;
}

.input-timerangepicker .shared-timerangepicker .caret, .input-time .shared-timerangepicker .caret {
  float: right;
}

/*  Dashboard print styles */
/*  -------------------------------------------------- */
@media print {
  #header, .edit-dashboard-menu, .select2-choice > div, .panel-footer, .form-submit, .ui-resizable-handle {
    display: none !important;
  }

  .fieldset .input > label:first-child {
    font-weight: bold;
  }

  .fieldset .input input, .fieldset .input .select2-choices, .fieldset .input .select2-container {
    border: none;
    box-shadow: none !important;
    transition: none !important;
  }

  .select2-container {
    min-width: 0px !important;
  }

  .select2-container a.select2-choice, .select2-container .select2-choices, .select2-container .select2-search-choice {
    border-style: none !important;
  }

  .select2-search-choice {
    padding-left: 2px !important;
  }

  .shared-timerangepicker .btn, .shared-timerangepicker .btn .time-label {
    max-width: 200px !important;
    width: 200px !important;
    text-align: left;
  }

  .dashboard-element:not(.table):not(.event) {
    page-break-inside: avoid;
  }

  .splunk-paginator a.selected {
    font-weight: bold;
  }
}

.content-preview {
  box-sizing: border-box;
  width: 450px;
  height: 100%;
}

.content-preview .preview-body {
  overflow-y: auto;
  position: absolute;
  width: 100%;
  padding: 10px;
  box-sizing: border-box;
  top: 65px;
  bottom: 0;
}

.content-preview .preview-body .control-group {
  clear: both;
}

.dashboard-list-item .accordion-group {
  border: none;
}

.dashboard-panel {
    transition: border-color 2s ease-out, box-shadow 2s ease-out, border-width 2s ease-out;
}

.panel-highlight .dashboard-panel {
  border-color: #3863a0;
  box-shadow: 0 0 10px 2px rgba(56, 99, 160, 0.4);
}

/*  Lite UI */
.input-editor-body .input-editor-type li > a {
  color: #333;
}
.progress-bar {
  display: none;
}
.splunk-header {
  height: 40px;
  background: #333;
}

.splunk-header {
  min-height:20px;
}
/* Add any other necessary core style sheets here. In the previous version,
 the style sheet for select2 was included on the page directly. I do not think
 this will be necessary anymore because that style sheet is included with the
 javscript that depends on it. */

/* Add app specific bootstrap styles here */
